<xsl:stylesheet
  xmlns:math="http://www.w3.org/1998/Math/MathML"
  xmlns:mdf="http://www.mathdox.org/MathDox/Functions"
  xmlns:om="http://www.openmath.org/OpenMath"
  xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="2.0"
>
  <xsl:import href="../openmath2mathml-params.xsl"/>

  <!--
    Utility functions/templates
  -->

  <!-- check if all the argument nodes are points -->
  <xsl:function name='mdf:all_points_without_conditions' as='xs:boolean'>
    <xsl:param name='points' as='node()*'/>
    <xsl:variable name='all_oma_or_omv' as="xs:boolean"
      select='not($points[not (self::OMA or self::om:OMA or self::OMV or
	self::om:OMV)])' 
    />
    <xsl:variable name='all_oms' as="xs:boolean"
      select='not($points[(self::OMA or self::om:OMA) and 
      *[1][not (self::OMS or self::om:OMS)]])' 
    />
    <xsl:variable name='all_points' as="xs:boolean"
      select='not($points[(self::OMA or self::om:OMA) and 
      *[1][not (@name="point" and @cd="plangeo1")]])' 
    />
    <xsl:variable name='all_points_no_conditions' as="xs:boolean"
      select='not($points[(self::OMA or self::om:OMA) and *[3]])' 
    />
    <xsl:value-of select='$all_oma_or_omv and $all_oms and $all_points and 
      $all_points_no_conditions'
    />
  </xsl:function>

  <!--
    mdf:and n-ary and as fn:min
  -->
  <xsl:function name="mdf:and" as='xs:boolean'>
    <xsl:param name='booleanlist' as='xs:boolean*'/>
    <xsl:copy-of select='min($booleanlist)'/>
  </xsl:function>

  <!--
    mdf:interval-separators
    check which separators to use for an interval
    (if commas are used for floats and a float is present, then use a
    semi-colon)
  -->
  <xsl:function name="mdf:interval-separators">
    <xsl:param name="interval" as="node()"/>
    <xsl:choose>
      <xsl:when test="$OMF_use_comma_separator and ($interval/OMF or $interval/om:OMF)">
	<xsl:text>;</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>,</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:function>

  <!-- constructs a list with ',' and 'and' -->
  <xsl:function name='mdf:makelist'>
    <xsl:param name='list' as='node()*'/>
    <xsl:for-each select='$list'>
      <xsl:choose>
        <xsl:when test='position() = 1'/>
        <xsl:when test='position() = last()'>
          <math:mtext>
            <!-- U+00A0 non breakable space -->
            <xsl:text>&#xA0;and&#xA0;</xsl:text>
          </math:mtext>
        </xsl:when>
        <xsl:otherwise>
          <math:mtext>
            <!-- U+00A0 non breakable space -->
            <xsl:text>,&#xA0;</xsl:text>
          </math:mtext>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select='.'/>
    </xsl:for-each>
  </xsl:function>

  <!--
    mdf:om_applied_symbol 
    function that is true if the argument is an <OMA> containing a <OMS> of the
    specified cd and name
  -->

  <xsl:function name='mdf:om_applied_symbol'>
    <xsl:param name='testnode' as='node()'/>
    <xsl:param name='cd' as='xs:string'/>
    <xsl:param name='name' as='xs:string'/>

    <xsl:variable name='is_oma' as='xs:boolean' 
      select='boolean($testnode[self::OMA or self::om:OMA])'
    />
    <xsl:variable name='is_oms' as='xs:boolean' 
      select='boolean($testnode/*[1][self::OMS or self::om:OMS])'
    />
    <xsl:variable name='is_symbol' as='xs:boolean' 
      select='boolean($testnode/*[1][@cd=$cd and $name=$name])'
    />
    <xsl:copy-of select='$is_oma and $is_oms and $is_symbol'/>
  </xsl:function>

  <xsl:function name='mdf:omi_pos' as='xs:boolean'>
    <xsl:param name='testnode' as='node()'/>

    <xsl:copy-of select='boolean($testnode[(self::OMI or self::om:OMI) and not(starts-with(.,"-"))])'/>
  </xsl:function>

  <!--
    mdf:or 
    n-ary or as fn:max
  -->
  <xsl:function name="mdf:or" as='xs:boolean'>
    <xsl:param name='booleanlist' as='xs:boolean*'/>
    <xsl:copy-of select='max($booleanlist)'/>
  </xsl:function>

  <xsl:function name='mdf:nodetest_transc1_power' as='xs:boolean'>
    <xsl:param name='testnode' as='node()'/>

    <xsl:variable name='is_oma_power' as='xs:boolean' 
      select='mdf:om_applied_symbol($testnode, "arith1", "power")'
    />
    <xsl:variable name='is_intexp' as='xs:boolean' 
      select='boolean($testnode/*[3]) and mdf:omi_pos($testnode/*[3])'
    />
    <xsl:variable name='is_transc1_sym' as='xs:boolean' 
    >
      <xsl:variable name='testnode'
        select='$testnode/*[2]'
      />
      <xsl:variable name='is_oma' as='xs:boolean' 
        select='boolean($testnode[self::OMA or self::om:OMA])'
      />
      <xsl:variable name='omsnode' select='$testnode/*[1]'/>

      <xsl:variable name='is_oms' as='xs:boolean' 
        select='boolean($omsnode[self::OMS or self::om:OMS])'
      />
      <xsl:variable name='is_transc1' as='xs:boolean' 
        select='boolean($omsnode[@cd = "transc1"])'
      />
      <xsl:variable name='name' as='xs:string' >
        <xsl:choose>
          <xsl:when test='$omsnode/@name'>
            <xsl:value-of select='$omsnode/@name'/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>none</xsl:text>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>

      <xsl:variable name='is_sinlike' as='xs:boolean' 
        select='not(empty(index-of(("arccos", "arccosh", "arccot", "arccoth", "arccsc", "arccsch", "arcsec", "arcsech", "arcsin", "arcsinh", "arctan", "arctanh", "cos", "cosh", "cot", "coth", "csc", "csch", "sec", "sech", "sin", "sinh", "tan", "tanh"), $name)))'
      />

      <xsl:copy-of select='$is_oma and $is_oms and $is_transc1 and $is_sinlike'/>
    </xsl:variable>

    <xsl:copy-of select='$is_oma_power and $is_intexp and $is_transc1_sym'/>
  </xsl:function>

</xsl:stylesheet> 
