<xsl:stylesheet 
  xmlns:math="http://www.w3.org/1998/Math/MathML"
  xmlns:om="http://www.openmath.org/OpenMath"
  xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
  version="2.0"
>
  <!--<xsl:param name='OMV_use_special' select='false()' as='xs:boolean'/>-->

  <!-- 
    the naming of symbols is like LaTeX, 
    NOTE: there is no omicron, and not all capitals are present
  -->
  <xsl:variable name='omv_special' as='node()*'>
    <OMV name='...' style='cdots'>
      <math:mo>
        <!-- U+22EF midline horizontal ellipsis -->
        <xsl:text>&#x22EF;</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='...'>
      <math:mo>
        <xsl:text>...</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='cdot'>
      <math:mo>
        <!-- U+00B7 middle dot -->
        <xsl:text>&#x00B7;</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='cdots'>
      <math:mo>
        <!-- U+22EF midline horizontal ellipsis -->
        <xsl:text>&#x22EF;</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='cong'>
      <math:mo>
        <!-- U+2245 approximately equal to -->
        <xsl:text>&#x2245;</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='dots'>
      <math:mo>
        <!-- U+22EF midline horizontal ellipsis -->
        <xsl:text>&#x22EF;</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='equiv'>
      <math:mo>
        <!-- U+2261 identical to -->
        <xsl:text>&#x2261;</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='ldots'>
      <math:mo>
        <xsl:text>...</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='minus'>
      <math:mo>
        <xsl:text>-</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='plus'>
      <math:mo>
        <xsl:text>+</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='star'>
      <math:mo>
        <xsl:text>*</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='stippeltjes'>
      <math:mo>
        <xsl:text>...</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='tilde'>
      <math:mo>
        <!-- U+223C tilde operator -->
        <xsl:text>&#x223C;</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='times' style='cross'>
      <math:mo>
        <!-- U+00D7 multiplication sign -->
        <xsl:text>&#x00D7;</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='times' style='star'>
      <math:mo>
        <xsl:text>*</xsl:text>
      </math:mo>
    </OMV>
    <OMV name='times'>
      <math:mo>
        <!-- U+00B7 middle dot -->
        <xsl:text>&#x00B7;</xsl:text>
      </math:mo>
    </OMV>
  </xsl:variable>

  <xsl:variable name='omv_special_endings_xml' as='node()*'>
    <OMV ending="'">
      <math:mo>
        <!-- alternative U+2032 Prime -->
        <xsl:text>'</xsl:text>
      </math:mo>
    </OMV>
    <OMV ending='"'>
      <math:mo>
        <!-- alternative U+2033 Double prime -->
        <xsl:text>"</xsl:text>
      </math:mo>
    </OMV>
    <OMV ending="`">
      <math:mo>
        <!-- alternative U+2035 Reversed prime -->
        <xsl:text>`</xsl:text>
      </math:mo>
    </OMV>
    <OMV ending=" ">
      <math:mo>
        <xsl:text> </xsl:text>
      </math:mo>
    </OMV>
  </xsl:variable>

  <xsl:variable name='omv_special_endings' as='xs:string*'
    select='$omv_special_endings_xml/@ending'
  />
  <xsl:variable name='omv_special_names' as='xs:string*'
    select='$omv_special/@name'
  />

  <xsl:template match='OMV|om:OMV' mode='omv_special'>
    <xsl:variable name='name' select='@name'/>

    <xsl:choose>
      <xsl:when test='@style'>
        <xsl:variable name='style' select='@style'/>
        <xsl:choose>
          <xsl:when test='$omv_special[@name=$name and @style=$style]'>
            <xsl:copy-of select='$omv_special[@name=$name and @style=$style]/*'/>
          </xsl:when>
          <xsl:otherwise>
            <!-- style not found; use default -->
            <xsl:message>
              <xsl:text>WARNING: did not find special variable with name '</xsl:text>
              <xsl:value-of select='$name'/>
              <xsl:text>' and style '</xsl:text>
              <xsl:value-of select='$style'/>
              <xsl:text>'. Using the default style instead.</xsl:text>
            </xsl:message>

            <xsl:copy-of select='$omv_special/self::*[@name=$name and not(@style)]/*'/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:copy-of select='$omv_special/self::*[@name=$name and not(@style)]/*'/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match='OMV|om:OMV' mode='omv_special_ending'>
    <math:mrow>
      <xsl:variable name='ending' select='substring(@name, string-length(@name))'/>

      <!-- store result in contents -->
      <xsl:variable name='contents'>
        <math:mi>
          <xsl:value-of select='substring(@name, 0, string-length(@name))'/>
        </math:mi>

        <xsl:copy-of select='$omv_special_endings_xml[@ending=$ending]/*'/>
      </xsl:variable>

      <!-- for prime-like endings use msup -->
      <xsl:choose>
        <xsl:when test='$omv_special_endings_xml[@ending=$ending and @use_msup="true"]'>
          <math:msup>
            <xsl:copy-of select='$contents'/>
          </math:msup>
        </xsl:when>
        <xsl:otherwise>
          <math:mrow>
            <xsl:copy-of select='$contents'/>
          </math:mrow>
        </xsl:otherwise>
      </xsl:choose>
    </math:mrow>
  </xsl:template>
</xsl:stylesheet>
