<xsl:stylesheet
  xmlns:math="http://www.w3.org/1998/Math/MathML"
  xmlns:mdf="http://www.mathdox.org/MathDox/Functions"
  xmlns:om="http://www.openmath.org/OpenMath"
  xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="2.0"
>

  <!-- *******************************************************************
       
       prog1 CD 
       with mode prog1latex, for seperate translation of prog1 
       (not as inline math)
       version 0, revision 1
       supported: assignment, block, call_arguments, def_arguments, for,
         function_block, function_call, function_definition, global_var, if,
         local_var, while, return
       TODO: procedure_block, procedure_call, procedure_definition
       
       ALSO SUPPORTED (should not be used): 
       - arguments (call_arguments)
       - functioncall (function_call)
       ******************************************************************* -->
  
  <!-- arguments is now called call_arguments, but still supported for backwards compatibility -->

  <xsl:template match="OMA[OMS[@cd='prog1' and @name='assignment']]"
    mode="prog1latex"
  >
    <xsl:apply-templates select="*[2]" mode='#current'/>
    <xsl:text>:=</xsl:text>
    <xsl:apply-templates select="*[3]" mode='#current'/>
    <xsl:text>\  </xsl:text>
  </xsl:template>

  <xsl:template match="OMA[OMS[@cd='prog1' and @name='block']]" 
    mode="prog1latex"
  > 
    <xsl:choose>
      <xsl:when test="OMA[OMS[@cd='prog1' and @name='block']]">
        <xsl:text>\begin{array}{l}&#10;</xsl:text>
        <xsl:for-each select="*[position()>1]">
          <xsl:apply-templates select="." mode='#current'/>
          <xsl:text> \\ </xsl:text>
        </xsl:for-each>
        <xsl:text>\end{array}&#10;</xsl:text>
      </xsl:when>
      <xsl:when 
        test="parent::OMA[OMS[@cd='prog1' and @name='function_block']]"
      >
        <xsl:for-each select="*[position()>1]">
          <xsl:apply-templates select="." mode='#current'/>
          <xsl:if test="position() &lt; last()">
            <xsl:text>, \ </xsl:text>
          </xsl:if>
        </xsl:for-each> \\
      </xsl:when>
      <xsl:otherwise>
        <xsl:for-each select="*[position()>1]">
          <xsl:apply-templates select="." mode='#current'/>
          <xsl:if test="position() &lt; last()">
            <xsl:text>, \  </xsl:text>
          </xsl:if>
        </xsl:for-each> 
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- arguments is now called call_arguments, but still supported for backwards compatibility -->
  <xsl:template match="OMA[OMS[@cd='prog1' and (@name='call_arguments' or @name='arguments')]]" mode="prog1latex">
    <xsl:text>\mathbf{procedure}(</xsl:text>
    <xsl:for-each select="*[position()>1]">
      <xsl:apply-templates select="." mode='#current'/>
      <xsl:if test="position() &lt; last()">
        <xsl:text>,</xsl:text>
      </xsl:if>
    </xsl:for-each>
    <xsl:text>)</xsl:text>
  </xsl:template>

  <xsl:template match="OMA[OMS[@cd='prog1' and @name='def_arguments']]" mode="prog1latex">
    <xsl:text>\mathbf{procedure}(</xsl:text>
    <xsl:for-each select="*[position()>1]">
      <xsl:apply-templates select="." mode='#current'/>
      <xsl:if test="position() &lt; last()">
        <xsl:text>,</xsl:text>
      </xsl:if>
    </xsl:for-each>
    <xsl:text>)</xsl:text>
  </xsl:template>

  <xsl:template match="OMA[OMS[@cd='prog1' and @name='for']]" mode="prog1latex">
    <xsl:text>\mathbf{for\ } </xsl:text>
    <xsl:apply-templates select="*[2]" mode='#current'/>
    <xsl:text>\mathbf{\ while \ }</xsl:text>
    <xsl:apply-templates select="*[3]" mode='#current'/>
    <xsl:text>\mathbf{\ with\ step\ } </xsl:text>
    <xsl:apply-templates select="*[4]" mode='#current'/>
    <xsl:text>\mathbf{\ do\ } \\&#10;</xsl:text>
    <xsl:text>\phantom{aaa}\begin{array}{|l}&#10;</xsl:text>
    <xsl:apply-templates select="*[5]" mode='#current'/>
    <xsl:text>\\&#10;</xsl:text>
    <xsl:text>\end{array}\\</xsl:text>
  </xsl:template>

  <xsl:template mode="prog1latex" match="OMA[OMS[@cd='prog1' and @name='function_block']]">
    <xsl:for-each select="*[position() &gt; 1]">
      <xsl:apply-templates select="." mode='#current'/>
    </xsl:for-each>
  </xsl:template>

  <!-- functioncall is now named function_call -->
  <xsl:template match="OMA[OMS[@cd='prog1' and (@name='function_call' or @name='functioncall')]]" mode="prog1latex">
    <xsl:apply-templates select="*[2]" mode='#current'/>
  </xsl:template>

  <!-- 
    mathbf now ends after the name because the template for arguments also
    uses mathbf and nested bold is not permitted in latex, jwk
  -->
  <xsl:template match="OMA[OMS[@cd='prog1' and @name='function_definition']]"
    mode="prog1latex"
  >
    <xsl:text>\begin{array}{l}&#10;</xsl:text>
    <xsl:text>\mathbf{</xsl:text>
    <xsl:apply-templates select="*[2]" mode='#current'/>
    <xsl:text>} :=</xsl:text>
    <xsl:apply-templates select="*[3]" mode='#current'/>
    <xsl:text>\\ </xsl:text>
    <xsl:apply-templates select="*[4]" mode='#current'/>
    <xsl:text>\end{array} </xsl:text>
  </xsl:template>

  <xsl:template match="OMA[OMS[@cd='prog1' and @name='global_var']]" mode="prog1latex">
    <xsl:text>\mathbf{global variables}\\&#10;</xsl:text>
    <xsl:text>\phantom{aaa}\begin{array}{|l}&#10;</xsl:text>
    <xsl:for-each select="*[position() &gt; 1]">
      <xsl:apply-templates select="." mode='#current'/>
      <xsl:text> \\ </xsl:text>
    </xsl:for-each>
    <xsl:text>\end{array}\\ </xsl:text>
  </xsl:template>


  <xsl:template match="OMA[OMS[@cd='prog1' and @name='if']]" mode="prog1latex">
    <xsl:text>\mathbf{if\ }</xsl:text>
    <xsl:apply-templates select="*[2]" mode='#current'/>
    <xsl:text> \\&#10;</xsl:text>
    <xsl:text>\phantom{aaa}\begin{array}{|l}&#10;</xsl:text>
    <xsl:text>\mathbf{then\ }\\&#10;</xsl:text>
    <xsl:text>\phantom{aaa}\begin{array}{|l}</xsl:text>
    <xsl:apply-templates select="*[3]" mode='#current'/>
    <xsl:text>\end{array}\\&#10;</xsl:text>

    <xsl:if test="*[4]">
      <xsl:text>\mathbf{else\ }\\&#10;</xsl:text>
      <xsl:text>\phantom{aaa}\begin{array}{|l}</xsl:text>
      <xsl:apply-templates select="*[4]" mode='#current'/>
      <xsl:text>\end{array}\\</xsl:text>
    </xsl:if>

    <xsl:text>\end{array} \\ </xsl:text>
  </xsl:template>

  <xsl:template match="OMA[OMS[@cd='prog1' and @name='local_var']]" mode="prog1latex">
    <xsl:text>\mathbf{local\ variables}\\&#10;</xsl:text>
    <xsl:text>\phantom{aaa}\begin{array}{|l}&#10;</xsl:text>
    <xsl:for-each select="*[position() &gt;1]">
      <xsl:apply-templates select="." mode='#current'/> 
      <xsl:text>\\&#10;</xsl:text>
      <!--
        amc: following idea does not go well with the semicolons of
        assignments inside the local vars declarations
        <xsl:choose>
          <xsl:when test="position() =4 or position() =8 or position() =12 or position() =16">
            <xsl:text> \\ &#10;</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text> \ &#10;</xsl:text>
          </xsl:otherwise>
        </xsl:choose>
      -->
    </xsl:for-each>
    <xsl:text>\end{array}\\ </xsl:text>
  </xsl:template>

  <xsl:template match="OMA[OMS[@cd='prog1' and @name='return']]" mode="prog1latex">
    <xsl:text>\mathbf{return}\\&#10;</xsl:text>
    <xsl:text>\phantom{aaa}\begin{array}{|l}&#10;</xsl:text>
    <xsl:for-each select="*[position() &gt; 1]"> 
      <xsl:apply-templates select="." mode='#current'/>
        <xsl:text> \\&#10;</xsl:text>
    </xsl:for-each>
    <xsl:text>\end{array}\\&#10;</xsl:text>
  </xsl:template>

  <xsl:template match="OMA[OMS[@cd='prog1' and @name='while']]" mode="prog1latex">
    <xsl:variable name="position" select="position"/>
    <xsl:if test="$position &gt; 1 and ../OMA[$position - 1][OMS[@cd='prog1' and @name='assignment']]">
      <xsl:text>\\</xsl:text>
    </xsl:if>
    <xsl:text>\mathbf{while\ }</xsl:text>
    <xsl:apply-templates select="*[2]" mode='#current'/>
    <xsl:text>\ \mathbf{do}\\&#10;</xsl:text>
    <xsl:text>\phantom{aaa}\begin{array}{|l}&#10;</xsl:text>
    <xsl:apply-templates select="*[3]" mode='#current'/>
    <xsl:text>\\&#10;</xsl:text>
    <xsl:text>\end{array}\\ </xsl:text>
  </xsl:template>

  <!-- default for attributes/text copy -->
  <xsl:template match="@*|text()" mode='prog1latex'>
    <xsl:copy/>
  </xsl:template>

  <!-- default for elements: copy -->
  <xsl:template match="*" mode='prog1latex'>
    <xsl:copy>
      <xsl:apply-templates select='@*' mode='#current'/>
      <xsl:apply-templates mode='#current'/>
    </xsl:copy>
  </xsl:template>

</xsl:stylesheet>
