<xsl:stylesheet
  xmlns:xhtml="http://www.w3.org/1999/xhtml"
  xmlns:math="http://www.w3.org/1998/Math/MathML"
  xmlns:mdf="http://www.mathdox.org/MathDox/Functions"
  xmlns:om="http://www.openmath.org/OpenMath"
  xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="2.0"
>

  <!-- *******************************************************************

       prog1
       with mode prog1xhtml, for seperate translation of prog1 
       (not as inline math)
       version 0, revision 1
       supported: assignment, block, call_arguments, for, function_block,
         function_call, function_definition, global_var, if, local_var, while,
         return
       TODO: def_arguments, procedure_block, procedure_call, procedure_definition
       
       ALSO SUPPORTED (should not be used): 
       - arguments (call_arguments)
       - functioncall (function_call)
 
       ******************************************************************* -->

  <xsl:template match="om:OMA[om:OMS[@cd='prog1' and @name='assignment']]|OMA[OMS[@cd='prog1' and @name='assignment']]" mode='prog1xhtml'>
    <xhtml:div class="assignment">
      <xsl:apply-templates select="*[2]" mode="#current"/>
      <math:mo>
        <xsl:text>:=</xsl:text>
      </math:mo>
      <xsl:apply-templates select="*[3]" mode="#current"/>
    </xhtml:div>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='prog1' and @name='block']]|OMA[OMS[@cd='prog1' and @name='block']]" mode='prog1xhtml'>
    <xhtml:div>
      <xsl:for-each select="*[position()&gt;1]">
        <xsl:apply-templates select="." mode="#current"/>
      </xsl:for-each>
    </xhtml:div>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='prog1' and (@name='call_arguments' or @name='arguments')]]|OMA[OMS[@cd='prog1' and (@name='call_arguments' or @name='arguments')]]" mode='prog1xhtml'>
    <xsl:text>Procedure</xsl:text>
    <math:mfenced open="(" close=")" separator=",">
      <xsl:for-each select="*[position()&gt;1]">
        <xsl:apply-templates select="." mode="#current"/>
      </xsl:for-each>
    </math:mfenced>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='prog1' and @name='for']]|OMA[OMS[@cd='prog1' and @name='for']]" mode='prog1xhtml'>
    <xhtml:b>
      <xsl:text>For</xsl:text>
    </xhtml:b>
    <xhtml:div class="alg-block">
      <xhtml:b>
        <xsl:text> From</xsl:text>
      </xhtml:b>
      <xhtml:br/>
      <xhtml:div class="alg-block">
        <xsl:apply-templates select="*[2]" mode="#current"/>
      </xhtml:div>
      <xhtml:b>
        <xsl:text>To </xsl:text>
      </xhtml:b>
      <xhtml:br/>
      <xhtml:div class="alg-block">
        <xsl:apply-templates select="*[3]" mode="#current"/>
      </xhtml:div>
      <xhtml:b>
        <xsl:text>with stepsize </xsl:text>
      </xhtml:b>
      <xhtml:br/>
      <xhtml:div class="alg-block">
        <xsl:apply-templates select="*[4]" mode="#current"/>
      </xhtml:div>
      <xhtml:b>
        <xsl:text>Do</xsl:text>
      </xhtml:b>
      <xhtml:br/>
      <xhtml:div class="alg-block">
        <xsl:apply-templates select="*[5]" mode="#current"/>
      </xhtml:div>
    </xhtml:div>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='prog1' and @name='function_block']]|OMA[OMS[@cd='prog1' and @name='function_block']]" mode='prog1xhtml'>
    <xsl:for-each select="*[position() &gt; 1]">
      <xsl:apply-templates select="." mode="#current"/>
    </xsl:for-each>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='prog1' and @name='function_definition']]|OMA[OMS[@cd='prog1' and @name='function_definition']]" mode='prog1xhtml'>
    <xhtml:hr/>
    <xhtml:b>
      <xsl:apply-templates select="*[2]" mode="#current"/>
      <xsl:text> :=</xsl:text>
      <xsl:apply-templates select="*[3]" mode="#current"/>
    </xhtml:b>
    <xhtml:br/>
    <xhtml:div class="alg-block">
      <xsl:apply-templates select="*[4]" mode="#current"/>
    </xhtml:div>
    <xhtml:br/>
    <xhtml:hr/>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='prog1' and @name='procedure']]|OMA[OMS[@cd='prog1' and @name='procedure']]" mode='prog1xhtml'>
    <xhtml:hr/>
    <xhtml:b>
      <xsl:apply-templates select="*[2]" mode="#current"/>
      <xsl:text> :=</xsl:text>
      <xsl:apply-templates select="*[3]" mode="#current"/>
    </xhtml:b>
    <xhtml:br/>
    <xhtml:div class="alg-block">
      <xsl:apply-templates select="*[4]" mode="#current"/>
    </xhtml:div>
    <xhtml:br/>
    <xhtml:hr/>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='prog1' and (@name='function_call' or @name='functioncall')]]|OMA[OMS[@cd='prog1' and (@name='function_call' or @name='functioncall')]]" mode='prog1xhtml'>
    <xsl:apply-templates select="*[2]" mode="#current"/>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='prog1' and @name='global_var']]|OMA[OMS[@cd='prog1' and @name='global_var']]" mode='prog1xhtml'>
    <xhtml:b>
      <xsl:text> global variables </xsl:text>
    </xhtml:b>
    <xhtml:br/>
    <xhtml:div class="alg-block">
      <xsl:for-each select="*[position() &gt; 1]">
        <xsl:apply-templates select="." mode="#current"/>
      </xsl:for-each>
    </xhtml:div>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='prog1' and @name='if']]|OMA[OMS[@cd='prog1' and @name='if']]" mode='prog1xhtml'>
    <xhtml:b>
      <xsl:text>If</xsl:text>
    </xhtml:b>
    <xhtml:br/>
    <xhtml:div class="alg-block">
      <xsl:apply-templates select="*[2]" mode="#current"/>
      <xhtml:br/>
      <xhtml:br/>
      <xhtml:b>
        <xsl:text>Then </xsl:text>
      </xhtml:b>
      <xhtml:br/>
      <xhtml:div class="alg-block">
        <xsl:apply-templates select="*[3]" mode="#current"/>
      </xhtml:div>
      <xhtml:br/>
      <xhtml:b>
        <xsl:text>Else </xsl:text>
      </xhtml:b>
      <xhtml:br/>
      <xhtml:div class="alg-block">
        <xsl:apply-templates select="*[4]" mode="#current"/>
      </xhtml:div>
    </xhtml:div>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='prog1' and @name='local_var']]|OMA[OMS[@cd='prog1' and @name='local_var']]" mode='prog1xhtml'>
    <xhtml:b>
      <xsl:text> Local variables </xsl:text>
    </xhtml:b>
    <xhtml:br/>
    <xhtml:div class="alg-block">
      <xsl:for-each select="*[position() &gt; 1]">
        <xhtml:div>
          <xsl:apply-templates select="." mode="#current"/>
        </xhtml:div>
      </xsl:for-each>
      <xhtml:br/>
    </xhtml:div>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='prog1' and @name='local_vars']]|OMA[OMS[@cd='prog1' and @name='local_vars']]" mode='prog1xhtml'>
    <xhtml:b>
      <xsl:text> Local variables </xsl:text>
    </xhtml:b>
    <xhtml:br/>
    <xhtml:div class="alg-block">
      <xsl:for-each select="*[position() &gt; 1]">
        <xhtml:div>
          <xsl:apply-templates select="." mode="#current"/>
        </xhtml:div>
      </xsl:for-each>
      <xhtml:br/>
    </xhtml:div>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='prog1' and @name='return']]|OMA[OMS[@cd='prog1' and @name='return']]" mode='prog1xhtml'>
    <xhtml:b>
      <xsl:text>Return</xsl:text>
    </xhtml:b>
    <xhtml:br/>
    <xhtml:div class="alg-block">
      <xsl:for-each select="*[position() &gt; 1]">
        <xhtml:div>
          <xsl:apply-templates select="." mode="#current"/>
        </xhtml:div>
      </xsl:for-each>
    </xhtml:div>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='prog1' and @name='while']]|OMA[OMS[@cd='prog1' and @name='while']]" mode='prog1xhtml'>
    <xhtml:br/>
    <xhtml:b>
      <xsl:text>While</xsl:text>
    </xhtml:b>
    <xhtml:div class="alg-block">
      <!--<xhtml:b>Test</xhtml:b><br/>-->
      <xsl:apply-templates select="*[2]" mode="#current"/>
      <xhtml:br/>
      <xhtml:b>
        <xsl:text>Do</xsl:text>
      </xhtml:b>
      <xhtml:br/>
      <xhtml:div class="alg-block">
        <xsl:apply-templates select="*[3]" mode="#current"/>
      </xhtml:div>
    </xhtml:div>
    <xhtml:br/>
  </xsl:template>

  <!-- default for attributes/text copy -->
  <xsl:template match="@*|text()" mode='prog1xhtml'>
    <xsl:copy/>
  </xsl:template>

  <!-- default for elements: copy -->
  <xsl:template match="*" mode='prog1xhtml'>
    <xsl:copy>
      <xsl:apply-templates select='@*' mode='#current'/>
      <xsl:apply-templates mode='#current'/>
    </xsl:copy>
  </xsl:template>

</xsl:stylesheet>
