<?xml version="1.0" encoding="us-ascii"?>
<xsl:stylesheet 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:om="http://www.openmath.org/OpenMath"
  xmlns:math="http://www.w3.org/1998/Math/MathML" 
  version="2.0"
>

  <!-- 
    supported cds
    name            version canonical url
    units_metric1     3     http://www.openmath.org/cd/units_metric1.xhtml
    units_siprefix1   1     http://www.openmath.org/cd/units_siprefix1.xhtml
    units_time1       1     http://www.openmath.org/cd/units_time1.xhtml
  -->

  <!--
    CD  name: units_metric1
        version: 3 
        url: http://www.openmath.org/cd/units_metric1.xhtml
  -->

  <!-- 
    define some symbols that are used in composed units 
  -->
  <!-- metre, distance -->
  <xsl:variable name="units_metric1_metre">
    <om:OMS cd="metric1" name="metre"/>
  </xsl:variable>

  <!-- Newton, force -->
  <xsl:variable name="units_metric1_Newton">
    <om:OMS cd="metric1" name="Newton"/>
  </xsl:variable>

  <!-- second, time -->
  <xsl:variable name="units_metric1_second">
    <om:OMS cd="metric1" name="second"/>
  </xsl:variable>

  <!--
    put the code that is always the same and then apply the templates in mode
    simple to get the symbol itself.
  -->
  <xsl:template match="*[ ((name() = 'OMS') or (name() = 'om:OMS')) and @cd = 'units_metric1' and matches(@name, 'amp|Coulomb|degree_Celsius|degree_Kelvin|gramme|Joule|litre|litre_pre1964|metre|Newton|Pascal|second|volt|Watt') ]">
    <!-- 
      easy symbol 
    -->
    <math:mi mathvariant='normal' class='MathML-Unit'>
      <xsl:apply-templates mode="units_metric1_simple" select="."/>
    </math:mi>
  </xsl:template>

  <xsl:template match="*[ (name()='OMS' or name()='om:OMS') and @cd = 'units_metric1' and matches(@name, 'metre_sqrd|metres_per_second|metres_per_second_sqrd|Newton_per_sqr_metre') ]">
    <!-- 
      everything else handled differently per symbol
    -->
    <xsl:apply-templates mode="units_metric1_combined" select="."/>
  </xsl:template>

  <!--
    metre_sqrd, area, m^2
  -->
  <xsl:template mode="units_metric1_combined" match="*[ @name='metre_sqrd' ]">
    <math:apply>
      <math:power/>
      <xsl:apply-templates select="$units_metric1_metre"/>
      <math:cn type="integer">2</math:cn>
    </math:apply>
  </xsl:template>

  <!--
    metres per second, speed
  -->
  <xsl:template mode="units_metric1_combined" match="*[ @name='metres_per_second' ]">
    <math:apply>
      <math:divide/>
      <xsl:apply-templates select="$units_metric1_metre"/>
      <xsl:apply-templates select="$units_metric1_second"/>
    </math:apply>
  </xsl:template>

  <!--
    metres per second squared, acceleration
  -->
  <xsl:template mode="units_metric1_combined" match="*[ @name='metres_per_second_sqrd' ]">
    <math:apply>
      <math:divide/>
      <xsl:apply-templates select="$units_metric1_metre"/>
      <math:apply>
        <math:power/>
        <xsl:apply-templates select="$units_metric1_second"/>
        <math:cn type="integer">2</math:cn>
      </math:apply>
    </math:apply>
  </xsl:template>

  <!--
    Newton per square metre, pressure
  -->
  <xsl:template mode="units_metric1_combined" match="*[ @name='Newton_per_sqr_metre' ]">
    <math:apply>
      <math:divide/>
      <xsl:apply-templates select="$units_metric1_Newton"/>
      <math:apply>
        <math:power/>
        <xsl:apply-templates select="$units_metric1_metre"/>
        <math:cn type="integer">2</math:cn>
      </math:apply>
    </math:apply>
  </xsl:template>

  <!--
    Ampere, current
  -->
  <xsl:template mode="units_metric1_simple" match="*[ @name='amp' ]">
    <xsl:text>A</xsl:text>
  </xsl:template>

  <!--
    Coulomb, charge
  -->
  <xsl:template mode="units_metric1_simple" match="*[ @name='Coulomb' ]">
    <xsl:text>C</xsl:text>
  </xsl:template>

  <!--
    degree Celsius, temperature
  -->
  <xsl:template mode="units_metric1_simple" match="*[ @name='degree_Celsius' ]">
    <xsl:text>&#x00B0;C</xsl:text> <!-- U+00B0: degree sign -->
  </xsl:template>

  <!--
    degree Kelvin, temperature
  -->
  <xsl:template mode="units_metric1_simple" match="*[ @name='degree_Kelvin' ]">
    <xsl:text>&#x00B0;K</xsl:text> <!-- U+00B0: degree sign -->
  </xsl:template>

  <!--
    gramme, mass (1 gramme is 10^-3 kg)
  -->
  <xsl:template mode="units_metric1_simple" match="*[ @name='gramme' ]">
    <xsl:text>g</xsl:text>
  </xsl:template>

  <!--
    Joule, energy
  -->
  <xsl:template mode="units_metric1_simple" match="*[ @name='Joule' ]">
    <xsl:text>J</xsl:text>
  </xsl:template>

  <!--
    litre, volume, 10^-3 m^3
  -->
  <xsl:template mode="units_metric1_simple" match="*[ @name='litre' ]">
    <xsl:text>l</xsl:text>
  </xsl:template>

  <!--
    litre, volume, 1901-1964, 1kg water at maximum density
  -->
  <xsl:template mode="units_metric1_simple" match="*[ @name='litre_pre1964' ]">
    <xsl:text>l</xsl:text>
  </xsl:template>

  <!--
    metre, distance
  -->
  <xsl:template mode="units_metric1_simple" match="*[ @name='metre' ]">
    <xsl:text>m</xsl:text>
  </xsl:template>

  <!--
    Newton, force
  -->
  <xsl:template mode="units_metric1_simple" match="*[ @name='Newton' ]">
    <xsl:text>N</xsl:text>
  </xsl:template>

  <!--
    Pascal, pressure
  -->
  <xsl:template mode="units_metric1_simple" match="*[ @name='Pascal' ]">
    <xsl:text>Pa</xsl:text>
  </xsl:template>

  <!--
    second, time
  -->
  <xsl:template mode="units_metric1_simple" match="*[ @name='Pascal' ]">
    <xsl:text>s</xsl:text>
  </xsl:template>

  <!--
    volt, potential/voltage
  -->
  <xsl:template mode="units_metric1_simple" match="*[ @name='volt' ]">
    <xsl:text>V</xsl:text>
  </xsl:template>

  <!--
    Watt, power
  -->
  <xsl:template mode="units_metric1_simple" match="*[ @name='Watt' ]">
    <xsl:text>W</xsl:text>
  </xsl:template>

  <!--
    CD  name: units_siprefix1
	version: 1
	url: http://www.openmath.org/cd/units_siprefix1.xhtml
  -->

  <xsl:variable name="units_siprefix1_all">
    <xsl:text>atto|centi|deci|deka|exa|femto|giga|hecto|kilo|mega|micro|milli|nano|peta|pico|tera|yocto|yotta|zepto|zetta</xsl:text>
  </xsl:variable>

  <!--
    put the code that is always the same and then apply the templates in mode
    simple to get the symbol itself.
  -->
  <xsl:template match="*[ ((name() = 'OMS') or (name() = 'om:OMS')) and @cd = 'units_siprefix1' and matches(@name, $units_siprefix1_all) ]">
    <!-- 
      easy symbol 
    -->
    <math:mi mathvariant='normal' class='MathML-Unit'>
      <xsl:apply-templates mode="units_siprefix1_simple" select="."/>
    </math:mi>
  </xsl:template>

  <!-- 
    applying a prefix to another unit is a kind of multiplication 
  -->
  <xsl:template match="OMA[OMS[position() = 1 and @cd = 'units_siprefix1' and matches(@name, $units_siprefix1_all)]]|om:OMA[om:OMS[position() = 1 and @cd = 'units_siprefix1' and matches(@name, $units_siprefix1_all)]]">
    <xsl:choose>
      <!--
        second is a simple metric unit
      -->
      <xsl:when test="*[ position()=2 and (name()='OMS' or name()='om:OMS') and @cd='units_metric1' and matches(@name, 'amp|Coulomb|degree_Celsius|degree_Kelvin|gramme|Joule|litre|litre_pre1964|metre|Newton|Pascal|second|volt|Watt')]">
	<math:mi mathvariant='normal' class='MathML-Unit'>
	  <xsl:apply-templates mode="units_siprefix1_simple" select="*[1]"/>
	  <xsl:apply-templates mode="units_metric1_simple" select="*[2]"/>
	</math:mi>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="*[1]"/>
        <xsl:apply-templates select="*[2]"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--
    atto, 10^-18
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='atto' ]">
    <xsl:text>a</xsl:text>
  </xsl:template>

  <!--
    centi, 10^-2
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='centi' ]">
    <xsl:text>c</xsl:text>
  </xsl:template>

  <!--
    deci, 10^-1
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='deci' ]">
    <xsl:text>d</xsl:text>
  </xsl:template>

  <!--
    deka, 10^1
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='deka' ]">
    <xsl:text>da</xsl:text>
  </xsl:template>

  <!--
    exa, 10^18
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='exa' ]">
    <xsl:text>E</xsl:text>
  </xsl:template>

  <!--
    femto, 10^-15
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='femto' ]">
    <xsl:text>f</xsl:text>
  </xsl:template>

  <!--
    giga, 10^92
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='giga' ]">
    <xsl:text>G</xsl:text>
  </xsl:template>

  <!--
    hecto, 10^2
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='hecto' ]">
    <xsl:text>h</xsl:text>
  </xsl:template>

  <!--
    kilo, 10^3
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='kilo' ]">
    <xsl:text>k</xsl:text>
  </xsl:template>

  <!--
    mega, 10^6
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='mega' ]">
    <xsl:text>M</xsl:text>
  </xsl:template>

  <!--
    micro, 10^-6
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='micro' ]">
    <xsl:text>&#x00B5;</xsl:text> <!-- U+00B5 is micro sign (mu-like) -->
  </xsl:template>

  <!--
    milli, 10^-3
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='milli' ]">
    <xsl:text>m</xsl:text>
  </xsl:template>

  <!--
    nano, 10^-9
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='nano' ]">
    <xsl:text>n</xsl:text>
  </xsl:template>

  <!--
    peta, 10^15
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='peta' ]">
    <xsl:text>P</xsl:text>
  </xsl:template>

  <!--
    pico, 10^-12
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='pico' ]">
    <xsl:text>p</xsl:text>
  </xsl:template>

  <!--
    tera, 10^12
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='tera' ]">
    <xsl:text>T</xsl:text>
  </xsl:template>

  <!--
    yocto, 10^-24
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='yocto' ]">
    <xsl:text>y</xsl:text>
  </xsl:template>

  <!--
    yotta, 10^24
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='yotta' ]">
    <xsl:text>Y</xsl:text>
  </xsl:template>

  <!--
    zepto, 10^-21
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='zepto' ]">
    <xsl:text>z</xsl:text>
  </xsl:template>

  <!--
    zetta, 10^21
  -->
  <xsl:template mode="units_siprefix1_simple" match="* [ @name='zetta' ]">
    <xsl:text>Z</xsl:text>
  </xsl:template>

  <!--
    CD  name: units_time1
	version: 1
	url: http://www.openmath.org/cd/units_time1.xhtml
  -->

<xsl:template match="*[ ((name() = 'OMS') or (name() = 'om:OMS')) and @cd = 'units_time1' and matches(@name, 'calendar_month|calendar_year|day|hour|minute|second|week') ]">
    <!-- 
      easy symbol 
    -->
    <math:mi mathvariant='normal' class='MathML-Unit'>
      <xsl:apply-templates mode="units_time1_simple" select="."/>
    </math:mi>
  </xsl:template>

  <!--
    calendar_month, 28-31 days
  -->
  <xsl:template mode="units_time1_simple" match="* [ @name='calendar_month' ]">
    <xsl:text>maand</xsl:text>
  </xsl:template>

  <!--
    calendar_year, 365-366 days
  -->
  <xsl:template mode="units_time1_simple" match="* [ @name='calendar_year' ]">
    <xsl:text>jaar</xsl:text>
  </xsl:template>

  <!--
    day, 24 hours
  -->
  <xsl:template mode="units_time1_simple" match="* [ @name='day' ]">
    <xsl:text>dag</xsl:text>
  </xsl:template>

  <!--
    hour, 60 minutes
  -->
  <xsl:template mode="units_time1_simple" match="* [ @name='hour' ]">
    <xsl:text>uur</xsl:text>
  </xsl:template>

  <!--
    minute, 60 seconds
  -->
  <xsl:template mode="units_time1_simple" match="* [ @name='minute' ]">
    <xsl:text>minuut</xsl:text>
  </xsl:template>

  <!--
    second, unit of time
  -->
  <xsl:template mode="units_time1_simple" match="* [ @name='second' ]">
    <xsl:text>seconde</xsl:text>
  </xsl:template>

  <!--
    week, 7 days 
  -->
  <xsl:template mode="units_time1_simple" match="* [ @name='week' ]">
    <xsl:text>week</xsl:text>
  </xsl:template>

</xsl:stylesheet>
