<?xml version="1.0" encoding="us-ascii"?>
<xsl:stylesheet
  version="2.0"
  xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
>
   <!--
    parameter: short_complex1_complex_cartesian (boolean)
    if true then only nonzero parts of complex1.complex_cartesian will be
    displayed (or "0" if both parts are zero).
  -->
  <xsl:param name='short_complex1_complex_cartesian' select='true()' as='xs:boolean'/>

  <!--
    parameter: OMF_use_comma_separator
    if true then use a comma ',' instead of a period '.' while displaying
    decimal notation
  -->
  <xsl:param name='OMF_use_comma_separator' select='false()' as='xs:boolean'/>

  <!--
    parameter: OMF_OMI_use_thousand_separator
    if true then use a ',' (or '.') between all sets of 3 numbers.
    NOTE: for floats, only do this before the decimal mark
    NOTE: if the OMF_use_comma_seperator flag is a period is used (otherwise a comma)
  -->
  <xsl:param name='OMF_OMI_use_thousand_separator' select='false()' as='xs:boolean'/>

  <!--
    parameter: OMV_use_special_variables
    if true, enable special rules from openmath/omv_special.xml
  <xsl:param name='OMV_use_special' select='false()' as='xs:boolean'/>
  -->

  <!--
    use mathml3 entities
  -->

  <xsl:param name='openmath2mathml.mathml3_entities' select='false()'/>

  <!--
    parameter to configure display of fractions
    options:
    - mfrac : use math:mfrac (except for units)
    - slash : use an inline '/' operator (not in equation)
    - colon : use an inline ':' operator (not in equation)
  -->
  <xsl:param name='openmath2mathml.arith1.divide.style' select="'mfrac'"/>

  <!--
    parameter to configure display of powers of some transc1 functions
    - true : write sin(..)^(expr) as  sin^(expr) (...) if expr is an OMI not starting with -
    - false : just write sin(...)^(expr)
  -->
  <xsl:param name='openmath2mathml.arith1.power.prefix' select="true()"/>

  <!--
    parameter to configure display of the times symbol
    options:
    - dots: use (c)dots: expr*...*expr
    - pi: use a capital pi (default)
  -->
  <xsl:param name='openmath2mathml.arith1.product.style' select="'pi'"/>

  <!--
    parameter to configure display of the times symbol
    options:
    - cross: use a cross-like product (x-like symbol)
    - dot: use a dot (default)
    - star: use a star/asterisk
  -->
  <xsl:param name='openmath2mathml.arith1.times.style' select="'dot'"/>
  
  <!--
    parameter to configure display of the logic1.equivalent symbol
    options:
    - arrow: use a double left-right arrow (default)
    - lines: use three lines
  -->
  <xsl:param name='openmath2mathml.logic1.equivalent.style' select="'arrow'"/>

   <!--
    Interval1 parameters for brackets
    left side open/close
    right side open/close
  -->
  <xsl:param name='openmath2mathml.interval1.left.open' select="'('"/>
  <xsl:param name='openmath2mathml.interval1.left.close' select="'['"/>
  <xsl:param name='openmath2mathml.interval1.right.open' select="')'"/>
  <xsl:param name='openmath2mathml.interval1.right.close' select="']'"/>
  
  <xsl:param name='openmath2mathml.set3.big.boundvariable' select="false()"/>

  <!--
    parameter to configure display of binary logarithm function log(a,b)
    - prefix: ^a log(b)
    - postfix: log_a(b) (default)
  -->
  <xsl:param name='openmath2mathml.transc1.log.style' select="'postfix'"/>
</xsl:stylesheet>
