<?xml version="1.0" encoding="us-ascii"?>
<xsl:stylesheet
  version="2.0"
  xmlns:math="http://www.w3.org/1998/Math/MathML"
  xmlns:mdf="http://www.mathdox.org/MathDox/Functions"
  xmlns:om="http://www.openmath.org/OpenMath"
  xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
>
  <xsl:import href='openmath/functions.xsl'/>
  <xsl:import href='openmath/omv_greek.xsl'/>
  <xsl:import href='openmath/omv_special.xsl'/>
  <xsl:import href='openmath2mathml-params.xsl'/>
  <xsl:import href='openmath/plangeo.xsl'/>
  <xsl:import href='openmath/omv_bind_replace.xsl'/>
  <xsl:import href='openmath/units.xsl'/>
  <xsl:import href='openmath/linalg8.xsl'/>

  <xsl:include href='openmath/integer3.xsl'/>
  <!-- 
    TODO
    - interval (configurable open/close for open/close intervals)
    - plangeo2, 4
    - m4a private CD (?)
  -->

  <!-- *****************************************************************

       Common rendering

       ***************************************************************** -->

  <xsl:template match="om:OMATTR|OMATTR">
    <xsl:choose>
      <xsl:when test="@brackets='round'">
        <math:mfenced open="(" close=")" separators=",">
           <xsl:apply-templates select="*[1]"/>
        </math:mfenced>
      </xsl:when>
      <xsl:when test="@brackets='square'">
        <math:mfenced open="[" close="]" separators=",">
           <xsl:apply-templates select="*[1]"/>
        </math:mfenced>
      </xsl:when>
      <xsl:when test="@brackets='brace'">
        <math:mfenced open="{{" close="}}" separators=",">
           <xsl:apply-templates select="*[1]"/>
        </math:mfenced>
      </xsl:when>
      <xsl:when test="@brackets='none'">
        <math:mfenced open="" close="" separators=",">
           <xsl:apply-templates select="*[1]"/>
        </math:mfenced>
      </xsl:when>
      <xsl:when test="@brackets='angle'">
        <math:mfenced open="&#9001;" close="&#9002;" separators=",">
           <xsl:apply-templates select="*[1]"/>
        </math:mfenced>
      </xsl:when>
      <xsl:otherwise>
        <math:mfenced open="(" close=")" separators=",">
           <xsl:apply-templates select="*[1]"/>
        </math:mfenced>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="om:OMA|OMA" mode='#default generic'>
    <xsl:choose>
      <xsl:when test="@style='brackets'">
        <math:mrow>
           <math:mo>(</math:mo>
              <xsl:apply-templates select="*[2]"/>
            <math:mfenced open="" close="" separators="">
              <xsl:for-each select="*[position()&gt;2]">
                <xsl:apply-templates select="."/>
              </xsl:for-each>
            </math:mfenced>
           <math:mo>)</math:mo>
        </math:mrow>
      </xsl:when>
      <xsl:when test="@style='infix'">
        <xsl:variable name='infix'>
          <xsl:apply-templates select="*[1]"/>
        </xsl:variable>

        <math:mrow>
          <xsl:if test="*[2]">
            <xsl:apply-templates select="*[2]"/>
          </xsl:if>
          <xsl:for-each select="*[position()&gt;2]">
            <xsl:copy-of select="$infix/*"/>
            <xsl:apply-templates select="."/>
          </xsl:for-each>
        </math:mrow>
      </xsl:when>
      <xsl:when test="@style='right'">
        <math:mrow>
          <math:mfenced open="(" close=")" separators=",">
            <xsl:for-each select="*[position()&gt;1]">
              <xsl:apply-templates select="."/>
            </xsl:for-each>
          </math:mfenced>
          <math:mrow><xsl:apply-templates select="*[1]"/></math:mrow>
        </math:mrow>
      </xsl:when>
      <xsl:when test="@style='sub'">
        <math:mrow>
          <math:msub>
            <xsl:apply-templates select="*[1]"/>
            <math:mfenced open="" close="" separators=",">
              <xsl:for-each select="*[position()&gt;1]">
                <xsl:apply-templates select="."/>
              </xsl:for-each>
            </math:mfenced>
          </math:msub>
        </math:mrow>
      </xsl:when>
      <xsl:when test="@style='sup'">
        <math:mrow>
          <math:msup>
            <xsl:apply-templates select="*[1]"/>
            <math:mfenced open="" close="" separators=",">
              <xsl:for-each select="*[position()&gt;1]">
                <xsl:apply-templates select="."/>
              </xsl:for-each>
            </math:mfenced>
          </math:msup>
        </math:mrow>
      </xsl:when>
      <xsl:otherwise>
        <math:mrow>
          <math:mrow><xsl:apply-templates select="*[1]"/></math:mrow>
          <math:mfenced open="(" close=")" separators=",">
            <xsl:for-each select="*[position()&gt;1]">
              <xsl:apply-templates select="."/>
            </xsl:for-each>
          </math:mfenced>
        </math:mrow>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="om:OMBIND|OMBIND">
    <math:mrow>
      <xsl:for-each select="*">
        <xsl:apply-templates select="."/>
      </xsl:for-each>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMBVAR|OMBVAR">
    <math:mrow>
      <xsl:for-each select="*">
        <xsl:apply-templates select="."/>
        <xsl:if test="position() &lt; last()">,</xsl:if>
      </xsl:for-each>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OME|OME">
    <math:mrow>
      <math:mi><xsl:value-of select="*[1]/@cd"/>.
      <xsl:value-of select="*[1]/@name"/></math:mi>
      <math:mfenced open="(" close=")" separators=",">
        <xsl:for-each select="*[position()&gt;1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <!--
    OMF
    use a comma instead of a point
  -->
  <xsl:template match="om:OMF|OMF">
    <xsl:choose>
      <xsl:when test="$OMF_use_comma_separator and substring-after(@dec,'.')!= ''">
        <math:mn><xsl:value-of select="substring-before(@dec,'.')"/>,<xsl:value-of select="substring-after( @dec,'.')"/></math:mn>
      </xsl:when>
      <xsl:otherwise> 
        <math:mn><xsl:value-of select="@dec"/></math:mn>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="om:OMI|OMI">
    <math:mn><xsl:apply-templates/></math:mn>
  </xsl:template>

  <xsl:template match="om:OMOBJ|OMOBJ">
    <math:math xmlns="http://www.w3.org/1998/Math/MathML" mode="inline">
      <xsl:apply-templates/>
    </math:math>
  </xsl:template>

  <xsl:template match="om:OMS|OMS" mode='#default generic'>
    <math:mrow>
      <math:mi>
        <xsl:value-of select="@cd"/>.<xsl:value-of select="@name"/>
      </math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMSTR|OMSTR">
    <math:mtext><xsl:value-of select="."/></math:mtext>
  </xsl:template>

  <xsl:template match="om:OMV|OMV">
    <xsl:param name='omv_bind_replace' tunnel='yes' select='false()' as='xs:boolean'/>

    <xsl:choose>
      <xsl:when test="exists(index-of($omv_special_names,@name))">
        <xsl:apply-templates select='.' mode='omv_special'/>
      </xsl:when>
      <xsl:when test="exists(index-of($greek_letters, @name))">
        <xsl:apply-templates select='.' mode='omv_greek'/>
      </xsl:when>
      <xsl:when test='string-length(@name) &gt; 1 and 
        exists(index-of($omv_special_endings,substring(@name,string-length(@name))))'
      >
        <xsl:apply-templates select='.' mode='omv_special_ending'/>
      </xsl:when>
      <xsl:when test="$omv_bind_replace">
        <xsl:apply-templates select='.' mode='omv_bind_replace'/>
      </xsl:when>
      <xsl:when test="*">
        <math:mrow>
          <math:msub>
            <math:mi><xsl:value-of select="@name"/></math:mi>
            <math:mrow>
              <xsl:apply-templates/>
            </math:mrow>
          </math:msub>
        </math:mrow>
      </xsl:when>
      <xsl:otherwise>
        <math:mi>
          <xsl:value-of select="@name"/>
        </math:mi>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- *********************************************************************

       alg1

       ***************************************************************** -->

  <xsl:template match="om:OMS[@cd='alg1' and @name='zero']|OMS[@cd='alg1' and @name='zero']">
    <math:mrow>
      <math:mn>0</math:mn>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='alg1' and @name='one']|OMS[@cd='alg1' and @name='one']">
    <math:mrow>
      <math:mn>1</math:mn>
    </math:mrow>
  </xsl:template>

  <!-- *****************************************************************

       arith1

       ***************************************************************** -->

  <!-- arith1.abs -->
  <xsl:template match="om:OMA[om:OMS[@cd='arith1' and @name='abs']]|OMA[OMS[@cd='arith1' and @name='abs']]">
    <math:mrow>
      <math:mo>|</math:mo>
      <xsl:for-each select="*[position()&gt;1]">
        <xsl:apply-templates select="."/>
      </xsl:for-each>
      <math:mo>|</math:mo>
    </math:mrow>
  </xsl:template>

  <!--
    arith1.divide
    added styles colon/slash (default mfrac, meaning display style)
  -->
  <xsl:template match="om:OMS[@cd='arith1' and @name='divide']|OMS[@cd='arith1' and @name='divide']">
    <xsl:param name='oma_style' as='xs:string' select='"default"' tunnel='yes'/>

    <!-- use @style if present, otherwise use the style from the oma -->
    <xsl:variable name='tmpstyle'>
      <xsl:choose>
        <xsl:when test='@style'>
          <xsl:value-of select='@style'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select='$oma_style'/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name='style'>
      <xsl:choose>
        <xsl:when test='not(empty(index-of(("colon","div","mfrac","slash"),$tmpstyle)))'>
          <xsl:value-of select='$tmpstyle'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>default</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:choose>
      <xsl:when test="$style='colon' or ($style='default' and $openmath2mathml.arith1.divide.style = 'colon')">
        <math:mo>
          <!-- U+2236 ratio -->
          <xsl:text>&#x2236;</xsl:text>
        </math:mo> 
      </xsl:when>
      <xsl:when test="$style='div' or ($style='default' and $openmath2mathml.arith1.divide.style = 'div')">
        <math:mo>
          <!-- U+00F7 division sign-->
          <xsl:text>&#x00F7;</xsl:text>
        </math:mo> 
      </xsl:when>
      <xsl:when test="$style='slash' or ($style='default' and $openmath2mathml.arith1.divide.style = 'slash')">
        <math:mo>
          <!-- U+2215 division slash -->
          <xsl:text>&#x2215;</xsl:text>
        </math:mo>
      </xsl:when>
      <xsl:otherwise>
        <math:mo>
          <!-- U+2215 division slash -->
          <xsl:text>&#x2215;</xsl:text>
        </math:mo>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- arith1.divide -->
  <xsl:template match="om:OMA[om:OMS[@cd='arith1' and @name='divide']]|OMA[OMS[@cd='arith1' and @name='divide']]">
    <xsl:variable name='style'>
      <xsl:choose>
        <xsl:when test='@style'>
          <xsl:value-of select='@style'/>
        </xsl:when>
        <xsl:when test='OMS[@cd="arith1" and @name="divide"]/@style'>
          <xsl:value-of select='OMS[@cd="arith1" and @name="divide"]/@style'/>
        </xsl:when>
        <xsl:when test='om:OMS[@cd="arith1" and @name="divide"]/@style'>
          <xsl:value-of select='om:OMS[@cd="arith1" and @name="divide"]/@style'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>default</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name='operator'>
      <xsl:apply-templates select='*[1]'>
        <xsl:with-param name='oma_style' select='$style' as='xs:string' tunnel='yes'/>
      </xsl:apply-templates>
    </xsl:variable>

    <xsl:choose>
      <xsl:when test="$style='frac:big' or (($style='default') and $openmath2mathml.arith1.divide.style = 'mfrac')">
        <math:mfrac>
          <xsl:apply-templates select="*[2]"/>
          <xsl:apply-templates select="*[3]"/>
        </math:mfrac>
      </xsl:when>
      <xsl:when test="self::ancestor/equation and not(
          *[last() and local-name()='OMS' and starts-with(@cd,'units_')])"
      >
        <math:mfrac>
          <xsl:apply-templates select="*[2]"/>
          <xsl:apply-templates select="*[3]"/>
        </math:mfrac>
      </xsl:when>
      <xsl:when test="$style='brackets'">
        <math:mrow>
          <math:mo>(</math:mo>
          <xsl:apply-templates select="*[2]"/>
          <xsl:copy-of select='$operator'/>
          <xsl:apply-templates select="*[3]"/>
          <math:mo>)</math:mo>
        </math:mrow>
      </xsl:when>
      <xsl:when test="$style='nobrackets' or 
          *[last() and local-name()='OMS' and starts-with(@cd,'units_')]"
      >
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
          <xsl:copy-of select='$operator'/>
          <xsl:apply-templates select="*[3]"/>
        </math:mrow>
      </xsl:when>
      <xsl:when test="not(empty(index-of(('colon','div','slash'),$style))) 
        or (($style='default') and not(empty(index-of(('colon','div','slash'), $openmath2mathml.arith1.divide.style ))))">
        <math:mrow>
          <xsl:choose>
            <xsl:when test="*[2]/self::om:OMA[om:OMS[@name='plus']]| *[2]/self::om:OMA[om:OMS[@name='minus']]|*[2]/self::OMA[OMS[@name='plus']]| *[2]/self::OMA[OMS[@name='minus']]">
              <math:mo>(</math:mo>
              <xsl:apply-templates select="*[2]"/>
              <math:mo>)</math:mo>
            </xsl:when>
            <xsl:otherwise>
              <xsl:apply-templates select="*[2]"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:copy-of select='$operator'/>
          <xsl:choose>
            <xsl:when test="*[3]/self::om:OMA[om:OMS[@name='plus']] | *[3]/self::om:OMA[om:OMS[@name='times']] | *[3]/self::om:OMA[om:OMS[@name='minus']] | *[3]/self::om:OMA[om:OMS[@name='divide']] | *[3]/self::OMA[OMS[@name='complex_cartesian']] | *[3]/self::OMA[OMS[@name='plus']] | *[3]/self::OMA[OMS[@name='times']] | *[3]/self::OMA[OMS[@name='minus']] | *[3]/self::OMA[OMS[@name='divide']]| *[3]/self::OMA[OMS[@name='complex_cartesian']]">
              <math:mo>(</math:mo>
              <xsl:apply-templates select="*[3]"/>
              <math:mo>)</math:mo>
            </xsl:when>
            <xsl:otherwise>
              <xsl:apply-templates select="*[3]"/>
            </xsl:otherwise>
          </xsl:choose>
        </math:mrow>
      </xsl:when>
      <xsl:otherwise>
         <math:mfrac>
          <xsl:apply-templates select="*[2]"/>
          <xsl:apply-templates select="*[3]"/>
        </math:mfrac>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- arith1.gcd -->
  <xsl:template match="om:OMS[@name='gcd' and @cd='arith1']|OMS[@name='gcd' and @cd='arith1']">
    <math:mi>gcd</math:mi>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='gcd' and @cd='arith1']]|OMA[OMS[@name='gcd' and @cd='arith1']]">
    <math:mrow>
      <!-- first the symbol -->
      <xsl:apply-templates select='*[1]'/>
      <math:mfenced open="(" close=")" separators=",">
        <xsl:for-each select="*[position() &gt; 1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <!-- arith1.lcm -->
  <xsl:template match="om:OMS[@name='lcm' and @cd='arith1']|OMS[@name='lcm' and @cd='arith1']">
    <math:mi>lcm</math:mi>
  </xsl:template>

  <!-- arith1.lcm -->
  <xsl:template match="om:OMA[om:OMS[@name='lcm' and @cd='arith1']]|OMA[OMS[@name='lcm' and @cd='arith1']]">
    <math:mrow>
      <!-- first the symbol -->
      <xsl:apply-templates select='*[1]'/>
      <math:mfenced open="(" close=")" separators=",">
        <xsl:for-each select="*[position() &gt; 1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <!-- arith1.minus -->
  <xsl:template match="om:OMS[@cd='arith1' and @name='minus'] | OMS[@cd='arith1' and @name='minus']">
    <math:mo>
      <!-- 2212 minus sign -->
      <xsl:text>&#x2212;</xsl:text>
    </math:mo>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='arith1' and @name='minus']]|OMA[OMS[@cd='arith1' and @name='minus']]">
    <xsl:variable name='operator'>
      <xsl:apply-templates select='*[1]'/>
    </xsl:variable>
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <xsl:for-each select="*[3]">
        <xsl:choose>
          <xsl:when test="self::om:OMA[om:OMS[@name='unary_minus']]|self::OMA[OMS[@name='unary_minus']]">
            <xsl:copy-of select='$operator'/>
            <math:mrow>
              <math:mo>(</math:mo>
              <xsl:apply-templates select="."/>
              <math:mo>)</math:mo>
            </math:mrow>
          </xsl:when>
          <xsl:when test="self::om:OMA[om:OMS[@name='plus']]|self::OMA[OMS[@name='plus']]">
            <xsl:variable name='style'>
              <xsl:choose>
                <xsl:when test='@style'>
                  <xsl:value-of select='@style'/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>default</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:variable>
            <xsl:copy-of select='$operator'/>
            <xsl:if test='$style != "invisible"'>
              <math:mo>(</math:mo>
            </xsl:if>
            <xsl:apply-templates select="."/>
            <xsl:if test='$style != "invisible"'>
              <math:mo>)</math:mo>
            </xsl:if>
          </xsl:when>
          <xsl:when test="self::om:OMA[om:OMS[@name='minus']]|self::OMA[OMS[@name='minus']]">
            <xsl:copy-of select='$operator'/>
            <math:mo>(</math:mo>
            <xsl:apply-templates select="."/>
            <math:mo>)</math:mo>
          </xsl:when>
           <xsl:otherwise>
            <xsl:copy-of select='$operator'/>
            <xsl:apply-templates select="."/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:for-each>
    </math:mrow>
  </xsl:template>

  <!-- arith1.plus -->
  <xsl:template match="om:OMS[@cd='arith1' and @name='plus']|OMS[@cd='arith1' and @name='plus']">
    <xsl:param name='oma_style' as='xs:string' select='"default"' tunnel='yes'/>

    <!-- use @style if present, otherwise use the style from the oma -->
    <xsl:variable name='tmpstyle'>
      <xsl:choose>
        <xsl:when test='@style'>
          <xsl:value-of select='@style'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select='$oma_style'/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name='style'>
      <xsl:choose>
        <xsl:when test='not(empty(index-of(("invisible"),$tmpstyle)))'>
          <xsl:value-of select='$tmpstyle'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>default</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:choose>
      <!-- 
        do not show if the style is invisible, do not allow default invisible
        style 
      -->
      <xsl:when test="$style='invisible'">
        <math:mo>
          <!-- U+2064 invisible plus -->
          <xsl:text>&#x2064;</xsl:text>
        </math:mo>
      </xsl:when>
      <xsl:otherwise>
        <math:mo>
          <xsl:text>+</xsl:text>
        </math:mo>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  <!-- arith1.plus -->
  <xsl:template match="om:OMA[om:OMS[@cd='arith1' and @name='plus']]|OMA[OMS[@cd='arith1' and @name='plus']]">
    <xsl:param name='oma_style' as='xs:string' select='"default"' tunnel='yes'/>

    <xsl:variable name='style'>
      <xsl:choose>
        <xsl:when test='@style'>
          <xsl:value-of select='@style'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>default</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name='operator'>
      <xsl:apply-templates select='*[1]'>
        <xsl:with-param name='oma_style' select='$style' as='xs:string' tunnel='yes'/>
      </xsl:apply-templates>
    </xsl:variable>
    <math:mrow>
      <xsl:choose>
        <xsl:when test="@style='brackets'">
          <math:mrow>
            <math:mo>(</math:mo>
            <xsl:for-each select="*[2]">
              <xsl:choose>
                <xsl:when test="self::om:OMA|self::OMA">
                  <math:mo>(</math:mo>
                  <xsl:apply-templates select="."/>
                  <math:mo>)</math:mo>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="."/>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:for-each>
            <xsl:for-each select="*[position()&gt;2]">
              <xsl:copy-of select='$operator'/>
              <xsl:choose>
                <xsl:when test="self::om:OMA|self::OMA">
                  <math:mo>(</math:mo>
                  <xsl:apply-templates select="."/>
                  <math:mo>)</math:mo>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="."/>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:for-each>
            <math:mo>)</math:mo>
          </math:mrow>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates select="*[2]"/>
          <xsl:for-each select="*[position()&gt;2]">
            <xsl:copy-of select='$operator'/>

            <xsl:variable name='substyle'>
              <xsl:choose>
                <xsl:when test='@style'>
                  <xsl:value-of select='@style'/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>default</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:variable>

            <xsl:choose>
              <xsl:when test="self::om:OMA[om:OMS[@name='unary_minus']]|self::OMA[OMS[@name='unary_minus']]">
                <math:mo>(</math:mo>
                <xsl:apply-templates select="."/>
                <math:mo>)</math:mo>
              </xsl:when>
              <xsl:when test="self::om:OMA[om:OMS[@name='plus']]|self::OMA[OMS[@name='plus']] and $substyle != 'invisible' ">
                <math:mo>(</math:mo>
                <xsl:apply-templates select="."/>
                <math:mo>)</math:mo>
              </xsl:when>
              <xsl:otherwise>
                <xsl:apply-templates select="."/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:for-each>
        </xsl:otherwise>
      </xsl:choose>
    </math:mrow>
  </xsl:template>

  <!-- arith1.product -->
  <xsl:template match="om:OMA[om:OMS[@cd='arith1' and @name='product']]|OMA[OMS[@cd='arith1' and @name='product']]">
    <xsl:param name='oma_style' as='xs:string' select='"default"' tunnel='yes'/>

    <!-- use @style if present, otherwise use the style from the oma -->
    <xsl:variable name='tmpstyle' as='xs:string'>
      <xsl:choose>
        <xsl:when test='om:OMS[@style]'>
          <xsl:value-of select='om:OMS/@style'/>
        </xsl:when>
        <xsl:when test='OMS[@style]'>
          <xsl:value-of select='OMS/@style'/>
        </xsl:when>
        <xsl:when test='@style'>
          <xsl:value-of select='@style'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select='$oma_style'/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name='style'>
      <xsl:choose>
        <xsl:when test='not(empty(index-of(("dots"),$tmpstyle)))'>
          <xsl:value-of select='$tmpstyle'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>default</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:choose>
      <xsl:when test='$style = "dots"'>
        <xsl:variable name='usenamespace' as='xs:boolean' select='boolean(self::om:OMA)'/>
        <xsl:variable name='dotexpr' as='node()'>
          <xsl:choose>
            <xsl:when test='$usenamespace'> 
              <om:OMA>
                <om:OMS cd='arith1' name='times'/>
                <xsl:apply-templates select='om:OMBIND/*[3]'>
                  <xsl:with-param name='ombind' select='om:OMBIND' as='node()' tunnel='yes'/>
                  <xsl:with-param name='omv_bind_replace' select='true()' as='xs:boolean' tunnel='yes'/>
                  <xsl:with-param name='expr' as='node()' tunnel='yes'>
                    <wrapper>
                      <xsl:copy-of select="om:OMA/*[2]"/>
                    </wrapper>
                  </xsl:with-param>
                </xsl:apply-templates>
                <om:OMV name='cdots'/>
                <xsl:apply-templates select='om:OMBIND/*[3]'>
                  <xsl:with-param name='ombind' select='om:OMBIND' as='node()' tunnel='yes'/>
                  <xsl:with-param name='omv_bind_replace' select='true()' as='xs:boolean' tunnel='yes'/>
                  <xsl:with-param name='expr' as='node()' tunnel='yes'>
                    <wrapper>
                      <xsl:copy-of select="om:OMA/*[3]"/>
                    </wrapper>
                  </xsl:with-param>
                </xsl:apply-templates>
               </om:OMA>
            </xsl:when>
            <xsl:otherwise>
              <OMA>
                <OMS cd='arith1' name='times'/>
                <xsl:apply-templates select='OMBIND/*[3]'>
                  <xsl:with-param name='ombind' select='OMBIND' as='node()' tunnel='yes'/>
                  <xsl:with-param name='omv_bind_replace' select='true()' as='xs:boolean' tunnel='yes'/>
                  <xsl:with-param name='expr' as='node()' tunnel='yes'>
                    <wrapper>
                      <xsl:copy-of select="OMA/*[2]"/>
                    </wrapper>
                  </xsl:with-param>
                </xsl:apply-templates>
                <OMV name='cdots'/>
                <xsl:apply-templates select='OMBIND/*[3]'>
                  <xsl:with-param name='ombind' select='OMBIND' as='node()' tunnel='yes'/>
                  <xsl:with-param name='omv_bind_replace' select='true()' as='xs:boolean' tunnel='yes'/>
                  <xsl:with-param name='expr' as='node()' tunnel='yes'>
                    <wrapper>
                      <xsl:copy-of select="OMA/*[3]"/>
                    </wrapper>
                  </xsl:with-param>
                </xsl:apply-templates>
               </OMA>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
        <!--<xsl:message>dotexpr: <xsl:copy-of select='$dotexpr'/></xsl:message>-->
        <xsl:apply-templates select='$dotexpr'/>
      </xsl:when>
      <xsl:otherwise>
        <math:mrow>
          <xsl:choose>
            <xsl:when test="*[3]/self::om:OMBIND/*[1][self::om:OMS[@name='lambda']]|*[3]/self::OMBIND/*[1][self::OMS[@name='lambda']]">
              <xsl:variable name='use_brackets' as='xs:string'>
                <xsl:choose>
                  <!-- no brackets around variables -->
                  <xsl:when test='*[3]/*[3]/self::om:OMV | *[3]/*[3]/self::OMV'>
                    <xsl:text>false</xsl:text>
                  </xsl:when>
                  <!-- no brackets around applications of variables -->
                  <xsl:when test='*[3]/*[3]/self::om:OMA/*[1]/self::om:OMV | *[3]/*[3]/self::OMA/*[1]/self::OMV'>
                    <xsl:text>false</xsl:text>
                  </xsl:when>
                  <xsl:when test='*[3]/*[3]/self::om:OMA/*[1]/self::om:OMS[@cd="arith1" and @name="power"] | 
                    *[3]/*[3]/self::OMA/*[1]/self::OMS[@cd="arith1" and @name="power"]'
                  >
                  <xsl:text>false</xsl:text>
                </xsl:when>
                  <xsl:otherwise>
                    <xsl:text>true</xsl:text>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:variable>
              <xsl:choose>
                <xsl:when test="*[2]/self::om:OMA/*[1][self::om:OMS[@name='integer_interval']]|*[2]/self::OMA/*[1][self::OMS[@name='integer_interval']]">
                  <math:munderover>
                    <!-- U+220F n-ary product -->
                    <math:mo>&#x220F;</math:mo>
                    <math:mrow>
                      <xsl:apply-templates select="om:OMBIND/om:OMBVAR|OMBIND/OMBVAR"/>
                      <math:mo>=</math:mo>
                      <xsl:apply-templates select="om:OMA/*[2]|OMA/*[2]"/>
                    </math:mrow>
                    <xsl:apply-templates select="om:OMA/*[3]|OMA/*[3]"/>
                  </math:munderover>
                </xsl:when>
                <xsl:otherwise>
                  <math:munder>
                    <!-- U+220F N-ary product -->
                    <math:mo>&#x220F;</math:mo>
                    <math:mrow>
                      <xsl:apply-templates select="om:OMBIND/om:OMBVAR|OMBIND/OMBVAR"/>
                      <math:mo>&#x2208;</math:mo>
                      <!-- U+2208 element of -->
                      <xsl:apply-templates select="*[2]"/>
                    </math:mrow>
                  </math:munder>
                </xsl:otherwise>
              </xsl:choose>
              <xsl:if test='$use_brackets="true"'>
                <math:mo>(</math:mo>
              </xsl:if>
              <xsl:apply-templates select="om:OMBIND/*[3]|OMBIND/*[3]"/>
              <xsl:if test='$use_brackets="true"'>
                <math:mo>)</math:mo>
              </xsl:if>
            </xsl:when>
            <xsl:otherwise>
              <xsl:choose>
                <xsl:when test="*[2]/self::om:OMA/*[1][self::om:OMS[@name='integer_interval']]|*[2]/self::OMA/*[1][self::OMS[@name='integer_interval']]">
                  <math:munderover>
                    <math:mo>&#x220F;</math:mo>
                    <!-- U+220F N-ary product -->
                    <xsl:apply-templates select="om:OMA/*[2]|OMA/*[2]"/>
                    <xsl:apply-templates select="om:OMA/*[3]|OMA/*[3]"/>
                  </math:munderover>
                </xsl:when>
                <xsl:otherwise>
                  <math:msub>
                    <math:mo>&#x220F;</math:mo>
                    <!-- U+220F N-ary product -->
                    <xsl:apply-templates select="*[1]"/>
                  </math:msub>
                </xsl:otherwise>
              </xsl:choose>
              <xsl:apply-templates select="*[2]"/>
            </xsl:otherwise>
          </xsl:choose>
        </math:mrow>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- arith1.power -->
  <xsl:template match="om:OMA[om:OMS[@cd='arith1' and @name='power']]|OMA[OMS[@cd='arith1' and @name='power']]">
    <xsl:variable name='testnode' select='.'/>

    <xsl:choose>
      <xsl:when test='mdf:nodetest_transc1_power(.)'>
        <math:mrow>
          <math:msup>
            <math:mrow>
              <xsl:apply-templates select="*[2]/*[1]"/>
            </math:mrow>
            <math:mrow>
              <xsl:apply-templates select="*[3]"/>
            </math:mrow>
          </math:msup>
          <math:mo>(</math:mo>
          <xsl:apply-templates select="*[2]/*[2]"/>
          <math:mo>)</math:mo>
        </math:mrow>
      </xsl:when>
      <xsl:otherwise>
        <math:msup>
          <math:mrow>
            <xsl:choose>
              <xsl:when test="*[2]/self::om:OMA|*[2]/self::OMA">
                <math:mo>(</math:mo>
                <xsl:apply-templates select="*[2]"/>
                <math:mo>)</math:mo>
              </xsl:when>
              <xsl:when test="*[2][(self::om:OMI or self::OMI) and starts-with(string(.),'-')]">
                <math:mo>(</math:mo>
                <xsl:apply-templates select="*[2]"/>
                <math:mo>)</math:mo>
              </xsl:when>
              <xsl:otherwise>
                <xsl:apply-templates select="*[2]"/>
              </xsl:otherwise>
            </xsl:choose>
          </math:mrow>
          <math:mrow>
            <xsl:apply-templates select="*[3]"/>
          </math:mrow>
        </math:msup>
       </xsl:otherwise>
    </xsl:choose>
 </xsl:template>

  <!--
    arith1.root
    in cases where the root is an integer use math:mroot.
  -->
  <xsl:template match="om:OMA[om:OMS[@cd='arith1' and @name='root']]|OMA[OMS[@cd='arith1' and @name='root']]">
    <xsl:choose>
      <xsl:when test="*[3]/self::om:OMI[normalize-space(.)='2']|*[3]/self::OMI[normalize-space(.)= '2']">
        <math:msqrt>
          <xsl:apply-templates select="*[2]"/>
        </math:msqrt>
      </xsl:when>
      <xsl:otherwise>
        <math:mroot>
          <math:mrow>
            <xsl:apply-templates select="*[2]"/>
          </math:mrow>
          <xsl:apply-templates select="*[3]"/>
        </math:mroot>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- arith1.sum -->
  <xsl:template match="om:OMA[om:OMS[@cd='arith1' and @name='sum']]|OMA[OMS[@cd='arith1' and @name='sum']]">
    <math:mrow>
      <xsl:choose>
        <xsl:when test="*[3]/self::om:OMBIND/*[1][self::om:OMS[@name='lambda']]|*[3]/self::OMBIND/*[1][self::OMS[@name='lambda']]">
          <xsl:variable name='use_brackets' as='xs:string'>
            <xsl:choose>
              <!-- no brackets around variables -->
              <xsl:when test='*[3]/*[3]/self::om:OMV | *[3]/*[3]/self::OMV'>
                <xsl:text>false</xsl:text>
              </xsl:when>
              <!-- no brackets around applications of variables -->
              <xsl:when test='*[3]/*[3]/self::om:OMA/*[1]/self::om:OMV | *[3]/*[3]/self::OMA/*[1]/self::OMV'>
                <xsl:text>false</xsl:text>
              </xsl:when>
              <xsl:when test='*[3]/*[3]/self::om:OMA/*[1]/self::om:OMS[@cd="arith1" and @name="times"] | 
                *[3]/*[3]/self::OMA/*[1]/self::OMS[@cd="arith1" and @name="times"]'
              >
                <xsl:text>false</xsl:text>
              </xsl:when>
              <xsl:when test='*[3]/*[3]/self::om:OMA/*[1]/self::om:OMS[@cd="arith1" and @name="power"] | 
                *[3]/*[3]/self::OMA/*[1]/self::OMS[@cd="arith1" and @name="power"]'
              >
                <xsl:text>false</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>true</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:variable>
          <xsl:choose>
            <xsl:when test="*[2]/self::om:OMA/*[1][self::om:OMS[@name='integer_interval']]|*[2]/self::OMA/*[1][self::OMS[@name='integer_interval']]">
              <math:munderover>
                <math:mo>
                  <xsl:text>&#x2211;</xsl:text>
                </math:mo>
                <!-- U+2211 N-ary summation -->
                <math:mrow>
                  <xsl:apply-templates select="om:OMBIND/om:OMBVAR|OMBIND/OMBVAR"/>
                  <math:mo>
                    <xsl:text>=</xsl:text>
                  </math:mo>
                  <xsl:apply-templates select="om:OMA/*[2]|OMA/*[2]"/>
                </math:mrow>
                <xsl:apply-templates select="om:OMA/*[3]|OMA/*[3]"/>
              </math:munderover>
            </xsl:when>
            <xsl:otherwise>
              <math:munder>
                <math:mo>
                  <xsl:text>&#x2211;</xsl:text>
                  <!-- U+2211 N-ary summation -->
                </math:mo>
                <math:mrow>
                  <xsl:apply-templates select="om:OMBIND/om:OMBVAR|OMBIND/OMBVAR"/>
                    <math:mo>
                      <xsl:text>&#x2208;</xsl:text>
                      <!-- U+2208 Element of -->
                    </math:mo>
                  <xsl:apply-templates select="*[2]"/>
                </math:mrow>
              </math:munder>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:if test="$use_brackets='true'">
            <math:mo>(</math:mo>
          </xsl:if>
          <xsl:apply-templates select="om:OMBIND/*[3]|OMBIND/*[3]"/>
          <xsl:if test="$use_brackets='true'">
            <math:mo>)</math:mo>
          </xsl:if>
        </xsl:when>
        <xsl:otherwise>
          <xsl:choose>
            <xsl:when test="*[2]/self::om:OMA/*[1][self::om:OMS[@name='integer_interval']]|*[2]/self::OMA/*[1][self::OMS[@name='integer_interval']]">
              <math:munderover>
                <math:mo>&#8721;</math:mo>
                <xsl:apply-templates select="om:OMA/*[2]|OMA/*[2]"/>
                <xsl:apply-templates select="om:OMA/*[3]|OMA/*[3]"/>
              </math:munderover>
            </xsl:when>
            <xsl:otherwise>
              <math:msub>
                <math:mo>&#8721;</math:mo>
                <xsl:apply-templates select="*[1]"/>
              </math:msub>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:apply-templates select="*[2]"/>
        </xsl:otherwise>
      </xsl:choose>
    </math:mrow>
  </xsl:template>

  <!--
    arith1.times
    added styles cross/dot/star (default star)
  -->
  <xsl:template match="om:OMS[@cd='arith1' and @name='times']|OMS[@cd='arith1' and @name='times']">
    <xsl:param name='oma_style' as='xs:string' select='"default"' tunnel='yes'/>

    <!-- use @style if present, otherwise use the style from the oma -->
    <xsl:variable name='tmpstyle'>
      <xsl:choose>
        <xsl:when test='@style'>
          <xsl:value-of select='@style'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select='$oma_style'/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name='style'>
      <xsl:choose>
        <xsl:when test='not(empty(index-of(("cross","dot","star","invisible"),$tmpstyle)))'>
          <xsl:value-of select='$tmpstyle'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>default</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:choose>
      <xsl:when test="$style='cross' or ($style='default' and $openmath2mathml.arith1.times.style = 'cross')">
        <math:mo>
          <!-- U+00D7 is cross -->
          <xsl:text>&#x00D7;</xsl:text>
        </math:mo> 
      </xsl:when>
      <xsl:when test="$style='dot' or ($style='default' and $openmath2mathml.arith1.times.style = 'dot')">
        <math:mo>
          <!-- U+00B7 Middle dot -->
          <xsl:text>&#x00B7;</xsl:text>
        </math:mo> 
      </xsl:when>
      <xsl:when test="$style='star' or ($style='default' and $openmath2mathml.arith1.times.style = 'star')">
        <math:mo>
          <!-- U+2217 asterisk operator -->
          <xsl:text>&#x2217;</xsl:text>
        </math:mo>
      </xsl:when>
      <!-- 
        do not show if the style is invisible, do not allow default invisible
        style 
      -->
      <xsl:when test="$style='invisible'">
        <math:mo>
          <!-- U+2062 invisible times -->
          <xsl:text>&#x2062;</xsl:text>
        </math:mo>
      </xsl:when>
      <xsl:otherwise>
        <math:mo>
          <!-- U+00B7 Middle dot -->
          <xsl:text>&#x00B7;</xsl:text>
        </math:mo>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- arith1.times -->
  <xsl:template match="om:OMA[om:OMS[@cd='arith1' and @name='times']]|OMA[OMS[@cd='arith1' and @name='times']]">
    <xsl:variable name='style'>
      <xsl:choose>
        <xsl:when test='@style'>
          <xsl:value-of select='@style'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>default</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name='operator'>
      <xsl:apply-templates select='*[1]'>
        <xsl:with-param name='oma_style' select='$style' as='xs:string' tunnel='yes'/>
      </xsl:apply-templates>
    </xsl:variable>
   
    <math:mrow>
      <xsl:if test="@style='brackets'">
        <math:mo>(</math:mo>
      </xsl:if>
      <xsl:for-each select="*[2]">
        <xsl:choose>
          <xsl:when test="OMS[last() and starts-with(@cd,'units_')] or
            om:OMS[last() and starts-with(@cd,'units_')]"
          >
            <xsl:if test="@style='brackets'">
              <xsl:text>(</xsl:text>
            </xsl:if>
            <xsl:apply-templates select="*[2]"/>
            <xsl:for-each select="*[ position() &gt; 2 ]">
              <xsl:choose>
                <xsl:when test="last()">
                  <math:mo rspace='thickmathspace'>
                    <mchar name="InvisibleTimes"/>
                  </math:mo>
                  <xsl:apply-templates select="."/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:copy-of select="$operator"/>
                  <xsl:apply-templates select="."/>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:for-each>
            <xsl:if test="@style='brackets'">
              <xsl:text>)</xsl:text>
            </xsl:if>
          </xsl:when>
          <xsl:when test="(self::om:OMA[om:OMS[@name='unary_minus']]|self::OMA[OMS[@name='unary_minus']])">
            <math:mo>(</math:mo>
            <xsl:apply-templates select="."/>
            <math:mo>)</math:mo>
          </xsl:when>
          <xsl:when test="(self::om:OMI[starts-with(.,'-')]|self::OMI[starts-with(.,'-')])">
            <math:mo>(</math:mo>
            <xsl:apply-templates select="."/>
            <math:mo>)</math:mo>
          </xsl:when>
          <xsl:when test="(self::om:OMA[@style='invisible' and om:OMS[@name='plus']] or self::OMA[@style='invisible' and OMS[@name='plus']])">
            <xsl:apply-templates select="."/>
          </xsl:when>
          <xsl:when test="(self::om:OMA[om:OMS[@name='plus']] or self::om:OMA[om:OMS[@name='minus']]|self::OMA[OMS[@name='plus']] or self::OMA[OMS[@name='minus']])">
            <math:mo>(</math:mo>
            <xsl:apply-templates select="."/>
            <math:mo>)</math:mo>
          </xsl:when>
          <xsl:when test="(self::om:OMA[om:OMS[@cd='complex1' and @name='complex_cartesian']] or self::OMA[OMS[@cd='complex1' and @name='complex_cartesian']])">
            <math:mo>(</math:mo>
            <xsl:apply-templates select="."/>
            <math:mo>)</math:mo>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="."/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:for-each>
      <xsl:for-each select="*[position()&gt;2]">
        <xsl:copy-of select="$operator"/>
        <xsl:choose>
          <xsl:when test="(self::om:OMA[om:OMS[@name='unary_minus']]|self::OMA[OMS[@name='unary_minus']])">
            <math:mo>(</math:mo>
            <xsl:apply-templates select="."/>
            <math:mo>)</math:mo>
          </xsl:when>
          <xsl:when test="(self::om:OMI[starts-with(.,'-')]|self::OMI[starts-with(.,'-')])">
            <math:mo>(</math:mo>
            <xsl:apply-templates select="."/>
            <math:mo>)</math:mo>
          </xsl:when>
          <xsl:when test="(self::om:OMA[@style='invisible' and om:OMS[@name='plus']] or self::OMA[@style='invisible' and OMS[@name='plus']])">
            <xsl:apply-templates select="."/>
          </xsl:when>
          <xsl:when test="(self::om:OMA[om:OMS[@name='plus']] or self::om:OMA[om:OMS[@name='minus']]|self::OMA[OMS[@name='plus']] or self::OMA[OMS[@name='minus']])">
            <math:mo>(</math:mo>
            <xsl:apply-templates select="."/>
            <math:mo>)</math:mo>
          </xsl:when>
          <xsl:when test="(self::om:OMA[om:OMS[@cd='complex1' and @name='complex_cartesian']] or self::OMA[OMS[@cd='complex1' and @name='complex_cartesian']])">
            <math:mo>(</math:mo>
            <xsl:apply-templates select="."/>
            <math:mo>)</math:mo>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="."/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:for-each>
      <xsl:if test="@style='brackets'">
        <math:mo>)</math:mo>
      </xsl:if>
    </math:mrow>
  </xsl:template>
 
  <!-- arith1.unary_minus -->
  <xsl:template match="om:OMS[@cd='arith1' and @name='unary_minus'] | OMS[@cd='arith1' and @name='unary_minus']">
    <math:mo>
      <!-- 2212 minus sign -->
      <xsl:text>&#x2212;</xsl:text>
    </math:mo>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='arith1' and @name='unary_minus']]|OMA[OMS[@cd='arith1' and @name='unary_minus']]">
    <xsl:variable name="operator">
      <xsl:apply-templates select="*[1]"/>
    </xsl:variable>

    <xsl:for-each select="*[2]">
      <xsl:variable name="argument">
        <xsl:apply-templates select='.'/>
      </xsl:variable>

      <xsl:choose>
        <xsl:when test="self::om:OMA[om:OMS[@cd='arith1' and @name='times']] or 
          self::OMA[OMS[@cd='arith1' and @name='times']]"
        >
          <math:mrow>
            <xsl:copy-of select="$operator"/>
            <xsl:copy-of select="$argument"/>
          </math:mrow>
        </xsl:when>
        <xsl:when test="self::om:OMA[@style='invisible' and om:OMS[@cd='arith1' and @name='plus']] or 
          self::OMA[@style='invisible' and OMS[@cd='arith1' and @name='times']]"
        >
          <math:mrow>
            <xsl:copy-of select="$operator"/>
            <xsl:copy-of select="$argument"/>
          </math:mrow>
        </xsl:when>
        <!-- 
          no brackets around mfrac, 
          i.e. usually arith1.divide, nums1.rational, or calculus1.diff variants
        -->
        <xsl:when test="$argument/*[1][self::math:mfrac]">
          <math:mrow>
            <xsl:copy-of select="$operator"/>
            <xsl:copy-of select="$argument"/>
          </math:mrow>
        </xsl:when>
        <xsl:when test="self::om:OMA|self::OMA">
          <math:mrow>
            <xsl:copy-of select="$operator"/>
            <math:mo>(</math:mo>
            <xsl:copy-of select="$argument"/>
            <math:mo>)</math:mo>
          </math:mrow>
        </xsl:when>
        <xsl:otherwise>
          <math:mrow>
            <xsl:copy-of select="$operator"/>
            <xsl:copy-of select="$argument"/>
          </math:mrow>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>
  </xsl:template>

  <!-- ********************************************************************

       arith2

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='arith2' and @name='inverse']]|OMA[OMS[@cd='arith2' and @name='inverse']]">
    <math:msup>
      <math:mrow>
        <xsl:choose>
          <xsl:when test="om:OMA|OMA">
               <math:mo>(</math:mo>
            <xsl:apply-templates select="*[2]"/>
            <math:mo>)</math:mo>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="*[2]"/>
          </xsl:otherwise>
        </xsl:choose>
      </math:mrow>
      <math:mrow>
        -1
      </math:mrow>
    </math:msup>
  </xsl:template>

  <!-- ********************************************************************

       arith3

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@name='extended_gcd' and @cd='arith3']]|OMA[OMS[@name='extended_gcd' and @cd='arith3']]">
    <math:mrow>
      <math:mi>
        <xsl:text>extended-gcd</xsl:text>
      </math:mi>
      <math:mfenced open="(" close=")" separators=",">
        <xsl:for-each select="*[position()&gt;1]">
          <math:mrow>
            <xsl:apply-templates select="."/>
          </math:mrow>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       bigfloat1

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@name='bigfloat' and @cd='bigfloat1']]|OMA[OMS[@name='bigfloat' and @cd='bigfloat1']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>&#8901;</math:mo>
      <math:msup>
        <xsl:apply-templates select="*[3]"/>
        <xsl:apply-templates select="*[4]"/>
      </math:msup>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='bigfloatprec' and @cd='bigfloat1']]|OMA[OMS[@name='bigfloatprec' and @cd='bigfloat1']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>&#8901;</math:mo>
      <math:msup>
        <xsl:apply-templates select="*[3]"/>
        <xsl:apply-templates select="*[4]"/>
      </math:msup>
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       calculus1 (partially implemented)

       implemented: defint, diff, int, partialdiff
       not implemented: nthdiff, partialdiffdegree
       version: 5

       ******************************************************************** -->

  <!--
    transform an integral with interval
  -->
  <xsl:template match='om:OMA[om:OMS[@cd="calculus1" and @name="defint"] ] |
    OMA[OMS[@cd="calculus1" and @name="defint" ]]'>
    <math:mrow>
      <math:munderover>
        <math:mo>
          <!-- U+222B integral -->
          <xsl:text>&#x222B;</xsl:text>
        </math:mo>
        <xsl:apply-templates select="*[2]/*[2]"/>
        <xsl:apply-templates select="*[2]/*[3]"/>
      </math:munderover>
      <xsl:apply-templates select="*[3]/*[3]"/>
      <math:mo>
        <!-- U+2146 double-struck italic small d &DifferentialD; -->
        <xsl:text>&#x2146;</xsl:text>
      </math:mo>
      <xsl:apply-templates select="*[3]/OMBVAR | *[3]/om:OMBVAR"/>
    </math:mrow>
  </xsl:template>

  <!-- calculus1.diff applied on a variable -->
  <xsl:template match='
    om:OMA[om:OMS[@cd="calculus1" and @name="diff"] and om:OMV] |
    OMA[OMS[@cd="calculus1" and @name="diff"] and OMV]'
  >
    <math:mrow>
      <xsl:apply-templates select='om:OMV|OMV'/>
      <math:mo>'</math:mo>
    </math:mrow>
  </xsl:template>

  <!-- calculus1.diff applied on an application -->
  <xsl:template match='
    om:OMA[om:OMS[@cd="calculus1" and @name="diff"] and om:OMA] |
    OMA[OMS[@cd="calculus1" and @name="diff"] and OMA]'
  >
    <math:mrow>
      <!-- 
        no (f')' but f'' 
      -->
      <xsl:choose>
        <xsl:when test="om:OMA/om:OMS[@cd='calculus1' and @name='diff']
          or OMA/OMS[@cd='calculus1' and @name='diff']"
        >
          <xsl:apply-templates select='om:OMA|OMA'/>
          <math:mo>'</math:mo>
        </xsl:when>
        <xsl:otherwise>
          <math:mo>(</math:mo>
          <xsl:apply-templates select='om:OMA|OMA'/>
          <math:mo>)</math:mo>
          <math:mo>'</math:mo>
        </xsl:otherwise>
      </xsl:choose>
    </math:mrow>
  </xsl:template>

  <!-- calculus1.diff applied on a lambda function -->
  <xsl:template match='
    om:OMA[om:OMS[@cd="calculus1" and @name="diff"] and om:OMBIND] |
    OMA[OMS[@cd="calculus1" and @name="diff"] and OMBIND]'
  >
    <math:mfrac>
      <math:mrow>
        <math:mo>
          <xsl:text>d</xsl:text>
        </math:mo>
        <xsl:apply-templates select="om:OMBIND/*[3] | OMBIND/*[3]"/>
      </math:mrow>
      <math:mrow>
        <math:mo>
          <xsl:text>d</xsl:text>
        </math:mo>
        <xsl:apply-templates select="om:OMBIND/om:OMBVAR/* | OMBIND/OMBVAR/*"/>
      </math:mrow>
    </math:mfrac>
  </xsl:template>

  <!-- calculus1.int with OMBIND -->
  <xsl:template match='om:OMA[om:OMS[@cd="calculus1" and @name="int"] and
    om:OMBIND] | OMA[OMS[@cd="calculus1" and @name="int"] and OMBIND]'
  >
    <math:mrow>
      <math:mo>
        <!-- U+222B integral -->
        <xsl:text>&#x222b;</xsl:text>
      </math:mo>
      <xsl:apply-templates select='om:OMBIND/*[3] | OMBIND/*[3]'/>
      <math:mo>
        <!-- U+2146 double-struck italic small d &DifferentialD; -->
        <xsl:text>&#x2146;</xsl:text>
      </math:mo>
      <xsl:apply-templates select='om:OMBIND/*[2] | OMBIND/*[2]'/>
    </math:mrow>
  </xsl:template>

  <!-- calculus1.nthdiff -->
  <xsl:template match="OMA[OMS[@cd='calculus1' and @name='nthdiff']] |
      om:OMA[om:OMS[@cd='calculus1' and @name='nthdiff']]">
    <xsl:choose>
      <!--
        lambda function -> we know how we're differentiating, so use that

        d^n ( formula )      d^n f
        - - - - - - - -   or - - -
        d l^n                d l^n
      -->
      <xsl:when test="*[position()=3 and name()='OMBIND' or name()='om:OMBIND']">
        <math:mrow>
          <math:mfrac>
            <math:mrow>
              <math:msup>
                <math:mo>
                  <xsl:text>d</xsl:text>
                </math:mo>
                <xsl:apply-templates select="*[2]"/>
              </math:msup>
              <xsl:choose>
                <!--
                  add extra brackets around a formula
                -->
                <xsl:when test="*[3]/*[3][name()='OMA' or name()='om:OMA']">
                  <math:mo>
                    <xsl:text>(</xsl:text>
                  </math:mo>
                  <xsl:apply-templates select="*[3]/*[3]"/>
                  <math:mo>
                    <xsl:text>)</xsl:text>
                  </math:mo>
                </xsl:when>
                <!--
                  no extra brackets around a non-formula
                -->
                <xsl:otherwise>
                  <xsl:apply-templates select="*[3]/*[3]"/>
                </xsl:otherwise>
              </xsl:choose>
            </math:mrow>
            <math:mrow>
              <math:mo>
                <xsl:text>d</xsl:text>
              </math:mo>
              <math:msup>
                <xsl:choose>
                  <xsl:when test="OMBIND/OMBVAR">
                    <xsl:apply-templates select="OMBIND/OMBVAR/*"/>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:apply-templates select="om:OMBIND/om:OMBVAR/*"/>
                  </xsl:otherwise>
                </xsl:choose>
                <xsl:apply-templates select="*[2]"/>
              </math:msup>
            </math:mrow>
          </math:mfrac>
        </math:mrow>
      </xsl:when>
      <!--
        no lambda function, use f^{(n)} or (formula)^{(n)}
      -->
      <xsl:otherwise>
        <math:msup>
          <xsl:choose>
            <!--
              add extra brackets around a formula
            -->
            <xsl:when test="*[3][name()='OMA' or name()='om:OMA']">
              <math:mrow>
                <math:mo>
                  <xsl:text>(</xsl:text>
                </math:mo>
                <xsl:apply-templates select="*[3]"/>
                <math:mo>
                  <xsl:text>)</xsl:text>
                </math:mo>
              </math:mrow>
            </xsl:when>
            <!--
              no extra brackets around a non-formula
            -->
            <xsl:otherwise>
              <xsl:apply-templates select="*[3]"/>
            </xsl:otherwise>
          </xsl:choose>
          <math:mrow>
            <math:mo>
              <xsl:text>(</xsl:text>
            </math:mo>
            <xsl:apply-templates select="*[2]"/>
            <math:mo>
              <xsl:text>)</xsl:text>
            </math:mo>
          </math:mrow>
        </math:msup>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- calculus1.partialdiff applied on a lambda function -->
  <xsl:template match='
    om:OMA[om:OMS[@cd="calculus1" and @name="partialdiff"] and om:OMBIND] |
    OMA[OMS[@cd="calculus1" and @name="partialdiff"] and OMBIND]'
  >
    <!-- 
      XXX assuming 
        - *[2] is a list and *[2]/*[position() gt 1] are the items in the list
        - the function is written as a lambda function
        - items are OMI (or om:OMI)
    -->
    <math:mfrac>
      <math:mrow>
        <!-- U+2202 partial differential -->
        <xsl:variable name='count' select='count(*[2]/*)-1'/>
        <xsl:choose>
          <xsl:when test='$count = 1'>
            <math:mo>&#x2202;</math:mo>
          </xsl:when>
          <xsl:otherwise>
            <math:msup>
              <math:mo>&#x2202;</math:mo>
              <math:mn>
                <xsl:value-of select='string(count(*[2]/*)-1)'/>
              </math:mn>
            </math:msup>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates select='OMBIND/*[3]|om:OMBIND/*[3]'/>
      </math:mrow>
      <math:mrow>
        <xsl:for-each-group select='*[2]/*[position() gt 1]'
          group-by='.'
        >
          <xsl:variable name='pos'>
            <xsl:value-of select='current-group()[1]'/>
          </xsl:variable>

          <xsl:choose>
            <xsl:when test='count(current-group()) = 1'>
              <math:mo>&#x2202;</math:mo>
            </xsl:when>
            <xsl:otherwise>
              <math:msup>
                <!-- U+2202 partial differential -->
                <math:mo>&#x2202;</math:mo>
                <math:mn>
                  <xsl:value-of select='count(current-group())'/>
                </math:mn>
              </math:msup>
            </xsl:otherwise>
          </xsl:choose>

          <xsl:apply-templates select='../../OMBIND/OMBVAR/*[position() = $pos]|../../om:OMBIND/om:OMBVAR/*[position = $pos]'/>
          <xsl:if test='position() lt last()'>
            <!-- U+2062 invisible times -->
            <math:mo>&#x2062;</math:mo>
          </xsl:if>
        </xsl:for-each-group>
      </math:mrow>
    </math:mfrac>
  </xsl:template>

  <!-- ********************************************************************

       calculus3

       ******************************************************************** -->
  <xsl:template match="OMA[OMS[@name='diff_quot' and @cd='calculus3']]| om:OMA[om:OMS[@name='diff_quot' and @cd='calculus3']]">
    <xsl:choose>
      <xsl:when test="@style='uneval' and @lambda='t'">
        <math:mrow>
          <math:mtable rowlines="solid">
            <math:mtr>
              <math:mtd>
                <xsl:text>&#x394;</xsl:text> <!-- U+0394 greek capital delta -->
                <xsl:apply-templates select="*[2]"/>
              </math:mtd>
            </math:mtr>
            <math:mtr>
              <math:mtd>
                <xsl:text>&#x394;</xsl:text> <!-- U+0394 greek capital delta -->
                <math:mi>t</math:mi>
              </math:mtd>
            </math:mtr>
          </math:mtable>
        </math:mrow>
      </xsl:when>
      <xsl:when test="@style='uneval'">
        <math:mrow>
          <math:mtable rowlines="solid">
            <math:mtr>
              <math:mtd>
                <xsl:text>&#x394;</xsl:text> <!-- U+0394 greek capital delta -->
                <xsl:apply-templates select="*[2]"/>
              </math:mtd>
            </math:mtr>
            <math:mtr>
              <math:mtd>
                <xsl:text>&#x394;</xsl:text> <!-- U+0394 greek capital delta -->
                <math:mi>
                  <xsl:text>x</xsl:text>
                </math:mi>
              </math:mtd>
            </math:mtr>
          </math:mtable>
        </math:mrow>
      </xsl:when>
      <xsl:when test="@lambda='t'">
        <math:mrow>
          <math:mfrac>
            <math:mrow>&#916;<xsl:apply-templates select="*[2]"/></math:mrow>
            <math:mi>&#916; t</math:mi>
          </math:mfrac>
          <math:mo>(</math:mo>
          <xsl:apply-templates select="*[3]"/>,
          <xsl:apply-templates select="*[4]"/>
          <math:mo>)</math:mo>
        </math:mrow>
      </xsl:when>
      <xsl:otherwise>
        <math:mrow>
          <math:mfrac>
            <math:mrow>
              <xsl:text>&#916;</xsl:text>
              <xsl:apply-templates select="*[2]"/>
            </math:mrow>
            <xsl:text>&#916;</xsl:text>
            <math:mi>x</math:mi>
          </math:mfrac>
          <math:mo>(</math:mo>
          <xsl:apply-templates select="*[3]"/>,
          <xsl:apply-templates select="*[4]"/>
          <math:mo>)</math:mo>
        </math:mrow>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template match="OMA[OMS[@name='difference' and @cd='calculus3']]| om:OMA[om:OMS[@name='difference' and @cd='calculus3']]">
    <xsl:choose>
      <xsl:when test="@style='uneval'">
        <math:mrow>
          <math:mo>
            <xsl:text>&#916;</xsl:text>
          </math:mo>
          <!-- 916 = U+0394 Greek capital delta -->
          <xsl:apply-templates select="*[2]"/>
        </math:mrow>
      </xsl:when>
      <xsl:otherwise>
        <math:mrow>
          <math:mo>
            <xsl:text>&#916;</xsl:text>
            <!-- 916 = U+0394 Greek capital delta -->
          </math:mo>
          <xsl:apply-templates select="*[2]"/>
          <math:mo>
            <xsl:text>(</xsl:text>
          </math:mo>
          <xsl:apply-templates select="*[3]"/>
          <math:mo>
            <xsl:text>,</xsl:text>
          </math:mo>
          <xsl:apply-templates select="*[4]"/>
          <math:mo>
            <xsl:text>)</xsl:text>
          </math:mo>
        </math:mrow>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- ********************************************************************

       combinat1

       ******************************************************************** -->

 <xsl:template match="om:OMA[om:OMS[@name='binomial' and @cd='combinat1']]|OMA[OMS[@name='binomial' and @cd='combinat1']]">
    <math:mrow>
  <math:mo> ( </math:mo>
  <math:mtable>
    <math:mtr>
      <math:mtd><xsl:apply-templates select="*[2]"/></math:mtd>
    </math:mtr>
    <math:mtr>
      <math:mtd><xsl:apply-templates select="*[3]"/></math:mtd>
    </math:mtr>
  </math:mtable>
  <math:mo> ) </math:mo></math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       complex1

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@name='argument' and @cd='complex1']]|OMA[OMS[@name='argument' and @cd='complex1']]">
    <math:mrow>
      <math:mi>arg</math:mi>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='complex_cartesian' and @cd='complex1']]|OMA[OMS[@name='complex_cartesian' and @cd='complex1']]">
    <!-- test for zeroes; in short mode don't write zeroes if not necessary -->
    <xsl:variable name='zero_re' as='xs:boolean' 
      select='boolean(*[2]/self::om:OMI[normalize-space(.)="0"] or *[2]/self::OMI[normalize-space(.)="0"])'
    />
    <xsl:variable name='zero_im' as='xs:boolean' 
      select='boolean(*[3]/self::om:OMI[normalize-space(.)="0"] or *[3]/self::OMI[normalize-space(.)="0"])'
    />
    <!-- test for 1i; in short mode, just write i -->
    <xsl:variable name='one_im' as='xs:boolean' 
      select='boolean(*[3]/self::om:OMI[normalize-space(.)="1"] or *[3]/self::OMI[normalize-space(.)="1"])'
    />
    <xsl:variable name='negone_im' as='xs:boolean' 
      select='boolean(*[3]/self::om:OMI[normalize-space(.)="-1"] or *[3]/self::OMI[normalize-space(.)="-1"])'
    />
    <!-- test for negative imaginary part; in short mode, don't write + -->
    <xsl:variable name='neg_im' as='xs:boolean' 
      select='boolean(*[3]/self::om:OMI[starts-with(normalize-space(.),"-")] or *[3]/self::OMI[starts-with(normalize-space(.),"-1")])'
    />
    <math:mrow>
      <xsl:if test='not($short_complex1_complex_cartesian) or not($zero_re)'>
        <xsl:apply-templates select="*[2]"/>
      </xsl:if>
      
      <xsl:if test='not($short_complex1_complex_cartesian) or (not($zero_re) and not($zero_im) and not($neg_im))'>
        <math:mo>+</math:mo>
      </xsl:if>
      
      <xsl:if test='not($short_complex1_complex_cartesian) or not($zero_im)'>
        <!-- if it is an application, then add brackets -->
        <xsl:choose>
          <!-- do not write 1i in short notation -->
          <xsl:when test='$short_complex1_complex_cartesian and $one_im'/>
          <!-- do not write -1i, but -i in short notation -->
          <xsl:when test='$short_complex1_complex_cartesian and $negone_im'>
            <math:mo>-</math:mo>
          </xsl:when>
          <xsl:when test='*[3][self::OMA or self::om:OMA]'>
            <math:mo>(</math:mo>
            <xsl:apply-templates select="*[3]"/>
            <math:mo>)</math:mo>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="*[3]"/>
          </xsl:otherwise>
        </xsl:choose>
  
        <xsl:if test='not($short_complex1_complex_cartesian and ($one_im or $negone_im))'>
          <!-- U+2062 invisible times -->
          <math:mo>&#x2062;</math:mo>
        </xsl:if>

        <!-- U+2148 double-struck italic small i -->
        <math:mi>&#x2148;</math:mi>
      </xsl:if>

      <xsl:if test='$short_complex1_complex_cartesian and $zero_re and $zero_im'>
        <math:mn>0</math:mn>
      </xsl:if>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='complex_polar' and @cd='complex1']]|OMA[OMS[@name='complex_polar' and @cd='complex1']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>

      <!-- U+2062 invisible times -->
      <math:mo>&#x2062;</math:mo>

      <!-- now the power --> 
      <math:msup>
        <math:mi>e</math:mi>

        <!-- if it is an application, then add brackets -->
        <xsl:choose>
          <xsl:when test='*[3][self::OMA or self::om:OMA]'>
            <math:mo>(</math:mo>
            <xsl:apply-templates select="*[3]"/>
            <math:mo>)</math:mo>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="*[3]"/>
          </xsl:otherwise>
        </xsl:choose>
  
        <!-- U+2062 invisible times -->
        <math:mo>&#x2062;</math:mo>
        <!-- U+2148 double-struck italic small i -->
        <math:mi>&#x2148;</math:mi>
      </math:msup>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='conjugate' and @cd='complex1']]|OMA[OMS[@name='conjugate' and @cd='complex1']]">
    <math:mrow>
      <math:mover>
        <xsl:apply-templates select="*[2]"/>

        <!-- U+00AF macron -->
        <!-- also known as: overbar -->
        <math:mo>&#x00AF;</math:mo>
      </math:mover>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='imaginary' and @cd='complex1']]|OMA[OMS[@name='imaginary' and @cd='complex1']]">
    <math:mrow>
      <math:mi>Im</math:mi>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='real' and @cd='complex1']]|OMA[OMS[@name='real' and @cd='complex1']]">
    <math:mrow>
      <math:mi>Re</math:mi>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       editor1 
       only implemented symbol: input_box

       ******************************************************************** -->
  <xsl:template match="om:OMS[@name='input_box' and @cd='editor1']|OMS[@name='input_box' and @cd='editor1']">
    <!--  U+25A1 white square -->
    <math:mi>&#x25A1;</math:mi>
  </xsl:template>

  <!-- ********************************************************************

       field3

       ******************************************************************** -->


  <xsl:template match="om:OMA[om:OMS[@cd='field3' and @name='fraction_field']]|OMA[OMS[@cd='field3' and @name='fraction_field']]">
    <math:mrow>
      <math:mi>Q</math:mi>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@cd='field3' and @name='free_field']]|OMA[OMS[@cd='field3' and @name='free_field']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[3]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       fns1

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='fns1' and @name='image']]|OMA[OMS[@cd='fns1' and @name='image']]">
    <math:mrow>
      <math:mi>Im</math:mi>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='fns1' and @name='inverse']]|OMA[OMS[@cd='fns1' and @name='inverse']]">
    <math:mrow>
      <math:msup>
        <xsl:apply-templates select="*[2]"/>
        <math:mrow>
          <math:mo>-</math:mo>
          <math:mn>1</math:mn>
        </math:mrow>
      </math:msup>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMBIND[om:OMS[@cd='fns1' and @name='lambda']]|OMBIND[OMS[@cd='fns1' and @name='lambda']]">
    <math:mrow>
      <math:mfenced open="" close="" separators=",">
        <xsl:for-each select="om:OMBVAR/*|OMBVAR/*">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
      <math:mo>&#8614;</math:mo>
      <math:mrow>
        <xsl:apply-templates select="*[3]"/>
      </math:mrow>
    </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@name='left_compose']]|OMA[OMS[@name='left_compose']]">
    <xsl:choose>
      <xsl:when test="@style='brackets'">
           <math:mrow> <math:mo>(</math:mo>
            <math:mrow>
             <xsl:for-each select="*[position()&gt;1]">
              <xsl:apply-templates select="."/>
              <xsl:if test="position() &lt; last()">
                <math:mo>&#8728;</math:mo>
              </xsl:if>
             </xsl:for-each>
            </math:mrow>
           <math:mo>)</math:mo></math:mrow>
      </xsl:when>
    <xsl:otherwise>
    <math:mrow>
      <xsl:for-each select="*[position()&gt;1]">
          <xsl:apply-templates select="."/>
          <xsl:if test="position() &lt; last()">
            <math:mo>&#8728;</math:mo>
          </xsl:if>
      </xsl:for-each>
    </math:mrow>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:template>


  <xsl:template match="om:OMS[@name='left_compose']|OMS[@name='left_compose']">
                <math:mo>&#8728;</math:mo>
  </xsl:template>




  <!-- ********************************************************************

       fns2

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@name='kernel']]|OMA[OMS[@name='kernel']]">
    <math:mrow>
      <math:mi>Ker</math:mi>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='fns2' and @name='apply_to_list']]|OMA[OMS[@cd='fns2' and @name='apply_to_list']]">
    <math:mrow>
      <math:mi>TODO</math:mi>
      <xsl:choose>
        <xsl:when test="om:OMA|OMA">
          <math:mrow>
            <xsl:apply-templates select="*[1]"/>
          </math:mrow>
          <math:mfenced separators=",">
            <xsl:attribute name="open">(</xsl:attribute>
            <xsl:attribute name="close">)</xsl:attribute>
            <math:mrow>
              <xsl:apply-templates select="*[2]"/>
            </math:mrow>
            <math:mrow>
              <xsl:apply-templates select="*[3]"/>
            </math:mrow>
          </math:mfenced>
        </xsl:when>
        <xsl:otherwise>
          <math:mfenced separators=",">
            <xsl:attribute name="open">{</xsl:attribute>
            <xsl:attribute name="close">}</xsl:attribute>
            <math:mrow>
              <xsl:apply-templates select="*[2]"/>
            </math:mrow>
            <math:mrow>
              <xsl:apply-templates select="*[3]"/>
            </math:mrow>
          </math:mfenced>
        </xsl:otherwise>
      </xsl:choose>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='right_compose']]|OMA[OMS[@name='right_compose']]">
    <xsl:choose>
      <xsl:when test="@style='brackets'">
           <math:mrow> <math:mo>(</math:mo>
            <math:mrow>
             <xsl:for-each select="*[position()&gt;1]">
              <xsl:apply-templates select="."/>
              <xsl:if test="position() &lt; last()">
                <math:mo>&#8226;</math:mo>
              </xsl:if>
             </xsl:for-each>
            </math:mrow>
           <math:mo>)</math:mo></math:mrow>
      </xsl:when>
    <xsl:otherwise>
    <math:mrow>
      <xsl:for-each select="*[position()&gt;1]">
          <xsl:apply-templates select="."/>
          <xsl:if test="position() &lt; last()">
            <math:mo>&#8226;</math:mo>
          </xsl:if>
      </xsl:for-each>
    </math:mrow>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:template>



  <!-- ********************************************************************

       fns3

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='fns3' and @name='function']]|OMA[OMS[@cd='fns3' and @name='function']]">
    <xsl:choose>
      <xsl:when test="*[4]">
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
          <math:mo>&#8594;</math:mo>
          <xsl:apply-templates select="*[3]"/>
          <math:mo>,</math:mo>
          <xsl:apply-templates select="*[4]"/>
        </math:mrow>
      </xsl:when>
      <xsl:otherwise>
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
          <math:mo>&#8594;</math:mo>
          <xsl:apply-templates select="*[3]"/>
        </math:mrow>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

<xsl:template match="om:OMA[om:OMS[@cd='fns3' and @name='mapsto']]|OMA[OMS[@cd='fns3' and @name='mapsto']]">
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
          <math:mo>&#10236;</math:mo>
          <xsl:apply-templates select="*[3]"/>
        </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='fns3' and @name='restriction']]|OMA[OMS[@cd='fns3' and @name='restriction']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>&#8595;</math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       fns4

       ******************************************************************** -->

  <xsl:template match="om:OMBIND[om:OMS[@cd='fns4' and @name='maps_to']]|OMBIND[OMS[@cd='fns4' and @name='maps_to']]">
    <math:mrow>
      <xsl:apply-templates select="*[3]"/>
      <math:mo>&#8614;</math:mo>
      <xsl:apply-templates select="*[4]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='fns4' and  @name='assign_to']]|OMA[OMS[@cd='fns4' and  @name='assign_to']]">
    <!-- new version {1,3,...} -> {2,4,...} -->
    <math:mrow>
    <xsl:choose>
      <xsl:when test="*[4]"> <!-- more than 2 arguments -->
        <math:mfenced open="{{" close="}}" separators=",">
          <xsl:for-each select="*[position() mod 2 = 0]">
            <xsl:apply-templates select="."/>
          </xsl:for-each>
        </math:mfenced>
        <math:mo>&#8614;</math:mo>
        <math:mfenced open="{{" close="}}" separators=",">
          <xsl:for-each select="*[position() mod 2 = 1]">
            <xsl:if test="position()&gt;1">
              <xsl:apply-templates select="."/>
            </xsl:if>
          </xsl:for-each>
        </math:mfenced>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="*[2]"/>
        <math:mo>&#8614;</math:mo>
        <xsl:apply-templates select="*[3]"/>
      </xsl:otherwise>
    </xsl:choose>
    </math:mrow>
    <!-- old version 1->2, 3->4, ...
      <xsl:for-each select="*[position()>1]">
        <!- - warning: in this loop position 1 means the first argument - ->
        <xsl:if test="position() > 1">
          <xsl:choose>
            <xsl:when test="position() mod 2 = 0">
              <math:mo>&#x021a6;</math:mo>
            </xsl:when>
            <xsl:when test="position() mod 2 = 1">
              <xsl:text disable-output-escaping = "yes">&lt;/math:mrow&gt;
                <math:mo>,</math:mo>
                &lt;math:mrow&gt;
              </xsl:text>
            </xsl:when>
          </xsl:choose>
        </xsl:if>
        <xsl:apply-templates select="."/>
      </xsl:for-each>
      -->
  </xsl:template>



  <!-- ********************************************************************

       graph1

       ******************************************************************** -->


  <xsl:template match="om:OMA[om:OMS[@cd='graph1' and @name='graph']]|OMA[OMS[@cd='graph1' and @name='graph']]">
    <math:mrow>
      <math:mo>(</math:mo>
      <math:mfenced open="" close="" separators=",">
        <xsl:for-each select="*[position()&gt;1]">
          <math:mrow><xsl:apply-templates select="."/></math:mrow>
        </xsl:for-each>
      </math:mfenced>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>



  <!-- ********************************************************************

       group1

       ******************************************************************** -->


  <xsl:template match="om:OMA[om:OMS[@name='carrier']]|OMA[OMS[@name='carrier']]">
    <xsl:choose>
    <xsl:when test="om:OMA[om:OMS[@name='monoid' or @name='group']]|OMA[OMS[@name='monoid' or @name='group']]">
    <math:mrow>
      <xsl:apply-templates select="om:OMA/*[2]|OMA/*[2]"/>
    </math:mrow>
    </xsl:when>
    <xsl:otherwise>
     <math:mrow>
       <xsl:apply-templates select="*[2]"/>
     </math:mrow>
    </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@name='identity']]|OMA[OMS[@name='identity']]">
    <xsl:choose>
    <xsl:when test="om:OMA[om:OMS[@name='monoid' or @name='group']]|OMA[OMS[@name='monoid' or @name='group']]">
     <math:mrow>
       <xsl:apply-templates select="om:OMA/*[4]|OMA/*[4]"/>
     </math:mrow>
    </xsl:when>
    <xsl:otherwise>
     <math:mrow>
      <math:mo>1</math:mo>
     </math:mrow>
    </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@cd='group1' and @name='is_subgroup']]|OMA[OMS[@cd='group1' and @name='is_subgroup']]">
    <math:mrow>
      <xsl:apply-templates select="*[3]"/>
      <math:mo>&lt;</math:mo>
      <xsl:apply-templates select="*[2]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='left_cosets']]|OMA[OMS[@name='left_cosets']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mi>/</math:mi>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='group1' and @name='group']]|OMA[OMS[@cd='group1' and @name='group']]">
      <math:mfenced open="[" close="]" separators=",">
        <math:mrow> <xsl:apply-templates select="*[2]"/> </math:mrow>
  <math:mrow>         <xsl:apply-templates select="*[3]"/> </math:mrow>
  <math:mrow>         <xsl:apply-templates select="*[4]"/> </math:mrow>
  <math:mrow>         <xsl:apply-templates select="*[5]"/>  </math:mrow>
      </math:mfenced>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@name='right_cosets']]|OMA[OMS[@name='right_cosets']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mi>\\</math:mi>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='group1' and @name='multiplication']]|OMA[OMS[@cd='group1' and @name='multiplication']]">
    <xsl:for-each select="*[position()&gt;2]">
      <math:mrow>
        <xsl:apply-templates select="."/>
      </math:mrow>
    </xsl:for-each>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@name='right_cosets']]|OMA[OMS[@name='right_cosets']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mi>\\</math:mi>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@cd='group1' and @name='subgroup']]|OMA[OMS[@cd='group1' and @name='subgroup']]">
    <xsl:choose>
      <xsl:when test="*[3]">
        <math:msub>
          <math:mrow>
            <!-- XXX: mathematical versions not supported by mathml2latex translation -->
            <xsl:choose>
              <xsl:when test='$openmath2mathml.mathml3_entities'>
                <!-- U+27E8 Mathematical left angle bracket -->
                <math:mo>&#x27E8;</math:mo>
              </xsl:when>
              <xsl:otherwise>
                <!-- U+2329 left-pointing angle bracket -->
                <math:mo>&#x2329;</math:mo>
              </xsl:otherwise>
            </xsl:choose> 
            <xsl:apply-templates select="*[2]"/>
            <xsl:choose>
              <xsl:when test='$openmath2mathml.mathml3_entities'>
                <!-- U+27E9 Mathematical right angle bracket -->
                <math:mo>&#x27E9;</math:mo>
              </xsl:when>
              <xsl:otherwise>
                <!-- U+232A right-pointing angle bracket -->
                <math:mo>&#x232A;</math:mo>
              </xsl:otherwise>
            </xsl:choose> 
          </math:mrow>
          <xsl:apply-templates select="*[3]"/>
        </math:msub>
      </xsl:when>
      <xsl:otherwise>
        <math:mrow>
          <xsl:choose>
            <xsl:when test='$openmath2mathml.mathml3_entities'>
              <!-- U+27E8 Mathematical left angle bracket -->
              <math:mo>&#x27E8;</math:mo>
            </xsl:when>
            <xsl:otherwise>
              <!-- U+2329 left-pointing angle bracket -->
              <math:mo>&#x2329;</math:mo>
            </xsl:otherwise>
          </xsl:choose> 
          <xsl:apply-templates select="*[2]"/>
          <xsl:choose>
            <xsl:when test='$openmath2mathml.mathml3_entities'>
              <!-- U+27E9 Mathematical right angle bracket -->
              <math:mo>&#x27E9;</math:mo>
            </xsl:when>
            <xsl:otherwise>
              <!-- U+232A right-pointing angle bracket -->
              <math:mo>&#x232A;</math:mo>
            </xsl:otherwise>
          </xsl:choose> 
        </math:mrow>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>



  <!-- ********************************************************************

       group2

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@name='automorphism_group']]|OMA[OMS[@name='automorphism_group']]">
    <math:mrow>
      <math:mo>Aut</math:mo>
      <math:mi>(</math:mi>
      <xsl:apply-templates select="*[2]"/>
      <math:mi>)</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='left_multiplication']]|OMA[OMS[@name='left_multiplication']]">
    <math:msub>
      <math:mo>L</math:mo>
      <xsl:apply-templates select="*[2]"/>
    </math:msub>
  </xsl:template>

  <xsl:template match="om:OMS[@name='left_multiplication']|OMS[@name='left_multiplication']">
      <math:mo>L</math:mo>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='right_inverse_multiplication']]|OMA[OMS[@name='right_inverse_multiplication']]">
    <math:msub>
      <math:mo>R</math:mo>
      <xsl:apply-templates select="*[2]"/>
    </math:msub>
  </xsl:template>

  <xsl:template match="om:OMS[@name='right_inverse_multiplication']|OMS[@name='right_inverse_multiplication']">
      <math:mo>R</math:mo>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@cd='group2' and @name='conjugation']]|OMA[OMS[@cd='group2' and @name='conjugation']]">
    <math:msub>
      <math:mo>C</math:mo>
      <xsl:apply-templates select="*[2]"/>
    </math:msub>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='group2' and @name='conjugation']|OMS[@cd='group2' and @name='conjugation']">
      <math:mo>C</math:mo>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='isomorphic']]|OMA[OMS[@name='isomorphic']]">
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
          <math:mo>&#8773;</math:mo>
          <xsl:apply-templates select="*[3]"/>
        </math:mrow>
  </xsl:template>



  <!-- ********************************************************************

       group3

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='group3' and @name='center']]|OMA[OMS[@cd='group3' and @name='center']]">
    <math:mrow>
      <math:mi mathvariant="bold">Z</math:mi>
      <math:mi>(</math:mi>
      <xsl:apply-templates select="*[2]"/>
      <math:mi>)</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='group3' and @name='centralizer']]|OMA[OMS[@cd='group3' and @name='centralizer']]">
      <math:mrow>
        <math:msub>
           <math:mo>C</math:mo>
            <xsl:apply-templates select="*[2]"/>
        </math:msub>
        <math:mi>(</math:mi>
            <xsl:apply-templates select="*[3]"/>
        <math:mi>)</math:mi>
      </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@cd='group3' and @name='normalizer']]|OMA[OMS[@cd='group3' and @name='normalizer']]">
      <math:mrow>
        <math:msub>
           <math:mo>N</math:mo>
            <xsl:apply-templates select="*[2]"/>
        </math:msub>
        <math:mi>(</math:mi>
            <xsl:apply-templates select="*[3]"/>
        <math:mi>)</math:mi>
      </math:mrow>
  </xsl:template>



  <xsl:template match="om:OMA[om:OMS[@cd='group3' and @name='GLn']]|OMA[OMS[@cd='group3' and @name='GL']]">
    <math:mrow>
      <math:mo>GL</math:mo>
      <math:mi>(</math:mi>
      <xsl:apply-templates select="*[2]"/>
      <math:mi>)</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='group3' and @name='GLn']]|OMA[OMS[@cd='group3' and @name='GLn']]">
    <math:mrow>
      <math:mo>GL</math:mo>
      <math:mi>(</math:mi>
      <xsl:apply-templates select="*[2]"/>
      <math:mi>,</math:mi>
      <xsl:apply-templates select="*[3]"/>
      <math:mi>)</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='group3' and @name='SLn']]|OMA[OMS[@cd='group3' and @name='SLn']]">
    <math:mrow>
      <math:mo>SL</math:mo>
      <math:mi>(</math:mi>
      <xsl:apply-templates select="*[2]"/>
      <math:mi>,</math:mi>
      <xsl:apply-templates select="*[3]"/>
      <math:mi>)</math:mi>
    </math:mrow>
  </xsl:template>



  <xsl:template match="om:OMA[om:OMS[@name='direct_power']]|OMA[OMS[@name='direct_power']]">
    <math:msup>
      <math:mrow>
        <xsl:choose>
          <xsl:when test="om:OMA|OMA">
            <xsl:apply-templates select="*[2]"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="*[2]"/>
          </xsl:otherwise>
        </xsl:choose>
      </math:mrow>
      <math:mrow>
        <xsl:apply-templates select="*[3]"/>
      </math:mrow>
    </math:msup>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='direct_product']]|OMA[OMS[@name='direct_product']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <xsl:for-each select="*[position()&gt;2]">
            <math:mo>&#215;</math:mo><xsl:apply-templates select="."/>
      </xsl:for-each>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='group3' and @name='quotient_group']]|OMA[OMS[@cd='group3' and @name='quotient_group']]">
    <math:mrow>
          <xsl:apply-templates select="*[2]"/>
          <math:mo>/</math:mo>
          <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@cd='group3' and @name='symmetric_group']]|OMA[OMS[@cd='group3' and @name='symmetric_group']]">
        <math:mrow>
          <math:mi>Sym</math:mi>
          <math:mi>(</math:mi>
          <xsl:apply-templates select="*[2]"/>
          <math:mi>)</math:mi>
        </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@cd='group3' and @name='symmetric_groupn']]|OMA[OMS[@cd='group3' and @name='symmetric_groupn']]">
        <math:mrow>
          <math:msub>
            <math:mi>Sym</math:mi>
            <xsl:apply-templates select="*[2]"/>
          </math:msub>
        </math:mrow>
  </xsl:template>



  <xsl:template match="om:OMA[om:OMS[@cd='group3' and @name='free_group']]|OMA[OMS[@cd='group3' and @name='free_group']]">
    <math:mrow>
      <xsl:choose>
        <xsl:when test='$openmath2mathml.mathml3_entities'>
          <!-- U+27E8 Mathematical left angle bracket -->
          <math:mo>&#x27E8;</math:mo>
        </xsl:when>
        <xsl:otherwise>
          <!-- U+2329 left-pointing angle bracket -->
          <math:mo>&#x2329;</math:mo>
        </xsl:otherwise>
      </xsl:choose> 
     <xsl:apply-templates select="*[2]"/>
     <xsl:for-each select="*[position()&gt;2]">
       <math:mo>,</math:mo><xsl:apply-templates select="."/>
     </xsl:for-each>
      <xsl:choose>
        <xsl:when test='$openmath2mathml.mathml3_entities'>
          <!-- U+27E9 Mathematical right angle bracket -->
          <math:mo>&#x27E9;</math:mo>
        </xsl:when>
        <xsl:otherwise>
          <!-- U+232A right-pointing angle bracket -->
          <math:mo>&#x232A;</math:mo>
        </xsl:otherwise>
      </xsl:choose> 
   </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       groupname1

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@name='cyclic_group']]|OMA[OMS[@name='cyclic_group']]">
    <math:mrow>
      <math:msub>
        <math:mi>C</math:mi>
        <xsl:apply-templates select="*[2]"/>
      </math:msub>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='groupname1' and @name='dihedral_group']]|OMA[OMS[@cd='groupname1' and @name='dihedral_group']]">
    <math:mrow>
      <math:msub>
        <math:mi>D</math:mi>
        <xsl:apply-templates select="*[2]"/>
      </math:msub>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='groupname1' and @name='quaternion_group']|OMS[@cd='groupname1' and @name='quaternion_group']">
        <math:msub><math:mi>Q</math:mi><math:mi>8</math:mi></math:msub>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='groupname1' and @name='generalized_quaternion_group']]|OMA[OMS[@cd='groupname2' and @name='generalized_quaternion_group']]">
    <math:mrow>
      <math:msub>
        <math:mi>Q</math:mi>
        <xsl:apply-templates select="*[2]"/>
      </math:msub>
    </math:mrow>
  </xsl:template>


  <!-- ********************************************************************

       groupname2

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='groupname2' and @name='Sp']]|OMA[OMS[@cd='groupname2' and @name='Sp']]">
    <math:mrow>
        <math:mi>Sp(</math:mi>
        <xsl:apply-templates select="*[2]"/>
        <math:mi>)</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='groupname2' and @name='orthogonal_groupn']]|OMA[OMS[@cd='groupname2' and @name='orthogonal_groupn']]">
    <math:mrow>
        <math:mi>O(</math:mi>
        <xsl:apply-templates select="*[2]"/>
        <math:mi>,</math:mi>
        <xsl:apply-templates select="*[3]"/>
        <math:mi>)</math:mi>
    </math:mrow>
  </xsl:template>


  <!-- ********************************************************************

       integer1

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@name='factorof' and @cd='integer1']]|OMA[OMS[@name='factorof' and @cd='integer1']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <!-- U+2223 divides -->
      <math:mo>&#x2223;</math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='integer1' and @name='factorial']]|OMA[OMS[@cd='integer1' and @name='factorial']]">
    <math:mrow>
      <xsl:choose>
        <xsl:when test='*[2][self::OMA or self::om:OMA]'>
          <math:mfenced>
            <xsl:apply-templates select="*[2]"/>
          </math:mfenced>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates select="*[2]"/>
        </xsl:otherwise>
      </xsl:choose>
      <math:mo>!</math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='integer1' and @name='quotient']|OMS[@cd='integer1' and @name='quotient']">
    <math:mrow>
      <math:mi>quotient</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='integer1' and @name='quotient']]|OMA[OMS[@cd='integer1' and @name='quotient']]">
    <math:mrow>
      <math:mi>quot</math:mi>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>,</math:mo>
      <xsl:apply-templates select="*[3]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='integer1' and @name='remainder']|OMS[@cd='integer1' and @name='remainder']">
    <math:mrow>
      <math:mi>remainder</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='integer1' and @name='remainder']]|OMA[OMS[@cd='integer1' and @name='remainder']]">
    <math:mrow>
      <math:mi>rem</math:mi>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>,</math:mo>
      <xsl:apply-templates select="*[3]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <!-- *******************************************************************

       integer2

       ******************************************************************* -->

  <xsl:template match="om:OMA[om:OMS[@name='class' and @cd='integer2']]|OMA[OMS[@name='class' and @cd='integer2']]">
    <math:mrow>
      <math:mrow>
        <xsl:apply-templates select="*[2]"/>
      </math:mrow>
      <math:mrow>
        <math:mo>
          <xsl:text>(</xsl:text>
        </math:mo>
        <math:mi>
          <xsl:text>mod</xsl:text>
        </math:mi>
        <math:mo>
          <xsl:text>&#x00A0;</xsl:text> <!-- U+00A0 no-break space -->
        </math:mo>
        <xsl:apply-templates select="*[3]"/>
        <math:mo>
          <xsl:text>)</xsl:text>
        </math:mo>
      </math:mrow>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='divides' and @cd='integer2']]|OMA[OMS[@name='divides' and @cd='integer2']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <!-- U+2223 divides -->
      <math:mo>&#x2223;</math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@name='euler' and @cd='integer2']|OMS[@name='euler' and @cd='integer2']">
    <math:mrow>
      <xsl:text>&#934;</xsl:text> <!-- U+03A6 greek capital letter phi -->
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='euler' and @cd='integer2']]|OMA[OMS[@name='euler' and @cd='integer2']]">
    <math:mrow>
      <xsl:text>&#934;(</xsl:text><!-- U+03A6 greek capital letter phi -->
      <xsl:apply-templates select="*[2]"/>
      <xsl:text>)</xsl:text>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='eqmod']]|OMA[OMS[@name='eqmod']]">
    <math:mrow>
      <math:mrow>
        <xsl:apply-templates select="*[2]"/>
      </math:mrow>
      <math:mrow>
        <xsl:text>&#8801;</xsl:text> <!-- U+2261 identical to -->
      </math:mrow>
      <math:mrow>
        <xsl:apply-templates select="*[3]"/>
      </math:mrow>
      <math:mrow>
        <math:mo>
          <xsl:text>&#x00A0;(</xsl:text><!-- U+00A0 no-break space -->
        </math:mo>
        <math:mi>
          <xsl:text>mod</xsl:text>
        </math:mi>
        <math:mo>
          <xsl:text>&#x00A0;</xsl:text> <!-- U+00A0 no-break space -->
        </math:mo>
      </math:mrow>
      <math:mrow>
        <xsl:apply-templates select="*[4]"/>
        <math:mo>
          <xsl:text>)</xsl:text>
        </math:mo>
      </math:mrow>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='modulo_relation' and @cd='integer2']]|OMA[OMS[@name='modulo_relation' and @cd='integer2']]">
    <math:mrow>
      <math:mi>
        <xsl:text>mod</xsl:text>
      </math:mi>
      <math:mo>
        <xsl:text>&#x00A0;</xsl:text> <!-- U+00A0 no-break space -->
      </math:mo>
      <xsl:apply-templates select="*[2]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='integer2' and @name='ord']]|OMA[OMS[@cd='integer2' and @name='ord']]">
    <math:mrow>
      <math:msub>
        <math:mi>
          <xsl:text>ord</xsl:text>
        </math:mi>
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
        </math:mrow>
      </math:msub>
      <xsl:text>(</xsl:text>
      <xsl:apply-templates select="*[3]"/>
      <xsl:text>)</xsl:text>
    </math:mrow>
  </xsl:template>

 <xsl:template match="om:OMA[om:OMS[@name='neqmod' and @cd='integer2']]|OMA[OMS[@name='neqmod' and @cd='integer2']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>
        <xsl:text>&#8802;</xsl:text>
        <!-- 8802 = U+2262 not identical to (3 lines) -->
      </math:mo>
      <xsl:apply-templates select="*[3]"/>
      <math:mo>
        <xsl:text>&#x00A0;(</xsl:text><!-- U+00A0 no-break space -->
      </math:mo>
      <math:mi>
        <xsl:text>mod</xsl:text>
      </math:mi>
      <math:mo>
        <xsl:text>&#x00A0;</xsl:text> <!-- U+00A0 no-break space -->
      </math:mo>
      <xsl:apply-templates select="*[4]"/>
      <math:mo>
        <xsl:text>)</xsl:text>
      </math:mo>
    </math:mrow>
  </xsl:template>

  <!-- *******************************************************************

       interval1 (partial implementation)
       XXX: math:mrows around arguments of interval shouldn't be necessary

       ******************************************************************* -->

  <xsl:template match="om:OMA[om:OMS[@name='interval_cc' and @cd='interval1']]|OMA[OMS[@name='interval_cc' and @cd='interval1']]">
    <math:mrow>
      <math:mfenced 
        open="{$openmath2mathml.interval1.left.close}" 
        close="{$openmath2mathml.interval1.right.close}" 
        separators="{mdf:interval-separators(.)}"
      >
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
        </math:mrow>
        <math:mrow>
          <xsl:apply-templates select="*[3]"/>
        </math:mrow>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='interval_co' and @cd='interval1']]|OMA[OMS[@name='interval_co' and @cd='interval1']]">
    <math:mrow>
      <math:mfenced 
        open="{$openmath2mathml.interval1.left.close}" 
        close="{$openmath2mathml.interval1.right.open}" 
        separators="{mdf:interval-separators(.)}"
      >
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
        </math:mrow>
        <math:mrow>
          <xsl:apply-templates select="*[3]"/>
        </math:mrow>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='interval_oo' and @cd='interval1']]|OMA[OMS[@name='interval_oo' and @cd='interval1']]">
    <math:mrow>
      <math:mfenced 
        open="{$openmath2mathml.interval1.left.open}" 
        close="{$openmath2mathml.interval1.right.open}" 
        separators="{mdf:interval-separators(.)}"
      >
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
        </math:mrow>
        <math:mrow>
          <xsl:apply-templates select="*[3]"/>
        </math:mrow>
      </math:mfenced>
    </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@name='interval_oc' and @cd='interval1']]|OMA[OMS[@name='interval_oc' and @cd='interval1']]">
    <math:mrow>
      <math:mfenced 
        open="{$openmath2mathml.interval1.left.open}" 
        close="{$openmath2mathml.interval1.right.close}" 
        separators="{mdf:interval-separators(.)}"
      >
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
        </math:mrow>
        <math:mrow>
          <xsl:apply-templates select="*[3]"/>
        </math:mrow>
      </math:mfenced>
    </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@cd='interval1' and @name='integer_interval']]|OMA[OMS[@cd='interval1' and @name='integer_interval']]">
    <math:mrow>
      <math:mfenced separators=",">
        <xsl:attribute name="open">{</xsl:attribute>
        <xsl:attribute name="close">}</xsl:attribute>
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
        </math:mrow>
        <math:mrow>
          <math:mi>...</math:mi>
        </math:mrow>
        <math:mrow>
          <xsl:apply-templates select="*[3]"/>
        </math:mrow>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       limit1 (partial implementation)

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='limit1' and @name='limit']]|OMA[OMS[@cd='limit1' and @name='limit']]">
    <math:mrow>
      <math:munder>
        <math:mi>
          <xsl:text>lim</xsl:text>
        </math:mi>
        <math:mrow>
          <xsl:apply-templates select="om:OMBIND/om:OMBVAR|OMBIND/OMBVAR"/>
          <math:mo>&#8594;</math:mo>
          <xsl:choose>
            <xsl:when test="om:OMS[@cd='limit1' and @name='above']|OMS[@cd='limit1' and @name='above']">
              <math:msup>
                <xsl:apply-templates select="*[2]"/>
                <math:mo>+</math:mo>
              </math:msup>
            </xsl:when>
            <xsl:when test="om:OMS[@cd='limit1' and @name='below']|OMS[@cd='limit1' and @name='below']">
              <math:msup>
                <xsl:apply-templates select="*[2]"/>
                <math:mo>-</math:mo>
              </math:msup>
            </xsl:when>
            <xsl:otherwise>
              <xsl:apply-templates select="*[2]"/>
            </xsl:otherwise>
          </xsl:choose>
        </math:mrow>
      </math:munder>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="om:OMBIND/*[3]|OMBIND/*[3]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       linalg1 (TODO: check completeness)
       version 3
       determinant, matrix_selector, outerproduct, scalarproduct, transpose,
       vector_selector, vectorproduct

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='linalg1' and @name='determinant']]|OMA[OMS[@cd='linalg1' and @name='determinant']]">
    <math:mrow>
      <math:mi>det</math:mi>
      <math:mfenced>
      <xsl:apply-templates select="*[2]"/>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='linalg1'  and @name='matrix_selector']]|OMA[OMS[@cd='linalg1'  and @name='matrix_selector']]">
   <math:msub>
    <xsl:apply-templates select="*[4]"/>
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
   </math:msub>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='linalg1'  and @name='outerproduct']]|OMA[OMS[@cd='linalg1'  and @name='outerproduct']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <!-- U+2297 Circled Times-->
      <math:mo>&#x2297;</math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='linalg1'  and @name='scalarproduct']]|OMA[OMS[@cd='linalg1'  and @name='scalarproduct']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <!-- use the same symbol as times -->
      <xsl:variable name='times'>
        <om:OMS cd='arith1' name='times'/>
      </xsl:variable>
      <xsl:apply-templates select="$times/*"/>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='transpose' and @cd='linalg1']]|OMA[OMS[@name='transpose' and @cd='linalg1']]">
    <math:msup>
      <xsl:apply-templates select="*[2]"/>
      <math:mi>T</math:mi>
    </math:msup>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='linalg1'  and @name='outerproduct']]|OMA[OMS[@cd='linalg1'  and @name='outerproduct']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <!-- U+2297 Circled Times-->
      <math:mo>&#x2297;</math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='linalg1'  and @name='vector_selector']]|OMA[OMS[@cd='linalg1'  and @name='vector_selector']]">
    <math:msub>
      <xsl:apply-templates select="*[3]"/>
      <xsl:apply-templates select="*[2]"/>
   </math:msub>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='linalg1'  and @name='vectorproduct']]|OMA[OMS[@cd='linalg1'  and @name='vectorproduct']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <!-- U+2A2F vector or cross product -->
      <math:mo>&#x2A2F;</math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       linalg2

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@name='matrix' and @cd='linalg2']]|OMA[OMS[@name='matrix' and @cd='linalg2']]">
    <math:mrow>
      <math:mfenced open="(" close=")" class="linalg2matrix">
        <math:mtable>
          <xsl:for-each select="*[position()&gt;1]">
            <xsl:apply-templates select="."/>
          </xsl:for-each>
        </math:mtable>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='matrixrow' and @cd='linalg2']]|OMA[OMS[@name='matrixrow' and @cd='linalg2']]">
    <xsl:choose>
      <xsl:when test="../om:OMS[@name='matrix' and @cd='linalg2']| ../OMS[@name='matrix' and @cd='linalg2']">
        <math:mtr>
          <xsl:for-each select="*[position()&gt;1]">
            <math:mtd columnalign="center">
              <xsl:apply-templates select="."/>
            </math:mtd>
          </xsl:for-each>
        </math:mtr>
      </xsl:when>
      <xsl:otherwise>
        <math:mfenced open="(" close=")" separators=",">
          <xsl:for-each select="*[position()&gt;1]">
            <math:mrow>
              <xsl:apply-templates select="."/>
            </math:mrow>
          </xsl:for-each>
        </math:mfenced>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='vector' and @cd='linalg2']]|OMA[OMS[@name='vector' and @cd='linalg2']]">
    <math:mfenced open="(" close=")" separators="," class="linalg2vector">
      <xsl:for-each select="*[position()&gt;1]">
        <math:mrow>
          <xsl:apply-templates select="."/>
        </math:mrow>
      </xsl:for-each>
    </math:mfenced>
  </xsl:template>

  <!-- ********************************************************************

       linalg3

       ******************************************************************** -->

  <xsl:template match="OMA[OMS[@name='matrix' and @cd='linalg3']]|om:OMA[om:OMS[@name='matrix' and @cd='linalg3']]">
    <math:mfenced open="(" close=")" separators="," class="linalg3matrix">
      <math:mtable>
        <math:mtr>
          <xsl:for-each select="*[position()&gt;1]">
            <math:mtd columnalign="center">
              <xsl:apply-templates select="."/>
            </math:mtd>
          </xsl:for-each>
        </math:mtr>
      </math:mtable>
    </math:mfenced>
  </xsl:template>

  <xsl:template match="OMA[OMS[@name='matrixcolumn' and @cd='linalg3']]|om:OMA[om:OMS[@name='matrixcolumn' and @cd='linalg3']]">
    <math:mtable>
      <xsl:for-each select="*[position()&gt;1]">
        <math:mtr>
          <math:mtd>
            <xsl:apply-templates select="."/>
          </math:mtd>
        </math:mtr>
      </xsl:for-each>
    </math:mtable>
  </xsl:template>

  <xsl:template match="OMA[OMS[@name='vector' and @cd='linalg3']]|om:OMA[om:OMS[@name='vector' and @cd='linalg3']]">
    <math:mfenced open="(" close=")" separators="," class="linalg3vector">
      <math:mtable>
        <xsl:for-each select="*[position()&gt;1]">
          <math:mtr>
            <math:mtd>
              <xsl:apply-templates select="."/>
            </math:mtd>
          </math:mtr>
        </xsl:for-each>
      </math:mtable>
    </math:mfenced>
  </xsl:template>


  <!-- ********************************************************************

       linalg6

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@name='matrix_tensor' and @cd='linalg6']]|OMA[OMS[@name='matrix_tensor' and @cd='linalg6']]">
    <math:mrow>
<xsl:for-each select="*[position()&gt;1]"><xsl:apply-templates select="."/><xsl:if test="position() &lt; last()"><math:mo>&#8855;</math:mo></xsl:if></xsl:for-each>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='vector_tensor' and @cd='linalg6']]|OMA[OMS[@name='vector_tensor' and @cd='linalg6']]">
    <math:mrow>
<xsl:for-each select="*[position()&gt;1]"><xsl:apply-templates select="."/><xsl:if test="position() &lt; last()"><math:mo>&#8855;</math:mo></xsl:if></xsl:for-each>
    </math:mrow>
  </xsl:template>


  <!-- ********************************************************************

       list1 (partial implementation)

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@name='list' and @cd='list1']]|OMA[OMS[@name='list' and @cd='list1']]">
    <math:mrow>
      <math:mfenced open="[" close="]" separators="{mdf:interval-separators(.)}">
        <xsl:for-each select="*[position()&gt;1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='list1' and @name='suchthat']]|OMA[OMS[@cd='list1' and @name='suchthat']]">
      <math:mo>[</math:mo>
        <xsl:for-each select="om:OMBIND/om:OMBVAR/*|OMBIND/OMBVAR/*">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
        <math:mo>&#8712;</math:mo>
        <xsl:apply-templates select="*[2]"/>
        <math:mo>  </math:mo>        <math:mo> | </math:mo>        <math:mo>  </math:mo>
        <xsl:apply-templates select="om:OMBIND/*[3]|OMBIND/*[3]"/>
      <math:mo>]</math:mo>
  </xsl:template>


<!--TODO: implement map-->
  <!--xsl:template match="OMA[OMS[@name='map' and @cd='list1']]">
    <math:mrow>
      <math:mfenced open="[" close="]" separators=",">
        <xsl:for-each select="*[position()>1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template-->

  <!-- *****************************************************************
       list2 version 4 revision 1
       append, cons, first, in, list_selector, nil, rest, reverse, size
       ***************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='list2' and @name='append']]|OMA[OMS[@cd='list2' and @name='append']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>
        <!-- U+222A union -->
        <xsl:text>&#x222A;</xsl:text>
      </math:mo>
      <math:mo>
        <xsl:text>[</xsl:text>
      </math:mo>
      <xsl:apply-templates select="*[3]"/>
      <math:mo>
        <xsl:text>]</xsl:text>
      </math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='list2' and @name='cons']]|OMA[OMS[@cd='list2' and @name='cons']]">
    <math:mrow>
      <math:mi>
        <xsl:text>cons</xsl:text>
      </math:mi>
      <math:mfenced open="(" close=")" separators=",">
        <xsl:apply-templates select="*[position() &gt; 1]"/>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='list2' and @name='first']]|OMA[OMS[@cd='list2' and @name='first']]">
    <math:mrow>
      <math:mi>
        <xsl:text>first</xsl:text>
      </math:mi>
      <xsl:apply-templates select="*[2]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='list2' and @name='in']]|OMA[OMS[@cd='list2' and @name='in']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>
        <!-- U+2208 element of -->
        <xsl:text>&#x2208;</xsl:text>
      </math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='list2' and @name='list_selector']]|OMA[OMS[@cd='list2' and @name='list_selector']]">
    <math:msub>
      <xsl:apply-templates select="*[3]"/>
      <xsl:apply-templates select="*[2]"/>
    </math:msub>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='list2' and @name='nil']|OMS[@cd='list2' and @name='nil']">
    <math:mo>
      <!-- U+2205 empty set -->
      <xsl:text>&#x2205;</xsl:text>
    </math:mo>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='list2' and @name='rest']]|OMA[OMS[@cd='list2' and @name='rest']]">
    <math:mrow>
      <math:mi>
        <xsl:text>rest</xsl:text>
      </math:mi>
      <xsl:apply-templates select="*[2]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='list2' and @name='reverse']]|OMA[OMS[@cd='list2' and @name='reverse']]">
    <math:mrow>
      <math:mi>
        <xsl:text>reverse</xsl:text>
      </math:mi>
      <xsl:apply-templates select="*[2]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='list2' and @name='size']]|OMA[OMS[@cd='list2' and @name='size']]">
    <math:mrow>
      <math:mi>
        <xsl:text>size</xsl:text>
      </math:mi>
      <xsl:apply-templates select="*[2]"/>
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       list3

       ******************************************************************** -->



<xsl:template match="om:OMA[om:OMS[@name='append' and @cd='list3']]|OMA[OMS[@name='append' and @cd='list3']]">
    <math:mrow>
          <xsl:apply-templates select="*[2]"/>
          <math:mo>&#8746;</math:mo>
          <math:mo>[</math:mo>
            <xsl:apply-templates select="*[3]"/>
          <math:mo>]</math:mo>
     </math:mrow>
  </xsl:template>

<xsl:template match="om:OMA[om:OMS[@name='concatenate' and @cd='list3']]|OMA[OMS[@name='concatenate' and @cd='list3']]">
 <math:mrow>
  <xsl:apply-templates select="*[2]"/><math:mo>&#8746;</math:mo>
  <xsl:apply-templates select="*[3]"/>
 </math:mrow>
</xsl:template>



  <xsl:template match="om:OMA[om:OMS[@name='length' and @cd='list3']]|OMA[OMS[@name='length' and @cd='list3']]">
      <math:mrow>
          <math:mo>Length</math:mo>
          <math:mi>(</math:mi>
          <xsl:apply-templates select="*[2]"/>
          <math:mi>)</math:mi>
      </math:mrow>
  </xsl:template>

<!--not a symbol in list3
<xsl:template match="OMA[OMS[@name='prepend' and @cd='list3']]">
    <math:mrow>
          <xsl:apply-templates select="*[3]"/><math:mo>&#x222A;</math:mo>  [<xsl:apply-templates select="*[2]"/>
</math:mrow>]
  </xsl:template>
-->

  <xsl:template match="om:OMA[om:OMS[@cd='list3' and @name='list_selector']]|OMA[OMS[@cd='list3' and @name='list_selector']]">
    <math:mrow>
      <math:msub>
        <xsl:apply-templates select="*[3]"/>
        <xsl:apply-templates select="*[2]"/>
      </math:msub>
    </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@name='select']]|OMA[OMS[@name='select']]">
    <math:mrow>
      <math:msub>
        <xsl:apply-templates select="*[2]"/>
          <math:mo>{</math:mo>
           <xsl:apply-templates select="*[2]"/>
          <math:mo>}</math:mo>
      </math:msub>
    </math:mrow>
  </xsl:template>



  <xsl:template match="om:OMA[om:OMS[@cd='list3' and @name='in']]|OMA[OMS[@cd='list3' and @name='in']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>&#8712;</math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>


  <!-- ********************************************************************

       list4

       ******************************************************************** -->


  <xsl:template match="om:OMA[om:OMS[@name='entry' and @cd='list4']]|OMA[OMS[@name='entry' and @cd='list4']]">
   <math:mrow>
     <xsl:apply-templates select="*[2]"/>[<xsl:apply-templates select="*[3]"/>]
   </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@name='reverse' and @cd='list4']]|OMA[OMS[@name='reverse' and @cd='list4']]">
      <math:mrow>
          <math:mo>Reverse</math:mo>
          <math:mi>(</math:mi>
          <xsl:apply-templates select="*[2]"/>
          <math:mi>)</math:mi>
      </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@name='difference' and @cd='list4']]|OMA[OMS[@name='difference' and @cd='list4']]">
      <math:mrow>
          <xsl:apply-templates select="*[2]"/>
          <math:mi>\</math:mi>
          <xsl:apply-templates select="*[3]"/>
      </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@name='list_of_lengthn' and @cd='list4']]|OMA[OMS[@name='list_of_lengthn' and @cd='list4']]">
      <math:mrow>
          <xsl:apply-templates select="*[3]"/>
          <math:mo> (of length </math:mo>
          <xsl:apply-templates select="*[2]"/>
          <math:mo>)</math:mo>
      </math:mrow>
  </xsl:template>

<!--TODO: implement remove with a suchthat construct-->



  <!-- ********************************************************************

       logic1 version 3
       symbols: and, equivalent, false, implies, not, or, true, xor

       ******************************************************************** -->

  <xsl:template name="logic1_attribute">
    <xsl:param name="attr" as="node()"/>

    <!-- 
      no brackets when attribute is
      - OMV
      - logic1.false, logic1.true
      - logic1.not
    -->
    <xsl:choose>
      <xsl:when test="$attr/self::OMV|$attr/self::om:OMV">
        <xsl:apply-templates select="$attr"/>
      </xsl:when>
      <xsl:when test="$attr/self::OMS[@cd='logic1' and (@name='true' or @name='false')] | 
        $attr/self::om:OMS[@cd='logic1' and (@name='true' or @name='false')]"
      >
        <xsl:apply-templates select="$attr"/>
      </xsl:when>
      <xsl:when test="$attr/self::OMA[OMS[@cd='logic1' and @name='not']] | 
        $attr/self::om:OMA[om:OMS[@cd='logic1' and @name='not']]"
      >
        <xsl:apply-templates select="$attr"/>
      </xsl:when>
      <xsl:otherwise>
        <math:mo>(</math:mo>
        <xsl:apply-templates select="$attr"/>
        <math:mo>)</math:mo>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='logic1' and @name='and']]|OMA[OMS[@cd='logic1' and @name='and']]">
    <math:mrow>
      <xsl:for-each select="*[position()&gt;1 and position() &lt; last()]">
        <xsl:call-template name="logic1_attribute">
          <xsl:with-param name="attr" select="."/>
        </xsl:call-template>
        <math:mo>
          <xsl:text>&#8743;</xsl:text>
        </math:mo>
        <!-- 8743 = U+2227 logical and -->
      </xsl:for-each>
      <xsl:call-template name="logic1_attribute">
        <xsl:with-param name="attr" select="*[last()]"/>
      </xsl:call-template>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='logic1' and @name='equivalent']]|OMA[OMS[@cd='logic1' and @name='equivalent']]">
    <math:mrow>
      <xsl:call-template name="logic1_attribute">
        <xsl:with-param name="attr" select="*[2]"/>
      </xsl:call-template>
      <xsl:choose>
        <xsl:when test="$openmath2mathml.logic1.equivalent.style='arrow'">
          <math:mo>
            <!-- U+21D4 left right double arrow -->
            <xsl:text>&#x21D4;</xsl:text>
          </math:mo>
        </xsl:when>
        <xsl:when test="$openmath2mathml.logic1.equivalent.style='lines'">
          <math:mo>
            <!-- U+2261 identical to -->
            <xsl:text>&#x2261;</xsl:text>
          </math:mo>
        </xsl:when>
        <xsl:otherwise>
          <math:mo>
            <!-- U+21D4 left right double arrow -->
            <xsl:text>&#x21D4;</xsl:text>
          </math:mo>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:call-template name="logic1_attribute">
        <xsl:with-param name="attr" select="*[3]"/>
      </xsl:call-template>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='logic1' and @name='implies']]|OMA[OMS[@cd='logic1' and @name='implies']]">
    <math:mrow>
      <xsl:call-template name="logic1_attribute">
        <xsl:with-param name="attr" select="*[2]"/>
      </xsl:call-template>
      <math:mo>&#8658;</math:mo>
      <xsl:call-template name="logic1_attribute">
        <xsl:with-param name="attr" select="*[3]"/>
      </xsl:call-template>
    </math:mrow>
  </xsl:template>

 <xsl:template match="om:OMA[om:OMS[@cd='logic1' and @name='or']]|OMA[OMS[@cd='logic1' and @name='or']]">
    <math:mrow>
      <xsl:for-each select="*[position()&gt;1 and position() &lt; last()]">
        <xsl:call-template name="logic1_attribute">
          <xsl:with-param name="attr" select="."/>
        </xsl:call-template>
        <math:mo>
          <!-- 8744 = U+2228 logical or -->
          <xsl:text>&#8744;</xsl:text>
        </math:mo>
      </xsl:for-each>
      <xsl:call-template name="logic1_attribute">
        <xsl:with-param name="attr" select="*[last()]"/>
      </xsl:call-template>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='logic1' and @name='not']]|OMA[OMS[@cd='logic1' and @name='not']]">
    <math:mrow>
      <xsl:choose>
        <xsl:when test="*[2]/self::om:OMBIND/om:OMS[position()=1 and @cd='quant1' and @name='exists']|*[2]/self::OMBIND/OMS[position()=1 and @cd='quant1' and @name='exists']">
          <math:mo>&#8708;</math:mo>
          <math:mfenced open="" close="" separators=",">
            <xsl:for-each select="*[2]/om:OMBVAR/om:OMV|*[2]/OMBVAR/OMV">
              <xsl:apply-templates select="."/>
            </xsl:for-each>
          </math:mfenced>
          <math:mo>.</math:mo>
          <xsl:apply-templates select="*[2]/*[3]"/>
        </xsl:when>
        <xsl:when test="*[2]/self::om:OMA/om:OMS[position()=1 and @cd='logic1' and @name='implies']|*[2]/self::OMA/OMS[position()=1 and @cd='logic1' and @name='implies']">
          <math:mrow>
            <xsl:call-template name="logic1_attribute">
              <xsl:with-param name="attr" select="*[2]/*[2]"/>
            </xsl:call-template>
            <math:mo>&#8655;</math:mo>
            <xsl:call-template name="logic1_attribute">
              <xsl:with-param name="attr" select="*[2]/*[3]"/>
            </xsl:call-template>
          </math:mrow>
        </xsl:when>
        <xsl:otherwise>
          <math:mo>&#172;</math:mo>
          <xsl:call-template name="logic1_attribute">
            <xsl:with-param name="attr" select="*[2]"/>
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='logic1' and @name='false']|OMS[@cd='logic1' and @name='false']">
    <math:mo>false</math:mo>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='logic1' and @name='true']|OMS[@cd='logic1' and @name='true']">
    <math:mo>true</math:mo>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='logic1' and @name='xor']]|OMA[OMS[@cd='logic1' and @name='xor']]">
    <math:mrow>
      <xsl:call-template name="logic1_attribute">
        <xsl:with-param name="attr" select="*[2]"/>
      </xsl:call-template>
      <math:mo>
        <!-- U+22BB xor -->
        <xsl:text>&#x22BB;</xsl:text>
      </math:mo>
      <xsl:call-template name="logic1_attribute">
        <xsl:with-param name="attr" select="*[3]"/>
      </xsl:call-template>
    </math:mrow>
  </xsl:template>

  <!-- *******************************************************************

       minmax1

       ******************************************************************* -->


  <xsl:template match="om:OMA[om:OMS[@cd='minmax1' and @name='max']]|OMA[OMS[@cd='minmax1' and @name='max']]">
    <math:mrow>
      <math:mi>max</math:mi>
      <math:mfenced open="(" close=")" separators=",">
        <xsl:for-each select="*[position()&gt;1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='minmax1' and @name='min']]|OMA[OMS[@cd='minmax1' and @name='min']]">
    <math:mrow>
      <math:mi>min</math:mi>
      <math:mfenced open="(" close=")" separators=",">
        <xsl:for-each select="*[position()&gt;1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <!-- *******************************************************************

       monoid1

       ******************************************************************* -->


  <xsl:template match="om:OMA[om:OMS[@name='identity']]|OMA[OMS[@name='identity']]">
    <math:msub>
      <math:mi>1</math:mi>
      <xsl:apply-templates select="*[2]"/>
    </math:msub>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@name='invertibles']]|OMA[OMS[@name='invertibles']]">
    <math:msup>
        <!--<math:mfenced open="(" close=")" separators=",">-->
           <xsl:apply-templates select="*[2]"/>
        <!--</math:mfenced>-->
        <math:mo>&#215;</math:mo>
    </math:msup>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='monoid1' and @name='monoid']]|OMA[OMS[@cd='monoid1' and @name='monoid']]">
    <math:mrow>
      <math:mfenced open="[" close="]" separators=",">
        <xsl:for-each select="*[position()&gt;1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='monoid1' and @name='submonoid']]|OMA[OMS[@cd='monoid1' and @name='submonoid']]">
    <math:msub>
      <math:mrow>
        <xsl:choose>
          <xsl:when test='$openmath2mathml.mathml3_entities'>
            <!-- U+27E8 Mathematical left angle bracket -->
            <math:mo>&#x27E8;</math:mo>
          </xsl:when>
          <xsl:otherwise>
            <!-- U+2329 left-pointing angle bracket -->
            <math:mo>&#x2329;</math:mo>
          </xsl:otherwise>
        </xsl:choose> 
        <xsl:apply-templates select="*[3]"/>
        <xsl:choose>
          <xsl:when test='$openmath2mathml.mathml3_entities'>
            <!-- U+27E9 Mathematical right angle bracket -->
            <math:mo>&#x27E9;</math:mo>
          </xsl:when>
          <xsl:otherwise>
            <xsl:choose>
              <xsl:when test='$openmath2mathml.mathml3_entities'>
                <!-- U+27E9 Mathematical right angle bracket -->
                <math:mo>&#x27E9;</math:mo>
              </xsl:when>
              <xsl:otherwise>
                <!-- U+232A right-pointing angle bracket -->
                <math:mo>&#x232A;</math:mo>
              </xsl:otherwise>
            </xsl:choose> 
          </xsl:otherwise>
        </xsl:choose> 
      </math:mrow>
      <math:mi>
        <xsl:apply-templates select="*[2]"/>
      </math:mi>
    </math:msub>
  </xsl:template>


  <!-- ********************************************************************

       monoid3

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='monoid3' and @name='cyclic_monoid']]|OMA[OMS[@cd='monoid3' and @name='cyclic_monoid']]">
    <math:msub>
      <math:mi>C</math:mi>
      <math:mfenced open="" close="" separators=",">
        <xsl:apply-templates select="*[2]"/>
        <xsl:apply-templates select="*[3]"/>
      </math:mfenced>
    </math:msub>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='monoid3' and @name='maps_monoid']]|OMA[OMS[@cd='monoid3' and @name='maps_monoid']]">
    <math:mrow>
      <math:mi>Maps</math:mi>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@cd='monoid3' and @name='free_monoid']]|OMA[OMS[@cd='monoid3' and @name='free_monoid']]">
    <math:mrow>
      <math:mi>F</math:mi>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@cd='monoid3' and @name='strings']]|OMA[OMS[@cd='monoid3' and @name='strings']]">
    <math:mrow>
      <math:mi>Words</math:mi>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='monoid3' and @name='emptyword']|OMS[@cd='monoid3' and @name='emptyword']">
    <math:mrow>
      <math:mo>&#1013;</math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='monoid3' and @name='concatenation']|OMS[@cd='monoid3' and @name='concatenation']">
    <math:mo>
      <xsl:text>o</xsl:text>
    </math:mo>
  </xsl:template>

  <!-- ********************************************************************

       notation1

       ********************************************************************

  <xsl:template match="OMA[OMS[@cd='notation1' and @name='and']]">
    <math:mrow>
      <math:mfenced open="" close="" separators=",">
        <xsl:for-each select="*[position()>1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="OMA[OMS[@cd='notation1' and @name='chain_relation']]">
    <math:mrow>
      <xsl:for-each select="*[position()>1]">
        <xsl:apply-templates select="."/>
      </xsl:for-each>
    </math:mrow>
  </xsl:template>

  <xsl:template match="OMA[OMS[@cd='notation1' and @name='function']]">
    <math:mrow>
      <math:mi><xsl:value-of select="*[2]"/></math:mi>
      <math:mfenced open="(" close=")" separators=",">
        <xsl:for-each select="*[position()>2]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="OMA[OMS[@cd='notation1' and @name='list']]">
    <math:mrow>
      <math:mfenced open="[" close="]" separators=",">
        <xsl:for-each select="*[position()>1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="OMA[OMS[@name='sequence']]">
    <math:mrow>
      <math:mfenced open="" close="" separators=",">
        <xsl:for-each select="*[position()>1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="OMA[OMS[@cd='notation1' and @name='similar']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>&#x223C;</math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

<xsl:template match="OMA[OMS[@cd='notation1' and @name='string']]">
    <math:mrow>
        <xsl:for-each select="*[position()>1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
    </math:mrow>
  </xsl:template>

  <xsl:template
    match="OMA[OMS[@cd='notation1' and @name='in']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>&#x2208;</math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>



  <xsl:template match="OMS[@cd='notation2' and @name='ldots']">
    <math:mo>...</math:mo>
  </xsl:template>
  -->
  <!-- ********************************************************************

       nums1

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='nums1' and @name='based_integer']]|OMA[OMS[@cd='nums1' and @name='based_integer']]">
    <math:mrow>
          <math:msub>
            <math:mrow>[<xsl:apply-templates select="*[3]"/>]</math:mrow>
            <math:mrow><xsl:apply-templates select="*[2]"/>
            </math:mrow>
          </math:msub>
        </math:mrow>
  </xsl:template>



  <xsl:template match="om:OMS[@cd='nums1' and @name='e']|OMS[@cd='nums1' and @name='e']">
    <math:mrow>
      <math:mi mathvariant="normal">
        <xsl:text>e</xsl:text>
      </math:mi>
    </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMS[@cd='nums1' and @name='i']|OMS[@cd='nums1' and @name='i']">
    <math:mrow>
      <!-- U+2148 double-struck italic small i -->
      <math:mi>&#x2148;</math:mi>
    </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMS[@cd='nums1' and @name='infinity']|OMS[@cd='nums1' and @name='infinity']">
    <math:mrow>
      <!-- U+221E infinity -->
      <math:mi>&#x221E;</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='nums1' and @name='pi']|OMS[@cd='nums1' and @name='pi']">
    <math:mrow>
      <!-- U+03C0 greek small letter pi -->
      <math:mi>&#x03C0;</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='nums1' and @name='rational']]|OMA[OMS[@cd='nums1' and @name='rational']]">
    <xsl:choose>
      <xsl:when test="@style='slash'">
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
          <math:mo>/</math:mo>
          <xsl:apply-templates select="*[3]"/>
        </math:mrow>
      </xsl:when>
      <xsl:otherwise>
        <math:mrow>
          <math:mfrac>
            <xsl:apply-templates select="*[2]"/>
            <xsl:apply-templates select="*[3]"/>
          </math:mfrac>
        </math:mrow>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- ********************************************************************

       permgp1

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='permgp1' and @name='stabilizer']]|OMA[OMS[@cd='permgp1' and @name='stabilizer']]">
    <math:mrow>
      <math:msub>
        <xsl:apply-templates select="*[2]"/>
        <math:mfenced open="" close="" separators=",">
          <xsl:for-each select="*[position()&gt;2]">
            <xsl:apply-templates select="."/>
          </xsl:for-each>
        </math:mfenced>
      </math:msub>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='permgp1' and @name='orbit']]|OMA[OMS[@cd='permgp1' and @name='orbit']]">
    <math:mrow>
        <xsl:apply-templates select="*[2]"/>
        <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='permgp1' and @name='generators']]|OMA[OMS[@cd='permgp1' and @name='generators']]">
    <math:mrow>
           <math:mo>Generators</math:mo>
        <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>



  <xsl:template match="om:OMA[om:OMS[@cd='permgp1' and @name='group']]|OMA[OMS[@cd='permgp1' and @name='group']]">
    <math:mrow>
      <xsl:choose>
        <xsl:when test='$openmath2mathml.mathml3_entities'>
          <!-- U+27E8 Mathematical left angle bracket -->
          <math:mo>&#x27E8;</math:mo>
        </xsl:when>
        <xsl:otherwise>
          <!-- U+2329 left-pointing angle bracket -->
          <math:mo>&#x2329;</math:mo>
        </xsl:otherwise>
      </xsl:choose> 
      <math:mfenced open="" close="" separators=",">
        <xsl:for-each select="*[position()&gt;2]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
      <xsl:choose>
        <xsl:when test='$openmath2mathml.mathml3_entities'>
          <!-- U+27E9 Mathematical right angle bracket -->
          <math:mo>&#x27E9;</math:mo>
        </xsl:when>
        <xsl:otherwise>
          <!-- U+232A right-pointing angle bracket -->
          <math:mo>&#x232A;</math:mo>
        </xsl:otherwise>
      </xsl:choose> 
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       permgp2

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='permgp2' and @name='symmetric_group']]|OMA[OMS[@cd='permgp2' and @name='symmetric_group']]">
    <xsl:choose>
      <xsl:when test="@style='sub'">
        <math:mrow>
          <math:msub>
            <math:mi>Sym</math:mi>
            <xsl:apply-templates select="*[2]"/>
          </math:msub>
        </math:mrow>
      </xsl:when>
      <xsl:otherwise>
        <math:mrow>
          <math:mi>Sym</math:mi>
          <math:mi>(</math:mi>
          <xsl:apply-templates select="*[2]"/>
          <math:mi>)</math:mi>
        </math:mrow>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='permgp2' and @name='dihedral_group']]|OMA[OMS[@cd='permgp2' and @name='dihedral_group']]">
    <math:mrow>
      <math:msub>
        <math:mi>D</math:mi>
        <xsl:apply-templates select="*[2]"/>
      </math:msub>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='permgp2' and @name='quaternion_group']]|OMA[OMS[@cd='permgp2' and @name='quaternion_group']]">
    <math:mrow>
      <math:msub>
        <math:mi>Q</math:mi>
        <xsl:apply-templates select="*[2]"/>
      </math:msub>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='alternating_group']]|OMA[OMS[@name='alternating_group']]">
    <math:mrow>
      <math:mi>Alt</math:mi>
      <math:mi>(</math:mi>
      <xsl:apply-templates select="*[2]"/>
      <math:mi>)</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='alternating_groupn']]|OMA[OMS[@name='alternating_groupn']]">
    <math:msub>
      <math:mi>Alt</math:mi>
      <xsl:apply-templates select="*[2]"/>
    </math:msub>
  </xsl:template>

  <!-- *******************************************************************

       permutation1

       ******************************************************************* -->

  <xsl:template match="om:OMA[om:OMS[@cd='permutation1' and @name='action']]|OMA[OMS[@cd='permutation1' and @name='action']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mi>(</math:mi>
      <xsl:apply-templates select="*[3]"/>
      <math:mi>)</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='permutation1' and @name='cycle']]|OMA[OMS[@cd='permutation1' and @name='cycle']]">
    <math:mrow>
      <math:mfenced open="(" close=")" separators=",">
        <xsl:for-each select="*[position()&gt;1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='endomap' or @name='list_perm']]|OMA[OMS[@name='endomap' or @name='list_perm']]">
    <math:mrow>
      <math:mfenced open="[" close="]" separators=",">
        <xsl:for-each select="*[position()&gt;1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@cd='permutation1' and @name='permutation']]|OMA[OMS[@cd='permutation1' and @name='permutation']]">
    <xsl:choose>
      <xsl:when test="*[position()=1]">
        <math:mrow>
          <xsl:for-each select="*[position()&gt;1]">
            <xsl:apply-templates select="."/>
          </xsl:for-each>
        </math:mrow>
      </xsl:when>
      <xsl:otherwise>
        <math:mrow>
          <math:mi>()</math:mi>
        </math:mrow>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='permutation1' and @name='sign']]|OMA[OMS[@cd='permutation1' and @name='sign']]">
    <math:mrow>
      <math:mi>sign</math:mi>
      <math:mi>(</math:mi>
      <xsl:apply-templates select="*[2]"/>
      <math:mi>)</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='permutation1' and @name='support']]|OMA[OMS[@cd='permutation1' and @name='support']]">
    <math:mrow>
      <math:mi>Support</math:mi>
      <math:mi>(</math:mi>
      <xsl:apply-templates select="*[2]"/>
      <math:mi>)</math:mi>
    </math:mrow>
  </xsl:template>

  <!-- *******************************************************************

       quant1

       ******************************************************************* -->

  <xsl:template match="om:OMBIND[om:OMS[@cd='quant1' and @name='forall']]|OMBIND[OMS[@cd='quant1' and @name='forall']]">
    <math:mrow>
      <math:mo>&#8704;</math:mo>
      <math:mfenced open="" close="." separators=",">
        <xsl:for-each select="om:OMBVAR/om:OMV|OMBVAR/OMV">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
      <math:mi> </math:mi>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMBIND[om:OMS[@cd='quant1' and @name='exists']]|OMBIND[OMS[@cd='quant1' and @name='exists']]">
    <math:mrow>
      <math:mo>&#8707;</math:mo>
      <math:mfenced open="" close="." separators=",">
        <xsl:for-each select="om:OMBVAR/om:OMV|OMBVAR/OMV">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
      <math:mi> </math:mi>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>


  <!-- ********************************************************************

       polyd1

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='polyd1' and @name='poly_ring_d_named']]|OMA[OMS[@cd='polyd1' and @name='poly_ring_d_named']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
        <math:mo>[</math:mo>
<xsl:for-each select="*[position()&gt;2]"><xsl:apply-templates select="."/><xsl:if test="position() &lt; last()"><math:mo>,</math:mo></xsl:if></xsl:for-each>
        <math:mo>]</math:mo>
    </math:mrow>
  </xsl:template>


  <!-- ********************************************************************

       polynomial1

       ******************************************************************** -->

  <!--
    coefficient
  -->
  <xsl:template match="om:OMS[@cd='polynomial1' and @name='coefficient'] |
    OMS[@cd='polynomial1' and @name='coefficient']"
  >
    <math:mrow>
      <math:mi>
        <xsl:text>coefficient</xsl:text>
      </math:mi>
    </math:mrow>
  </xsl:template>

  <!--
    coefficient_ring
  -->
  <xsl:template match="om:OMS[@cd='polynomial1' and @name='coefficient_ring'] |
    OMS[@cd='polynomial1' and @name='coefficient_ring']"
  >
    <math:mrow>
      <math:mi>
        <xsl:text>coefficient_ring</xsl:text>
      </math:mi>
    </math:mrow>
  </xsl:template>

  <!--
    degree
  -->
  <xsl:template match="om:OMA[om:OMS[@name='degree']]|OMA[OMS[@name='degree']]">
    <math:mrow>
      <math:mi>degree</math:mi>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <!--
    expand
  -->
  <xsl:template match="om:OMS[@cd='polynomial1' and @name='expand'] |
    OMS[@cd='polynomial1' and @name='expand']"
  >
    <math:mrow>
      <math:mi>
        <xsl:text>expand</xsl:text>
      </math:mi>
    </math:mrow>
  </xsl:template>

  <!--
    leading_coefficient
  -->
  <xsl:template match="
    om:OMS[@cd='polynomial1' and @name='leading_coefficient'] |
    OMS[@cd='polynomial1' and @name='leading_coefficient']"
  >
    <math:mrow>
      <math:mi>
        <xsl:text>lc</xsl:text>
      </math:mi>
    </math:mrow>
  </xsl:template>

  <!--
    leading_monomial
  -->
  <xsl:template match="
    om:OMS[@cd='polynomial1' and @name='leading_monomial'] |
    OMS[@cd='polynomial1' and @name='leading_monomial']"
  >
    <math:mrow>
      <math:mi>
        <xsl:text>lm</xsl:text>
      </math:mi>
    </math:mrow>
  </xsl:template>

  <!--
    leading_term
  -->
  <xsl:template match="om:OMS[@cd='polynomial1' and @name='leading_term'] |
    OMS[@cd='polynomial1' and @name='leading_term']">
    <math:mrow>
      <math:mi>
        <xsl:text>lt</xsl:text>
      </math:mi>
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       polynomial3 (version 0)
       symbols: factors, gcd, quotient, remainder

       ******************************************************************** -->

  <!--
    use full name as text symbol
  -->
  <xsl:template match="om:OMS[@cd='polynomial3'] | OMS[@cd='polynomial3']"
  >
    <xsl:choose>
      <xsl:when test="not(empty(index-of(
        ('factors', 'gcd', 'quotient', 'remainder'), @name )))"
      >
        <math:mrow>
          <math:mi>
            <xsl:value-of select='@name'/>
          </math:mi>
        </math:mrow>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select='.' mode='generic'/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='polynomial3']] |
    OMA[OMS[@cd='polynomial3']]"
  >
    <xsl:variable name='name' select='*[1]/@name'/>

    <xsl:choose>
      <xsl:when test="not(empty(index-of(
        ('factors', 'gcd', 'quotient', 'remainder'), $name )))"
      >
        <math:mrow>
          <math:mi>
            <!-- 
              default: use the name
              for quotient, remainder: use an abbreviation
            -->
            <xsl:choose>
              <xsl:when test='$name="quotient"'>
                <xsl:text>quot</xsl:text>
              </xsl:when>
              <xsl:when test='$name="remainder"'>
                <xsl:text>rem</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select='$name'/>
              </xsl:otherwise>
            </xsl:choose>
          </math:mi>
    
          <math:mfenced open="(" close=")" separators=",">
            <xsl:apply-templates select='*[position() &gt; 1]'/>
          </math:mfenced>

        </math:mrow>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select='.' mode='generic'/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <!-- ********************************************************************

       relation1

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='relation1' and @name='eq']]|OMA[OMS[@cd='relation1' and @name='eq']]">
    <xsl:choose>
      <xsl:when test="@style='colon'">
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
          <math:mo>:</math:mo>
          <xsl:apply-templates select="*[3]"/>
        </math:mrow>
      </xsl:when>
         <xsl:when test="@style='multi'">
          <xsl:apply-templates select="*[2]"/>
        <xsl:for-each select="*[position() &gt; 2]">
       <math:mo>=</math:mo>    <xsl:apply-templates select="."/>
        </xsl:for-each>
         </xsl:when>
      <xsl:otherwise>
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
          <math:mo>=</math:mo>
          <xsl:apply-templates select="*[3]"/>
        </math:mrow>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='relation1' and @name='eq']|OMS[@cd='relation1' and @name='eq']">
    <math:mo>=</math:mo>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='relation1' and @name='geq']]|OMA[OMS[@cd='relation1' and @name='geq']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>&#8805;</math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='relation1' and @name='gt']]|OMA[OMS[@cd='relation1' and @name='gt']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>&gt;</math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='relation1' and @name='leq']]|OMA[OMS[@cd='relation1' and @name='leq']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>&#8804;</math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='relation1' and @name='lt']]|OMA[OMS[@cd='relation1' and @name='lt']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>&lt;</math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='relation1' and @name='neq']]|OMA[OMS[@cd='relation1' and @name='neq']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>&#8800;</math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='relation1' and @name='gt']|OMS[@cd='relation1' and @name='gt']">
    <math:mo>&gt;</math:mo>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='relation1' and @name='leq']|OMS[@cd='relation1' and @name='leq']">
    <math:mo>&#8804;</math:mo>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='relation1' and @name='lt']|OMS[@cd='relation1' and @name='lt']">
    <math:mo>&lt;</math:mo>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='relation1' and @name='approx']]|OMA[OMS[@cd='relation1' and @name='approx']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>&#8776;</math:mo>
      <!-- 8776 = U+2248 almost equal to -->
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       relation2

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@cd='relation2' and @name='approx']]|OMA[OMS[@cd='relation2' and @name='approx']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>
        <xsl:text>&#8776;</xsl:text>
        <!-- 8776 = U+2248 almost equal to -->
      </math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='relation2' and @name='eqs']]|OMA[OMS[@cd='relation2' and @name='eqs']]">
    <math:mrow>
    <math:mrow>          <xsl:apply-templates select="*[2]"/>    </math:mrow>
        <xsl:for-each select="*[position() &gt; 2]">
    <math:mrow>          <math:mo>=</math:mo>     </math:mrow>
    <math:mrow>          <xsl:apply-templates select="."/>     </math:mrow>
        </xsl:for-each>
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       relation4

       ******************************************************************** -->


  <xsl:template match="om:OMA[om:OMS[@cd='relation4' and @name='eqs']]|OMA[OMS[@cd='relation4' and @name='eqs']]">
    <math:mrow>
    <math:mrow>          <xsl:apply-templates select="*[2]"/>    </math:mrow>
        <xsl:for-each select="*[position() &gt; 2]">
    <math:mrow>          <math:mo>=</math:mo>     </math:mrow>
    <math:mrow>          <xsl:apply-templates select="."/>     </math:mrow>
        </xsl:for-each>
    </math:mrow>
  </xsl:template>
  <!-- *******************************************************************

       ring1

       ******************************************************************* -->

  <xsl:template match="om:OMA[om:OMS[@cd='ring1' and @name='ring']]|OMA[OMS[@cd='ring1' and @name='ring']]">
      <math:mfenced open="[" close="]" separators=",">
        <math:mrow> <xsl:apply-templates select="*[2]"/> </math:mrow>
        <math:mrow>         <xsl:apply-templates select="*[3]"/> </math:mrow>
        <math:mrow>         <xsl:apply-templates select="*[4]"/> </math:mrow>
        <math:mrow>         <xsl:apply-templates select="*[5]"/>  </math:mrow>
        <math:mrow>         <xsl:apply-templates select="*[6]"/>  </math:mrow>
        <math:mrow>         <xsl:apply-templates select="*[7]"/>  </math:mrow>
      </math:mfenced>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='ring1' and @name='subring']]|OMA[OMS[@cd='ring1' and @name='subring']]">
    <math:msub>
      <math:mrow>
        <xsl:choose>
          <xsl:when test='$openmath2mathml.mathml3_entities'>
            <!-- U+27E8 Mathematical left angle bracket -->
            <math:mo>&#x27E8;</math:mo>
          </xsl:when>
          <xsl:otherwise>
            <!-- U+2329 left-pointing angle bracket -->
            <math:mo>&#x2329;</math:mo>
          </xsl:otherwise>
        </xsl:choose> 
        <xsl:apply-templates select="*[3]"/>
        <xsl:choose>
          <xsl:when test='$openmath2mathml.mathml3_entities'>
            <!-- U+27E9 Mathematical right angle bracket -->
            <math:mo>&#x27E9;</math:mo>
          </xsl:when>
          <xsl:otherwise>
            <!-- U+232A right-pointing angle bracket -->
            <math:mo>&#x232A;</math:mo>
          </xsl:otherwise>
        </xsl:choose> 
      </math:mrow>
      <math:mi>
        <xsl:apply-templates select="*[2]"/>
      </math:mi>
    </math:msub>
  </xsl:template>

  <!-- *******************************************************************

       ring2

       ******************************************************************* -->

  <xsl:template match="om:OMA[om:OMS[@cd='ring2' and @name='left_multiplication']]|OMA[OMS[@cd='ring2' and @name='left_multiplication']]">
    <math:msub>
    <math:mo>L</math:mo>
        <xsl:apply-templates select="*[3]"/>
    </math:msub>
  </xsl:template>

  <!-- *******************************************************************

       ring3

       ******************************************************************* -->

  <xsl:template match="om:OMA[om:OMS[@cd='ring3' and @name='ideal']]|OMA[OMS[@cd='ring3' and @name='ideal']]">
  <xsl:choose>
   <xsl:when test="@style='bracket'">
      <math:mrow>
         (<xsl:for-each select="*[position()&gt;2]"><xsl:apply-templates select="."/><xsl:if test="position() &lt; last()"><math:mo>,</math:mo></xsl:if></xsl:for-each>)
      </math:mrow>
   </xsl:when>
   <xsl:otherwise>
    <math:mrow>
      {<xsl:for-each select="*[position()&gt;2]"><xsl:apply-templates select="."/><xsl:if test="position() &lt; last()"><math:mo>,</math:mo></xsl:if></xsl:for-each>}
      <xsl:apply-templates select="*[2]"/>
     </math:mrow>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:template>



  <xsl:template match="om:OMA[om:OMS[@cd='ring3' and @name='poly_ring']]|OMA[OMS[@cd='ring3' and @name='poly_ring']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
        <math:mo>[</math:mo>
      <xsl:apply-templates select="*[3]"/>
        <math:mo>]</math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='ring3' and @name='matrix_ring']]|OMA[OMS[@cd='ring3' and @name='matrix_ring']]">
    <math:mrow>
     <math:msub>
      <math:mo>M</math:mo>
      <xsl:apply-templates select="*[2]"/>
     </math:msub>
     <math:mo>(</math:mo>
     <xsl:apply-templates select="*[3]"/>
     <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@cd='ring3' and @name='m_poly_ring']]|OMA[OMS[@cd='ring3' and @name='m_poly_ring']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>


  <xsl:template match="om:OMA[om:OMS[@name='multiplicative_group']]|OMA[OMS[@name='multiplicative_group']]">
    <math:msup>
      <!--<math:mfenced open="(" close=")" separators=",">-->
        <xsl:apply-templates select="*[2]"/>
      <!--</math:mfenced>-->
      <math:mo>&#215;</math:mo>
    </math:msup>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='ring3' and @name='principal_ideal']]|OMA[OMS[@cd='ring3' and @name='principal_ideal']]">
  <xsl:choose>
   <xsl:when test="@style='brackets'">
      <math:mrow>
         (<xsl:apply-templates select="*[3]"/>)
      </math:mrow>
   </xsl:when>
   <xsl:otherwise>
    <math:mrow>
      (<xsl:apply-templates select="*[3]"/>)
      <xsl:apply-templates select="*[2]"/>
     </math:mrow>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:template>



  <xsl:template match="om:OMA[om:OMS[@cd='ring3' and @name='quotient_ring']]|OMA[OMS[@cd='ring3' and @name='quotient_ring']]">
    <math:mrow>
          <xsl:apply-templates select="*[2]"/>
          <math:mo>/</math:mo>
          <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <!-- *******************************************************************

       rounding1

       ******************************************************************* -->

  <xsl:template match="om:OMA[om:OMS[@cd='rounding1' and @name='ceiling']]|OMA[OMS[@cd='rounding1' and @name='ceiling']]">
    <math:mrow>
      <math:mi>sup</math:mi>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <!-- *******************************************************************

       semigroup1

       ******************************************************************* -->

  <xsl:template match="om:OMA[om:OMS[@cd='semigroup1' and @name='semigroup']]|OMA[OMS[@cd='semigroup1' and @name='semigroup']]">
    <math:mrow>
      <math:mo>[</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>,</math:mo>
      <xsl:apply-templates select="*[3]"/>
      <math:mo>]</math:mo>
    </math:mrow>
  </xsl:template>


  <!-- *******************************************************************

       semigroup3

       ******************************************************************* -->

  <xsl:template match="om:OMA[om:OMS[@cd='semigroup3' and @name='maps_semigroup']]|OMA[OMS[@cd='semigroup3' and @name='maps_semigroup']]">
    <math:mrow>
      <math:mo>Maps(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <!-- *******************************************************************

       set1

       ******************************************************************* -->

  <!-- put braces on arguments that are from set1 -->
  <xsl:template mode='set1'
    match='om:OMA[om:OMS[@cd="set1" and index-of(("carthesian_product", 
    "intersect", "union", "setdiff"),@name)]]|OMA[OMS[@cd="set1" and 
    index-of(("cartesian_product", "intersect", "union", "setdiff"),@name)]]' 
  >
    <!-- add opening bracket -->
    <xsl:text>(</xsl:text>

    <!-- apply the default template -->
    <xsl:apply-templates mode='#default' select='.'/>

    <!-- add closing bracket -->
    <xsl:text>)</xsl:text>
  </xsl:template>

  <!-- apply the default template -->
  <xsl:template match='*' mode='set1'>
    <xsl:apply-templates mode='#default' select='.'/>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set1' and @name='cartesian_product']]|OMA[OMS[@cd='set1' and @name='cartesian_product']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]" mode='set1'/>
      <xsl:for-each select="*[position()&gt;2]">
        <math:mo>
          <!-- U+00D7 Multiplication sign (Cartesian product) -->
          <xsl:text>&#x00D7;</xsl:text>
        </math:mo>
        <xsl:apply-templates select="." mode='set1'/>
      </xsl:for-each>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='set1' and @name='emptyset']|OMS[@cd='set1' and @name='emptyset']">
    <math:mrow>
      <math:mo>
        <!-- U+2205 empty set -->
        <xsl:text>&#x2205;</xsl:text>
      </math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set1' and @name='in']]|OMA[OMS[@cd='set1' and @name='in']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
        <math:mo>
          <!-- U+2208 element of -->
          <xsl:text>&#x2208;</xsl:text>
        </math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='set1' and @name='in']|OMS[@cd='set1' and @name='in']">
    <math:mo>
      <!-- U+2208 element of -->
      <xsl:text>&#x2208;</xsl:text>
    </math:mo>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set1' and @name='intersect']]|OMA[OMS[@cd='set1' and @name='intersect']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]" mode='set1'/>
      <xsl:for-each select="*[position()&gt;2]">
        <math:mo>
          <!-- U+2229 intersection -->
          <xsl:text>&#x2229;</xsl:text>
        </math:mo>
        <xsl:apply-templates select="." mode='set1'/>
      </xsl:for-each>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set1' and @name='map']]|OMA[OMS[@cd='set1' and @name='map']]">
    <math:mrow>
      <math:mo>
        <xsl:text>{</xsl:text>
      </math:mo>
      <xsl:apply-templates select="om:OMBIND/*[3]|OMBIND/*[3]"/>
      <math:mo>
        <xsl:text>|</xsl:text>
      </math:mo>
      <math:mrow>
        <xsl:for-each select="om:OMBIND/om:OMBVAR/*|OMBIND/OMBVAR/*">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
        <math:mo>
          <!-- U+2208 element of -->
          <xsl:text>&#x2208;</xsl:text>
        </math:mo>
        <xsl:apply-templates select="*[3]"/>
      </math:mrow>
      <math:mo>
        <xsl:text>}</xsl:text>
      </math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set1' and @name='notin']]|OMA[OMS[@cd='set1' and @name='notin']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>
        <!-- U+2209 not an element of -->
        <xsl:text>&#x2209;</xsl:text>
      </math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='set1' and @name='notin']|OMS[@cd='set1' and @name='notin']">
    <math:mo>
      <!-- U+2209 not an element of -->
      <xsl:text>&#x2209;</xsl:text>
    </math:mo>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set1' and @name='notprsubset']]|OMA[OMS[@cd='set1' and @name='notprsubset']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>
        <!-- U+2284 not a subset of -->
        <xsl:text>&#x2284;</xsl:text>
      </math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set1' and @name='notsubset']]|OMA[OMS[@cd='set1' and @name='notsubset']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>
        <!-- U+2288 neither a subset of nor equal to -->
        <xsl:text>&#x2288;</xsl:text>
      </math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set1' and @name='prsubset']]|OMA[OMS[@cd='set1' and @name='prsubset']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>
        <!-- U+2ACF closed subset -->
        <xsl:text>&#x2ACF;</xsl:text>
      </math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set1' and @name='set']]|OMA[OMS[@cd='set1' and @name='set']]">
    <math:mrow>
      <math:mfenced separators=",">
        <xsl:attribute name="open">
          <xsl:text>{</xsl:text>
        </xsl:attribute>
        <xsl:attribute name="close">
          <xsl:text>}</xsl:text>
        </xsl:attribute>
        <xsl:for-each select="*[position() &gt; 1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set1' and @name='setdiff']]|OMA[OMS[@cd='set1' and @name='setdiff']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]" mode='set1'/>
      <math:mo>
        <!-- U+2216 set minus -->
        <xsl:text>&#x2216;</xsl:text>
      </math:mo>
      <xsl:apply-templates select="*[3]" mode='set1'/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[position()= 1 and @cd='set1' and @name='size']]|OMA[OMS[position()= 1 and @cd='set1' and @name='size']]">
    <math:mrow>
      <math:mfenced open="|" close="|" separators="">
        <xsl:apply-templates select="*[2]"/>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set1' and @name='subset']]|OMA[OMS[@cd='set1' and @name='subset']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]"/>
      <!-- U+2282 subset of -->
      <math:mo>
        <xsl:text>&#x2282;</xsl:text>
      </math:mo>
      <xsl:apply-templates select="*[3]"/>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set1' and @name='suchthat']]|OMA[OMS[@cd='set1' and @name='suchthat']]">
    <math:mo>
       <xsl:text>{</xsl:text>
    </math:mo>
    <xsl:for-each select="om:OMBIND/om:OMBVAR/*|OMBIND/OMBVAR/*">
      <xsl:apply-templates select="."/>
    </xsl:for-each>
    <math:mo>
      <!-- U+2208 element of -->
      <xsl:text>&#x2208;</xsl:text>
    </math:mo>
    <xsl:apply-templates select="*[2]"/>
    <math:mo>
      <xsl:text>  </xsl:text>
    </math:mo>        
    <math:mo>
      <xsl:text> | </xsl:text>
    </math:mo>        
    <math:mo>
      <xsl:text>  </xsl:text>
    </math:mo>
    <xsl:apply-templates select="om:OMBIND/*[3]|OMBIND/*[3]"/>
    <math:mo>
      <xsl:text>}</xsl:text>
    </math:mo>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set1' and @name='union']]|OMA[OMS[@cd='set1' and @name='union']]">
    <math:mrow>
      <xsl:apply-templates select="*[2]" mode='set1'/>
      <xsl:for-each select="*[position()&gt;2]">
        <math:mo>
          <!-- U+222A union -->
          <xsl:text>&#x222A;</xsl:text>
        </math:mo>
        <xsl:apply-templates select="." mode='set1'/>
      </xsl:for-each>
    </math:mrow>
  </xsl:template>

  <!-- *******************************************************************

       set3

       ******************************************************************* -->

  <xsl:template match="om:OMA[om:OMS[@cd='set3' and @name='apply_to_set']]|OMA[OMS[@cd='set3' and @name='apply_to_set']]">
      <math:mo>{</math:mo>
      <xsl:choose>
       <xsl:when test="om:OMA[position()= 3 and om:OMS[@cd='interval1' and @name='integer_interval']]|OMA[position()= 3 and OMS[@cd='interval1' and @name='integer_interval']]">
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
        </math:mrow>
       </xsl:when>
       <xsl:otherwise>
        <xsl:apply-templates select="om:OMBIND/*[3]|OMBIND/*[3]"/>
        <math:mo>  </math:mo>        <math:mo> | </math:mo>        <math:mo>  </math:mo>
        <xsl:for-each select="om:OMBIND/om:OMBVAR/*|OMBIND/OMBVAR/*">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
        <math:mo>&#8712;</math:mo>
        <xsl:apply-templates select="*[3]"/>
        </xsl:otherwise>
       </xsl:choose>
      <math:mo>}</math:mo>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set3' and @name='big_intersect']]|OMA[OMS[@cd='set3' and @name='big_intersect']]">
    <xsl:choose>
      <xsl:when test='$openmath2mathml.set3.big.boundvariable'>
        <math:mrow>
          <math:munder>
            <math:mo>&#8745;</math:mo>
            <math:mrow>
              <math:mi>c</math:mi>
              <math:mo>
                <!-- U+2208 element of -->
                <xsl:text>&#x2208;</xsl:text>
              </math:mo>
              <xsl:apply-templates select="*[2]"/>
            </math:mrow>
          </math:munder>
          <math:mi>c</math:mi>
        </math:mrow>
      </xsl:when>
      <xsl:otherwise>
        <math:mrow>
          <math:mo>&#8745;</math:mo>
          <xsl:apply-templates select="*[2]"/>
        </math:mrow>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set3' and @name='big_union']]|OMA[OMS[@cd='set3' and @name='big_union']]">
    <xsl:choose>
      <xsl:when test='$openmath2mathml.set3.big.boundvariable'>
        <math:mrow>
          <math:munder>
            <math:mo>&#8746;</math:mo>
            <math:mrow>
              <math:mi>c</math:mi>
              <math:mo>
                <!-- U+2208 element of -->
                <xsl:text>&#x2208;</xsl:text>
              </math:mo>
              <xsl:apply-templates select="*[2]"/>
            </math:mrow>
          </math:munder>
          <math:mi>c</math:mi>
        </math:mrow>
      </xsl:when>
      <xsl:otherwise>
        <math:mrow>
          <math:mo>&#8746;</math:mo>
          <xsl:apply-templates select="*[2]"/>
        </math:mrow>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set3' and @name='cartesian_power']]|OMA[OMS[@cd='set3' and @name='cartesian_power']]">
    <math:msup>
      <xsl:apply-templates select="*[2]"/>
      <xsl:apply-templates select="*[3]"/>
    </math:msup>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set3' and @name='powerset']]|OMA[OMS[@cd='set3' and @name='powerset']]">
    <math:mrow>
      <math:mo>P</math:mo>
      <math:mo>(</math:mo>
      <xsl:apply-templates select="*[2]"/>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

 <xsl:template match="om:OMA[om:OMS[@name='k_subsets' and @cd='set3']]|OMA[OMS[@name='k_subsets' and @cd='set3']]">
    <math:mrow>
  <math:mo> ( </math:mo>
  <math:mtable>
    <math:mtr>
      <math:mtd><xsl:apply-templates select="*[2]"/></math:mtd>
    </math:mtr>
    <math:mtr>
      <math:mtd><xsl:apply-templates select="*[3]"/></math:mtd>
    </math:mtr>
  </math:mtable>
  <math:mo> ) </math:mo>
  </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='set3' and @name='map_on_set']]|OMA[OMS[@cd='set3' and @name='map_on_set']]">
      <math:mo>{</math:mo>
      <xsl:choose>
       <xsl:when test="om:OMA[position()= 3 and om:OMS[@cd='interval1' and @name='integer_interval']]|OMA[position()= 3 and OMS[@cd='interval1' and @name='integer_interval']]">
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
        </math:mrow>
       </xsl:when>
       <xsl:otherwise>
        <xsl:apply-templates select="om:OMBIND/*[3]|OMBIND/*[3]"/>
              <math:mo> | </math:mo>        <math:mo>  </math:mo>
        <xsl:for-each select="om:OMBIND/om:OMBVAR/*|OMBIND/OMBVAR/*">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
        <math:mo>&#8712;</math:mo>
        <xsl:apply-templates select="*[3]"/>
        </xsl:otherwise>
       </xsl:choose>
      <math:mo>}</math:mo>
  </xsl:template>

<xsl:template match="om:OMA[om:OMS[@cd='set3' and @name='map_with_target']]|OMA[OMS[@cd='set3' and @name='map_with_target']]">
      <math:mo>{</math:mo>
      <xsl:choose>
       <xsl:when test="om:OMA[position()= 3 and om:OMS[@cd='interval1' and @name='integer_interval']]|OMA[position()= 3 and OMS[@cd='interval1' and @name='integer_interval']]">
        <math:mrow>
          <xsl:apply-templates select="*[2]"/>
        </math:mrow>
       </xsl:when>
       <xsl:otherwise>
        <xsl:apply-templates select="om:OMBIND/*[3]|OMBIND/*[3]"/>
          <math:mspace width="3pt"/>       <math:mo> | </math:mo>   <math:mspace width="3pt"/>
        <xsl:for-each select="om:OMBIND/om:OMBVAR/*|OMBIND/OMBVAR/*">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
        <math:mo>&#8712;</math:mo>
        <xsl:apply-templates select="*[3]"/>
        </xsl:otherwise>
       </xsl:choose>
      <math:mo>}</math:mo>
  </xsl:template>

  <!-- *******************************************************************

       setname1

       ******************************************************************* -->

  <xsl:template match="om:OMS[@cd='setname1' and @name='C']|OMS[@cd='setname1' and @name='C']">
    <math:mrow>
      <math:mi>&#8450;</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='setname1' and @name='P']|OMS[@cd='setname1' and @name='P']">
    <math:mrow>
      <math:mi>&#8473;</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='setname1' and @name='N']|OMS[@cd='setname1' and @name='N']">
    <math:mrow>
      <math:mi>&#8469;</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='setname1' and @name='Q']|OMS[@cd='setname1' and @name='Q']">
    <math:mrow>
      <math:mi>&#8474;</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='setname1' and @name='R']|OMS[@cd='setname1' and @name='R']">
    <math:mrow>
      <math:mi>&#8477;</math:mi>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='setname1' and @name='Z']|OMS[@cd='setname1' and @name='Z']">
    <math:mrow>
      <math:mi>&#8484;</math:mi>
    </math:mrow>
  </xsl:template>

  <!-- *******************************************************************

       setname2

       ******************************************************************* -->

  <xsl:template match="om:OMS[@cd='setname2' and @name='A']|OMS[@cd='setname2' and @name='A']">
    <math:mrow>
      <math:mo>Algebraic</math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='setname2' and @name='Boolean']|OMS[@cd='setname2' and @name='Boolean']">
    <math:mrow>
      <math:mo>Boolean</math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='setname2' and @name='GFp']]|OMA[OMS[@cd='setname2' and @name='GFp']]">
    <math:mrow>
      <math:mi>GF</math:mi>
      <math:mo>(</math:mo>
      <math:mi><xsl:apply-templates select="*[2]"/></math:mi>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='setname2' and @name='GFpn']]|OMA[OMS[@cd='setname2' and @name='GFpn']]">
    <math:mrow>
      <math:mi>GF</math:mi>
      <math:mo>(</math:mo>
      <math:mi><xsl:apply-templates select="*[2]"/></math:mi>
      <math:mo>,</math:mo>
      <math:mi><xsl:apply-templates select="*[3]"/></math:mi>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='setname2' and @name='H']|OMS[@cd='setname2' and @name='H']">
    <math:mrow>
      <math:mo>
        <!-- U+210D Double-struck capital H -->
        <xsl:text>&#x210D;</xsl:text>
      </math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='setname2' and @name='QuotientField']]|OMA[OMS[@cd='setname2' and @name='QuotientField']]">
    <math:mrow>
      <math:mi>QF</math:mi>
      <math:mo>(</math:mo>
      <math:mi><xsl:apply-templates select="*[2]"/></math:mi>
      <math:mo>)</math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@name='Zm']]|OMA[OMS[@name='Zm']]">
    <math:mrow>
      &#8484;/<xsl:apply-templates select="*[2]"/> &#8484;
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       sequence1

       ******************************************************************** -->

  <xsl:template match="om:OMA[om:OMS[@name='sequence' and @cd='sequence1']]|OMA[OMS[@name='sequence' and @cd='sequence1']]">
    <math:mrow>
      <math:mfenced open="" close="" separators=",">
        <xsl:for-each select="*[position()&gt;1]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </math:mfenced>
    </math:mrow>
  </xsl:template>

  <!-- ********************************************************************

       transc1

       ******************************************************************** -->

  <xsl:template match="om:OMS[@cd='transc1' and @name='arccos']|OMS[@cd='transc1' and @name='arccos']">
    <math:mi>arccos</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='arccosh']|OMS[@cd='transc1' and @name='arccosh']">
    <math:mi>arccosh</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='arccot']|OMS[@cd='transc1' and @name='arccot']">
    <math:mi>arccot</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='arccoth']|OMS[@cd='transc1' and @name='arccoth']">
    <math:mi>arccoth</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='arccsc']|OMS[@cd='transc1' and @name='arccsc']">
    <math:mi>arccsc</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='arccsch']|OMS[@cd='transc1' and @name='arccsch']">
    <math:mi>arccsch</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='arcsec']|OMS[@cd='transc1' and @name='arcsec']">
    <math:mi>arcsec</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='arcsech']|OMS[@cd='transc1' and @name='arcsech']">
    <math:mi>arcsech</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='arcsin']|OMS[@cd='transc1' and @name='arcsin']">
    <math:mi>arcsin</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='arcsinh']|OMS[@cd='transc1' and @name='arcsinh']">
    <math:mi>arcsinh</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='arctan']|OMS[@cd='transc1' and @name='arctan']">
    <math:mi>arctan</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='arctanh']|OMS[@cd='transc1' and @name='arctanh']">
    <math:mi>arctanh</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='cos']|OMS[@cd='transc1' and @name='cos']">
    <math:mi>cos</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='cosh']|OMS[@cd='transc1' and @name='cosh']">
    <math:mi>cosh</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='cot']|OMS[@cd='transc1' and @name='cot']">
    <math:mi>cot</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='coth']|OMS[@cd='transc1' and @name='coth']">
    <math:mi>coth</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='csc']|OMS[@cd='transc1' and @name='csc']">
    <math:mi>csc</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='csch']|OMS[@cd='transc1' and @name='csch']">
    <math:mi>csch</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='exp']|OMS[@cd='transc1' and @name='exp']">
    <math:mi>exp</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='ln']|OMS[@cd='transc1' and @name='ln']">
    <math:mi>ln</math:mi>
  </xsl:template>

  <xsl:template match="om:OMA[om:OMS[@cd='transc1' and @name='log']]|OMA[OMS[@cd='transc1' and @name='log']]">
    <math:mrow>
      <xsl:choose>
        <xsl:when test="$openmath2mathml.transc1.log.style = 'prefix'">
          <math:mmultiscripts>
            <math:mi>log</math:mi>
            <math:mprescripts/>
            <math:none/>
            <xsl:apply-templates select="*[2]"/>
          </math:mmultiscripts>
        </xsl:when>
        <xsl:otherwise>
          <math:msub>
            <math:mi>log</math:mi>
            <xsl:apply-templates select="*[2]"/>
          </math:msub>
        </xsl:otherwise>
      </xsl:choose>
      <math:mo>
        <xsl:text>(</xsl:text>
      </math:mo>
      <xsl:apply-templates select="*[3]"/>
      <math:mo>
        <xsl:text>)</xsl:text>
      </math:mo>
    </math:mrow>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='sec']|OMS[@cd='transc1' and @name='sec']">
    <math:mi>sec</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='sech']|OMS[@cd='transc1' and @name='sech']">
    <math:mi>sech</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='sin']|OMS[@cd='transc1' and @name='sin']">
    <math:mi>sin</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='sinh']|OMS[@cd='transc1' and @name='sinh']">
    <math:mi>sinh</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='tan']|OMS[@cd='transc1' and @name='tan']">
    <math:mi>tan</math:mi>
  </xsl:template>

  <xsl:template match="om:OMS[@cd='transc1' and @name='tanh']|OMS[@cd='transc1' and @name='tanh']">
    <math:mi>tanh</math:mi>
  </xsl:template>

  <!-- ********************************************************************

       veccalc1
       version 3
       symbols: Laplacian, curl, divergence, grad

       ******************************************************************** -->

  <!--
    vector calculus functions
    no brackets for: 
    - variables
    - applications of variables
    maybe add a test for OM prefix functions
  -->
  <xsl:template match="om:OMA[om:OMS[@cd='veccalc1' and (@name='Laplacian' or @name='curl' or @name='divergence' or @name='grad')]]
    |OMA[OMS[@cd='veccalc1' and (@name='Laplacian' or @name='curl' or @name='divergence' or @name='grad')]]">
    <xsl:variable name='use_brackets'>
      <xsl:choose>
        <xsl:when test='*[2][self::OMV] or *[2][self::om:OMV]'>
          <xsl:text>false</xsl:text>
        </xsl:when>
        <xsl:when test='*[2][self::OMA[*[1][self::OMV]]] or *[2][self::om:OMA[*[1][self::om:OMV]]]'>
          <xsl:text>false</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>true</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <math:mrow>
      <xsl:apply-templates select='*[1]'/>

      <xsl:if test='$use_brackets ="true"'>
        <math:mo>
          <xsl:text>(</xsl:text>
        </math:mo>
      </xsl:if>
      <xsl:apply-templates select='*[2]'/>
      <xsl:if test='$use_brackets ="true"'>
        <math:mo>
          <xsl:text>)</xsl:text>
        </math:mo>
      </xsl:if>
    </math:mrow>
  </xsl:template>

  <xsl:template match="OMS[@cd='veccalc1' and @name='Laplacian']|om:OMS[@cd='veccalc1' and @name='Laplacian']">
    <math:msup>
      <math:mo>
        <!-- U+2207 Nabla -->
        <xsl:text>&#x2207;</xsl:text>
      </math:mo>
      <math:mn>
        <xsl:text>2</xsl:text>
      </math:mn>
    </math:msup>
  </xsl:template>

  <xsl:template match="OMS[@cd='veccalc1' and @name='curl']|om:OMS[@cd='veccalc1' and @name='curl']">
    <math:mo>
      <!-- U+2207 Nabla -->
      <xsl:text>&#x2207;</xsl:text>
    </math:mo>
    <math:mo>
      <!-- U+00D7 Multiplication sign, Cartesian product -->
      <xsl:text>&#x00D7;</xsl:text>
    </math:mo>
  </xsl:template>

  <xsl:template match="OMS[@cd='veccalc1' and @name='divergence']|om:OMS[@cd='veccalc1' and @name='divergence']">
    <math:mo>
      <!-- U+2207 Nabla -->
      <xsl:text>&#x2207;</xsl:text>
    </math:mo>
    <math:mo>
      <!-- U+00B7 Middle dot -->
      <xsl:text>&#x00B7;</xsl:text>
    </math:mo>
  </xsl:template>

  <xsl:template match="OMS[@cd='veccalc1' and @name='grad']|om:OMS[@cd='veccalc1' and @name='grad']">
    <math:mo>
      <!-- U+2207 Nabla -->
      <xsl:text>&#x2207;</xsl:text>
    </math:mo>
  </xsl:template>
</xsl:stylesheet>
